/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

PROJECT: Value of Regulatory Discretion

PURPOSE: Create reduced-form exhibits from the paper "The Value
         of Regulatory Discretion: Estimates from Environmental
         Inspections in India."

         Reduced-form exhibits include summary statistics tables,
         intention-to-treat estimates and the like. The
         structural estimates are produced separately by matlab
         code in the same parent directory.

AUTHORS: Duflo, Greenstone, Pande and Ryan  

INPUT:	/replication/data/01_reduced_form/
        All datasets *.dta within.

OUTPUT:	See list of local variables below for exhibits produced.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/

clear all
pause on
cap log close
set mem 400m
set more off
* set maxvar 10000
* set matsize 1200
set scrollbufsize 100000
local seed 92387
set seed `seed'
local BSNUM 200

ssc install listtab

//	Settings and paths
include settings.do
include programs.do

// Local variables to switch on (=1) / off (=0) exhibits.  

// Paper figures (reduced-form results only)
local Figure1_binnedRegressions					1
local Figure2_RegulatoryTargeting				1
    local CIs                                                   0
local Figure7_InspectionDistributions                           1
                                                                
// Paper tables (reduced-form results only)                     
local Table1_RegulatoryInteractions                             1
    local Table1_PanelAB					1
    local Table1_PanelC						1
    local 1c_USD						1
local Table2_PanelA_CostOnTreat                                 1
local Table2_PanelB_PollOnTreat                                 1
local Table3_PenaltyStageActions                                1
local Table4_PenaltyStagePolicy                                 1
                                                                
// Appendix exhibits                                            
local TableA2_SampleChain                                       1
local TableA3_TreatmentAssignments                              1
local TableA4_CovariateBalance                                  1
local TableA5_EndlineAttrition                                  1
local TableA6_AttritionByTreatment                              1
local TableA7_FollowupByTreatment                               1
local TableA8_LetterTreatment                                   1
local TableA9_PlaceboCompliance                                 1
local TableA10_TargetingOnUnobs                                 1


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// FIGURES (Reduced-form only)
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Figure 1: Effect of Treatment on Pollution Distribution
//   Panel A. Experimental Data
if `Figure1_binnedRegressions' == 1 {

	// get cetp status
	use "`WORK'/treatment_assignment_inspection", clear
	rename cetp_status cetp
	keep plantid cetp aud_treatment ins_treatment
	sort plantid 
	tempfile cetp
	save `cetp'
	
	use "`WORK'/endline_pollution_readings.dta", clear
	gen aud_sample = aud_treatment == 0 | aud_treatment == 1 
	replace aud_treatment = 0 if aud_treatment == 9
	gen audXins = aud_treatment * ins_treatment
	gen reg_abd = region == "ABD"
	gen reg_sur = region == "SUR"
	gen pol_stdlim = (pol - limit) / sd
			
	// Make empty variables for coefficient and SE of each bin
	local i = 0
	forvalues topbin = -6(2)16 {
		gen b_bin`i' = .
		gen se_bin`i' = .
		local i = `i' + 1
	}

	// Double observations and group into {all, air, water} pools
	gen pgroup=""
	tempfile double
	save "`double'"
	append using "`double'", gen(source)
	replace pgroup="water" if source==0 & type==1
	replace pgroup="air"   if source==0 & type==2
	replace pgroup="all"   if source==1

	// Make dummies for whether value falls in each bin
	local i = 0
	forvalues topbin = -6(2)16 {
		gen bin`i' = pol_stdlim>((`topbin'/10)-2/10) & pol_stdlim<=(`topbin'/10) if pgroup=="all"
		local i = `i' + 1
	}

	// Regress dummy on treatment status
	foreach bin of varlist bin* {
		reg `bin' ins_treatment aud_treatment audXins aud_sample reg_abd reg_sur, cluster(plantid)
		replace b_`bin' = _b[ins_treatment] if pgroup=="all"
		replace se_`bin' = _se[ins_treatment] if pgroup=="all"
	}
	drop bin*	
	
	// Reshape and adjust for graph plotting
	keep pgroup b_bin* se_bin*
	duplicates drop
	reshape long b_bin se_bin, i(pgroup) j(bin)
	rename b_bin b
	gen b_lo = b - 1.96*se_bin
	gen b_hi = b + 1.96*se_bin
	drop se_bin
	replace bin = (bin*0.2) - 0.7 

	#delimit ;
	twoway
		(bar b bin if pgroup=="all", barwidth(0.2) color(gs7) /*color(`gcolor7')*/ fintensity(inten100))
		(rcap b_lo b_hi bin if pgroup=="all", lcolor(black) msize(large)),
		legend(off)
		xscale(range(-0.8 1.6))
		yscale(range(-.05 .05))
		xline(0, lcolor(black))
		xlabel(#5, labsize(`glabelsize'))
		ylabel(#4, labsize(`glabelsize'))
		xtitle("Pollution in standard deviations relative to regulatory limit", size(`glabelsize'))
		ytitle("Inspection treatment (=1) coefficient in bin", size(`glabelsize'))
		`gproportions'
		graphregion(color(white))
		bgcolor(white)
		note("");
	#delimit cr
	
	graph export "`PAPERFIGURES'/figure1_panelA_treatment_on_pollution_bins.pdf", replace
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Figure 2: Regulatory Targeting of Extreme Polluters
if `Figure2_RegulatoryTargeting' == 1 {

	pause on
	
	// Get number of inspections and pollution readings in first year
	use "`WORK'/admin_inspection_outcomes", clear
	keep if date > 18110 & date < 18475
	*keep if date > 18110 & date <= 18808
	g pol_readings = !missing(spm) | !missing(so2) | !missing(nox) | !missing(tds) | !missing(tss) | !missing(cod) | !missing(bod) | !missing(an)
	keep plantid pol_readings ins_treatment
	g inspections = 1
	collapse (sum) inspections (sum) pol_readings, by(plantid ins_treatment)	
	tab ins_t
	tab ins_t if pol_readings != 0
	g firstyear_polreading = (pol_readings > 0)
	g firstyear_inspection = 1
	keep plantid firstyear*
	merge 1:1 plantid using "`WORK'/treatment_assignment_inspection"
	keep if !missing(ins_treatment)
	replace firstyear_inspection = 0 if missing(firstyear_inspection) & _m == 2
	replace firstyear_polreading = 0 if missing(firstyear_polreading) & _m == 2
	keep plantid firstyear* ins_treatment
	isid plantid
	sort plantid 
	tempfile firstyear
	save `firstyear'
		
	// get plantid status 
	use "`WORK'/treatment_assignment_inspection", clear
	keep plantid cetp_status ins_treatment
	rename cetp_status cetp
	sort plantid 
	tempfile cetpstatus
	save `cetpstatus'
	
	use "`WORK'/admin_pollution_readings", clear
	sort plantid
	merge m:1 plantid using `cetpstatus'
	keep if _merge == 3
	drop _merge

	// merge in limits and make polbin
	replace cetp = -97 if par == "nox" | par == "so2" | par == "spm"
	sort par cetp
	merge par cetp using "`WORK'/admin_pollution_limits"
	drop if _merge == 2
	g pol_std_limit = pol/limit
	lab var pol_std_limit "Pollution level / regulatory standard"
	keep plantid date ins_treatment pol_std_limit
	sort plantid date
	
	foreach type in limcount /* firstyear first latestpre_firstpost closest*/ {
		if "`type'" == "closest" {
			* For each plant, keeping the observation that was nearest the start of the experiment (if any within 365 days)
			g days_from_start = abs(18110 - date)
			bys plantid: egen mindays = min(days_from_start)
			keep if days_from_start == mindays
			keep if mindays < 365
			drop days_from_start mindays date
		}
		
		if "`type'" == "first" {
			* For each plant, keeping the first observation from after the experiment started, taken at that plant (losing sample that had only inspections pre-treatment) */
			keep if date > 18110
			bys plantid (date): g first = (_n==1)
			bys plantid date: egen firstday = max(first)
			keep if firstday == 1
			drop first firstday date 
		}
		
		if "`type'" == "firstyear" {
			* For each plant, keeping the first observation from within the first year of the experiment, taken at that plant (losing sample that had only inspections pre-treatment) */
			keep if date > 18110 & date < 18475
			bys plantid (date): g first = (_n==1)
			bys plantid date: egen firstday = max(first)
			keep if firstday == 1
			drop first firstday date 
		}
			
		if "`type'" == "latestpre_firstpost" {
			* For each plant, keep the last observation if any observations before experiment, or alternatively; first observation after start
			g keep = 0
			g pre = (date < 18110 )
			bys plantid: egen any_pre = max(pre)
			bys plantid pre (date): g last = (_n==_N)
			bys plantid pre (date): g first = (_n==1)
			bys plantid date: egen lastday = max(last)
			bys plantid date: egen firstday = max(first)
			replace keep = 1 if any_pre == 1 & pre == 1 & lastday == 1
			replace keep = 1 if any_pre == 0 & firstday == 1
			keep if keep == 1
			drop keep pre any_pre last first lastday firstday date	
		}
		
		if "`type'" == "limcount" {
			keep if date > 18110 & date < 18475
			drop date 
		}
		
		// Take mean pollution levels at plant, relative to limit
		collapse /*(mean) ins_treatment*/ (max) pol_std_limit , by(plantid)
		*lab def treat 0 "Inspection Control" 1 "Inspection Treatment"
		*lab val ins_treatment treat
		
		merge 1:1 plantid using `firstyear'
		assert _merge != 1
		lab var pol_std_limit "Maximum pollution reading in first year (relative to regulatory standard)" 
		
		if "`type'" == "limcount" {
			foreach n in 1 2 5 10 {
				forv T = 0/1 {
					qui cou if ins_treatment == `T'
					qui local c = `r(N)'
					qui cou if pol_std_limit > `n' & ins_treatment == `T' & !missing(pol_std_limit)
					local c`T'`n' = r(N)
					local lab`T'`n' = r(N)+10
					qui local  perc = 100*round(`r(N)'/`c',0.0001)
					di "`n'x limit: `r(N)'/`c' (`perc'%) `T' firms over limit"
					di `c`T'`n''
				}
				
				cou if  firstyear_polreading==1 & ins_t==1
					local cANYt = r(N)
					local labANYt = r(N)+10
				cou if  firstyear_polreading==1 & ins_t==0
					local cANYc = r(N)
					local labANYc =r(N)+10
				
				g firstyear_over`n' = (pol_std_limit > `n') & !missing(pol_std_limit) /* 0 if no pollution reading taken */ 
				lab var firstyear_over`n' "At least 1 pollution reading >`n'x limit in first year"
			}
		}


		
		
if `CIs'==1 {
	
	ttest firstyear_polr, by(ins_treatment)
	mat a = `r(mu_1)', `r(sd_1)', `r(N_1)',`r(mu_2)',`r(sd_2)', `r(N_2)',`r(t)',`r(p)'
	
	foreach n of numlist 1 2 5 10 {	
		ttest firstyear_over`n', by(ins_treatment)
	mat a`n' = `r(mu_1)', `r(sd_1)', `r(N_1)',`r(mu_2)',`r(sd_2)', `r(N_2)',`r(t)',`r(p)'
	}
	mat b = a\a1\a2\a5\a10
	mat rownames b = "Any Reading" ">1p" ">2p" ">5p" ">10p" 
	mat colnames b = "Treatment" "Treatment SD" "Treatment N" "Control" "Control SD" "Control N" "t" "p"
	mat list b	
	
	esttab mat(b) using "`PAPERTABLES'/Figure4_ttests.txt", fixed nomtitles replace
	
		set trace off
		
		foreach n of numlist 1 2 5 10 {
			foreach t of numlist 0 1 {
			
			cou if firstyear_polr==1 & ins_t==`t'
			local tany_`t' = r(N)

			sum firstyear_polr if ins_t==`t'
			local sdany_`t'= r(sd) * `tany_`t''
	
			sum firstyear_over`n' if ins_t==`t' & firstyear_polr==1
			local t`n'_`t' = r(mean) * `tany_`t''
			
			sum firstyear_over`n' if ins_t==`t' & firstyear_polr==1
			local sd`n'_`t'= r(sd) * `tany_`t''
			
			/* g total`n'_`t'_sd = `r(sd)'
			cou if firstyear_over`n'==1 & ins_t==`t'
			replace total`n'_`t'_sd=total`n'_`t'_sd * `r(N)'
			
			sum total`n'_`t' */
			
			}
		
		di "Any reading:"
		
		ttesti 480 `tany_1' `sdany_1' 480 `tany_0' `sdany_0', une
		mat a = `r(mu_1)',`r(sd_1)', 480,`r(mu_2)',`r(sd_2)', 480,`r(t)',`r(p)'
		
		
		di "Poll Bin = `n':"
		ttesti `tany_1' `t`n'_1' `sd`n'_1' `tany_0' `t`n'_0' `sd`n'_0', une
		mat a`n' = `r(mu_1)',`r(sd_1)', `tany_1',`r(mu_2)',`r(sd_2)', `tany_0',`r(t)',`r(p)'
		
		
		}
		
	mat b = a\a1\a2\a5\a10
	mat rownames b = "Any Reading" ">1p" ">2p" ">5p" ">10p" 
	mat colnames b = "Treatment" "Treatment SD" "Treatment N" "Control" "Control SD" "Control N" "t" "p"
	mat list b
	

	
	foreach n of numlist 1 2 5 10 {
			foreach t of numlist 0 1 {
			
			cou if firstyear_polr==1 & ins_t==`t'
			local tany_`t' = r(N)

			sum firstyear_polr if ins_t==`t'
			local sdany_`t'= r(sd) * `tany_`t''
	
			sum firstyear_over`n' if ins_t==`t' & firstyear_polr==1
			local t`n'_`t' = r(mean) * 480
			
			sum firstyear_over`n' if ins_t==`t' & firstyear_polr==1
			local sd`n'_`t'= r(sd) * 480
			
			/* g total`n'_`t'_sd = `r(sd)'
			cou if firstyear_over`n'==1 & ins_t==`t'
			replace total`n'_`t'_sd=total`n'_`t'_sd * `r(N)'
			
			sum total`n'_`t' */
			
			}
		
		di "Any reading:"
		
		ttesti 480 `tany_1' `sdany_1' 480 `tany_0' `sdany_0', une
		mat a = `r(mu_1)',`r(sd_1)', 480,`r(mu_2)',`r(sd_2)', 480,`r(t)',`r(p)'
		
		
		di "Poll Bin = `n':"
		ttesti 480 `t`n'_1' `sd`n'_1' 480 `t`n'_0' `sd`n'_0', une
		mat a`n' = `r(mu_1)',`r(sd_1)', `tany_1',`r(mu_2)',`r(sd_2)', `tany_0',`r(t)',`r(p)'
		
		
		}
		
	mat c = a\a1\a2\a5\a10
	mat rownames c = "Any Reading" ">1p" ">2p" ">5p" ">10p" 
	mat colnames c = "Treatment" "Treatment SD" "Treatment N" "Control" "Control SD" "Control N" "t" "p"
	mat list c
	
	esttab mat(b) mat(c) using "`PAPERTABLES'/Figure4_ttests", fixed nomtitles replace
		
		*/
}
				
		local varlist ""
		local colors ""
		local n = 1
		foreach var of varlist /*firstyear_inspection */ firstyear_polreading firstyear_over* {
			g empty_`var' = 0
			lab var empty_`var' ""
			forv T = 0/1 {
				if `T' == 0 {
					local treat "Control"
					local col "gs5"
				}
				if `T' == 1 {
					local treat "Treatment"
					local col "gs11"
				}
				
				/* if "`var'" == "firstyear_inspection" | "`var'" == "firstyear_polreading" local yaxis = 1
					else local yaxis = 2 /* creating two separate y-axes: one for 0-402, one for 0-150 */ */
					
				g t`T'_`var' = `var' if ins_treatment == `T' /* this way can easily create separate bars for treatment and control */ 
				g xvar`n' = `n'
				local varlist "`varlist' (bar t`T'_`var' xvar`n', yaxis(`yaxis') color(`col'))"
				local n = `n'+1
			}
			local varlist "`varlist' (bar empty_`var' xvar`n', yaxis(1))" /* adding this to create empty vertical space between pairs */
			g xvar`n' = `n'
			local n = `n'+1
		}

	di "`varlist'"

		su pol_std_limit if ins_treatment == 0
		su pol_std_limit if ins_treatment == 0, detail
		su pol_std_limit if ins_treatment == 1		
		su pol_std_limit if ins_treatment == 1, detail		
		
		estpost ttest firstyear_over*, by(ins_treatment) une
		esttab using "`PAPERTABLES'/Figure2_regulatory_targeting_ttests.tex", replace label
		
		local max = 25
	}

	collapse (sum) t0_* t1_* empty_* (mean) xvar*
		
		twoway `varlist', ///
			legend(order(1 "Control" 2 "Treatment") region(lcolor(white))) plotr(fcolor(white))  ///
			ytitle("Number of Plants with Reading") ///
			xtitle("Pollution relative to regulatory limit") ///
			bgcolor(white) ///
			graphregion(icolor(white) fcolor(white) margin(large) color(white) lcolor(none)) plotregion(color(white) lcolor(none)) ///
			xlabel(1.5 "Any Reading" 4.5 ">1p" 7.5 ">2p" 10.5 ">5p" 13.5 ">10p", noticks) ///
			ytick(0(100)250) ylabel(, nogrid) ///
			text(-6.5 4.77 "_") text(-6.5 7.77 "_") text(-6.5 10.77 "_") text(-6.5 13.9 "_")
			/*
			text(`labANYc' 1 "`cANYc'", place(c)) text(`labANYt' 2 "`cANYt'", place(c)) ///
			text(`lab01' 4 "`c01'", place(c)) text(`lab11' 5 "`c11'", place(c)) ///
			text(`lab02' 7 "`c02'", place(c)) text(`lab12' 8 "`c12'", place(c)) ///
			text(`lab05' 10 "`c05'", place(c)) text(`lab15' 11 "`c15'", place(c)) ///
 			text(`lab010' 13 "`c010'", place(c)) text(`lab110' 14 "`c110'", place(c)) */
			
			// The figure summarizes pollution readings taken during the first year //
			// of the intervention for the treatment and control groups. The first //
			// pair of bars shows the number of plants that underwent at least one ///
			// pollution reading. The remaining four pairs show the number of plants ///
			// at least one reading above the standard (>1x), more than 2 times the //
			// standar (>2x), more than 5 times the standard (>5x), and more than 10 //
			// times the standard (>10x). 
			
	graph export "`PAPERFIGURES'/figure2_regulatory_targeting_of_extreme_polluters.pdf", replace
}		


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Figure 7: Model Fit to Inspections and Pollution
//  This code produces inspection distributions only. The pollution distributions
//  and model inspection distributions are produced in matlab code in the same
//  parent directory.
//    Note that these distributions are for all inspections. The matlab code
//  produces the distributions of *initial* inspections that correspond to the
//  model object of interest. An initial inspection is the first inspection in a
//  chained interaction between the regulator and plants.
if `Figure7_InspectionDistributions' == 1 {
  
	use "`WORK'/admin_inspection_received", clear
	local aspectratio = 0.5
	
	* Rate of inspections for the histograms is defined as the total number
        * of inspections from august 2009 - may 2011, then times 12/22 to get
        * an annual rate
	g inspectionstotal_annual = (inspectionstotal_duringtreat)*(12/22)
	
	#delimit ;
	histogram inspectionstotal_annual if ins_treatment==0, 
		frequency
		width(1)
		xtitle("")
		ytitle("Frequency",size(vsmall)) 
		bgcolor(white)
		color(gs7)
	    graphregion(icolor(white) fcolor(white) margin(zero)) aspectratio(`aspectratio') ysize(12) xsize(20) 
		ylabel(, labsize(tiny)) xlabel(0(2)10, labsize(tiny)) plotregion(margin(zero))
		legend(off) scale(3) ysc(r(.5)) ylabel(0(50)250)
	;
	#delimit cr	
	graph export "`PAPERFIGURES'/figure7_panelA_inspection_distribution_control.pdf", replace
		
	#delimit ;
	histogram inspectionstotal_annual if ins_treatment==1, 
		frequency
		width(1)
		xtitle("")
		ytitle("Frequency",size(vsmall))
		bgcolor(white)
		color(gs7)
	    graphregion(icolor(white) fcolor(white) margin(zero)) aspectratio(`aspectratio') ysize(12) xsize(20) 
		ylabel(, labsize(tiny)) xlabel(0(2)10, labsize(tiny)) plotregion(margin(zero))
		legend(off) scale(3) ysc(r(.5)) ylabel(0(50)250)
	;
	#delimit cr
	graph export "`PAPERFIGURES'/figure7_panelB_inspection_distribution_treatment.pdf", replace
	
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table 1: Regulatory Interactions During Experiment
if `Table1_RegulatoryInteractions' == 1 {
  
	if `Table1_PanelAB' == 1 {
		use "`WORK'/endline_plant_survey", clear

		keep plantid a11* a12* a13*
		
		forv n = 2008/2010 {
			if `n'==2008 local num = 11
			if `n'==2009 local num = 12
			if `n'==2010 local num = 13
			
			rename a`num'a_inspections_`n' 			perceived_inspections_`n'
			rename a`num'b_show_cause_notices_`n' 	perceived_showcauses_`n'
			rename a`num'c_closure_notices_`n'		perceived_notices_`n'
			rename a`num'd_disconnections_`n'		perceived_disconnections_`n'
					
			foreach type in inspections showcauses notices disconnections {
				g p_`type'_`n'_orig = perceived_`type'_`n'
				
				* Keep one version which keeps missing as missing 
				replace p_`type'_`n'_orig = . if p_`type'_`n'_orig == -99 | p_`type'_`n'_orig==-97
				
				* Replace missing values as 0
				* (since other questions on the survey were answered, we can assume that the answer here should be 0 (and not missing))
				replace perceived_`type'_`n' = 0 if perceived_`type'_`n' ==-99 | perceived_`type'_`n' ==-97
			}

			egen perceived_total_`n' = rowtotal(perceived_showcauses_`n' perceived_notices_`n' perceived_disconnections_`n')
			egen p_total_`n' = rowtotal(p_showcauses_`n'_orig p_notices_`n'_orig p_disconnections_`n'_orig)
			
			label var perceived_inspections_`n' 	"Perceived Inspections by GPCB officials, `n'"
			label var perceived_showcauses_`n'		"Perceived Show cause/warning notices received, `n'"
			label var perceived_notices_`n'			"Perceived Closure notices received, `n'"
			label var perceived_disconnections_`n'	"Perceived Actual closures/utility disconnections, `n'"
			label var perceived_total_`n'			"Total perceived notices and closures received, `n'"
			
			label var p_inspections_`n'_orig		"Perceived Inspections by GPCB officials, `n'"
			label var p_showcauses_`n'_orig			"Perceived Show cause/warning notices received, `n'"
			label var p_notices_`n'_orig			"Perceived Closure notices received, `n'"
			label var p_disconnections_`n'_orig		"Perceived Actual closures/utility disconnections, `n'"
			label var p_total_`n'					"Total perceived notices and closures received, `n'"
		}
			
		isid plantid
		tempfile perceived
		save `perceived'
		
		// get audit sample
		use "`WORK'/treatment_assignment_inspection", clear
		rename cetp_status cetp
		g audsamp = aud_treatment == 0 | aud_treatment == 1
		keep plantid audsamp
		sort plantid
		tempfile audsamp
		save `audsamp'
		
		use "`WORK'/admin_inspection_received",clear
			sort plantid
		merge plantid using "`WORK'/admin_inspection_assigned"	
		keep if _merge == 3
		drop _merge
		sort plantid
		merge plantid using `audsamp'
		assert _merge != 1
		keep if _merge == 3
		drop _merge
		
		merge 1:1 plantid using `perceived'
		drop _merge
		tempfile main
		save `main' 
		
			use "`WORK'/admin_chains_raw", clear
			g year  = year(date)
			g month = month(date)
			preserve
				use "`WORK'/treatment_assignment_inspection", clear
				keep if ins_tr<99
				keep plantid region size
				tempfile region
				save `region'
			restore 
			merge m:1 plantid using "`region'" 
			drop if _merge!=3
			drop _merge
			gen keep=0
			replace keep=1 if year==2010
			replace keep=1 if year==2009 & month>=8
			replace keep=1 if year == 2011 & month<=4 & region == "ABD"
			replace keep=1 if year == 2011 & month<=5 & region != "ABD"
			keep if keep==1
			drop keep 
			keep if chain_n==1
			sort plantid chain
			by plantid: gen chain_count=_n
			collapse (max) chain_count (first) region size, by(plantid)
			g chain_count_annual = (chain_count)*(12/22)
			replace chain_count_annual = (chain_count)*(12/21) if region=="ABD"
			keep plantid chain_count_annual size
			label var chain_count_annual "Number of chains, scaled and annual over treatment"
	
		merge 1:1 plantid using `main'
		drop _merge
		replace chain_count_annual=0 if chain_count_annual==.

                // Indicator for whether inspections insufficient
                gen medium = size=="Medium"
                label var medium "Capital investment Rs. 50m to Rs. 100m (=1)"

                g num_inspections_low = inspectionstotal_scaled < 1
                replace num_inspections_low = inspectionstotal_scaled < 4 if medium
                label var num_inspections_low "Inspections below prescribed (=1)"
		
		label var inspections2010 "Number of inspections in 2010, annual rate"
		local TESTVARSA assigned_inspections_annual inspectionstotal_scaled chain_count_annual num_inspections_low
		local TESTVARSB perceived_inspections_2008 perceived_inspections_2009 perceived_inspections_2010 perceived_total_2010
                
		cd "`PAPERTABLES'"
                
		// TABLE FOR PANEL A
		diffTest `TESTVARSA', by(ins_treatment)
		esttab using Table1_PanelA_inspections_received.tex, title(Inspections by Treatment Status\label{tab:Table2InspMeans}) ///
			nomtitles nonumbers collabels("Treatment" "Control" "Difference") varwidth(32) label replace ///
			booktabs cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N1 N2, labels(Observations) layout("@ @")) ///
			addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01" "Treatment ran August 2009-May 2011, inclusive." ///
			"Inspections for 2009 and 2011 are pro-rated to reflect this.")
		
		// TABLE FOR PANEL B
		diffTest `TESTVARSB', by(ins_treatment)
		esttab using Table1_PanelB_inspections_perceived.tex, title(Perceived Regulatory Actions by Treatment Status\label{tab:Table2InspMeansB}) ///
			nomtitles nonumbers collabels("Treatment" "Control" "Difference") varwidth(32) label replace ///
			booktabs cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N1 N2, labels(Observations) layout("@ @")) ///
			addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01" "Treatment ran August 2009-May 2011, inclusive." ///
			"Inspections for 2009 and 2011 are pro-rated to reflect this.")
				
	}

	if `Table1_PanelC' == 1 {
		clear
		use "`WORK'/treatment_assignment_inspection.dta"
		keep plantid ins_treatment
		keep if ins_treatment<.
		tempfile assignments
		save "`assignments'"

		//	Prepare GPCB actions
		clear
		use "`WORK'/admin_regulator_actions.dta"
		merge m:1 plantid using "`assignments'"
		keep if _merge==3
		drop _merge
		tab action_doc_type ins_treatment
		keep plantid doc_year doc_month action_doc_type action_reasons_03 action_reasons_04
		tempfile actions
		save "`actions'"

		//	Prepare industry bank guarantees
		use "`WORK'/admin_plant_actions.dta", clear
		merge m:1 plantid using "`assignments'"
		tab plantid
		keep if _merge==3
		drop _merge
		gen doc_year = year(date)
		gen doc_month = month(date)

		keep plantid doc_year doc_month doctype guar_amount
		keep if doctype=="Guarantee" | doctype=="Equipment" | doctype=="Third-Party"
		//keep if doctype=="Guarantee" | doctype=="Equipment" 
		replace doctype="Bank guarantee" if doctype=="Guarantee"
		replace doctype="Equipment installed" if doctype=="Equipment"
		tempfile guarantees
		save "`guarantees'"

		clear
		append using "`actions'" "`guarantees'"

		merge m:1 plantid using "`assignments'"
	
		keep if (doc_year == 2009 & doc_month>=8) | doc_year==2010 | (doc_year==2011 & doc_month<=6)
		keep if ins_treatment<.		// audit sample
		
		sort plantid 
		gen letter 		= action_doc_type==1 | action_doc_type==2
		gen showcause 	= action_doc_type==3
		gen cite_water	= action_doc_type==3 & action_reasons_03==1
		gen cite_air	= action_doc_type==3 & action_reasons_04==1
		gen cite_other	= action_doc_type==3 & action_reasons_03!=1 & action_reasons_04!=1
		gen notice 		= action_doc_type==4
		gen direction 	= action_doc_type==5
		gen guarantee	= doctype=="Bank guarantee"
		gen equipment	= doctype=="Equipment installed"
		gen shutoff2	= doctype=="Third-Party"
                
		by plantid: egen letters 	= total(letter)
		by plantid: egen showcauses 	= total(showcause)
		by plantid: egen cites_water = total(cite_water)
		by plantid: egen cites_air 	= total(cite_air)
		by plantid: egen cites_other = total(cite_other)
		by plantid: egen notices		= total(notice)
		by plantid: egen directions 	= total(direction)
		by plantid: egen guarantees 	= total(guarantee)
		by plantid: egen equipments	= total(equipment)
		by plantid: egen shutoffs	= total(shutoff2)
		
		label var showcauses 	"Citations"
		label var cites_water 	"~~~Citations, water"
		label var cites_air 	"~~~Citations, air"
		label var cites_other	"~~~Citations, other"
		label var notices	"Closure warnings"
		label var directions 	"Closure directions"
		label var guarantees 	"Bank guarantees"
		label var equipments 	"Equipment mandates"
		label var shutoffs	"Utility disconnections"
		
		keep plantid ins_treatment letters-shutoffs
		duplicates drop
		gen letter 		= letters > 0
		gen showcause 	= showcauses > 0
		gen cite_water	= cites_water > 0
		gen cite_air 	= cites_air > 0
		gen cite_other 	= cites_other > 0
		gen notice 		= notices > 0
		gen direction 	= directions > 0
		gen guarantee	= guarantees > 0
		gen equipment	= equipments > 0
		gen shutoff		= shutoffs > 0
		egen any = rowmax(letter-shutoff)
		label var showcause 	"Any citation issued (=1)"
		label var cite_water	"Any water citation issued (=1)"
		label var cite_air	"Any air citation issued (=1)"
		label var cite_other	"Any other citation issued (=1)"
		label var notice	"Any closure warning (=1)"
		label var direction	"Any closure direction (=1)"
		label var guarantee	"Any bank guarantee posted (=1)"
		label var equipment	"Any equipment mandated (=1)"
		label var shutoff	"Any utility disconnection (=1)"
		
		tempfile actions
		save "`actions'"

		//	NOW, deal with assignments dataset.
		cd "`WORK'"
		use treatment_assignment_inspection.dta
		
		// Drop firms not in inspection sample
		keep if ins_treatment < .

		// Merge back in the set of regulatory actions
		merge plantid using "`actions'", _merge(mergeActions)
		sort plantid 
		
		// Zero out the plants that had no interactions
                //   Scale to get annual rates for duration of treatment
		foreach var of varlist showcauses cites_water cites_air notices directions guarantees notices shutoffs equipments {
			replace `var' = 0 if `var'==.
                        // replace `var' = 12/22 * `var' /* At annual rate */
		}
		
		preserve
                
			// get limits
			use "`WORK'/admin_pollution_limits.dta", clear
			sort par cetp
			tempfile limits
			save `limits'
			
			// get inspection treatment
			use "`WORK'/treatment_assignment_inspection",clear
			keep plantid ins_treatment cetp_status
			rename cetp_status cetp
			sort plantid
			tempfile ins_treatment
			save `ins_treatment'
			
			// get reports which had no parameter taken
			use "`WORK'/admin_inspection_outcomes", clear
			keep plantid date
			duplicates drop
			sort plantid date 
			tempfile allreports
			save `allreports'
			
			use "`WORK'/admin_pollution_readings", clear
			// merge in inspection treatment indicators
			sort plantid
			merge plantid using `ins_treatment'
			keep if _merge == 3 
			drop _merge
			
			// merge in limits and create relative measures
			replace cetp = -97 if par == "nox" | par == "so2" | par == "spm"
			sort par cetp
			merge par cetp using `limits'
			keep if _merge == 3 
			drop _merge
			
			sort plantid date
			merge plantid date using `allreports' // this gives a missing pol for reports with no analysis
			g pol_reading = (_merge == 3)
			g above_limit = (pol > limit)
			drop _merge
					
			*keep if (doc_year == 2009 & doc_month>=8) | doc_year==2010 | (doc_year==2011 & doc_month<=6)
			keep if date >= 18110 & date <=18808
			
			lab var above_limit "Pollution reading is above the allowed limit"
			lab var pol_reading "Inspection included a pollution reading"
					
			bys plantid: egen ever_above_limit = max(above_limit)
			bys plantid: egen ever_pol_reading = max(pol_reading)
			bys plantid: egen n_pol_readings = sum(pol_reading)
			bys plantid: egen readings_above_limit = sum(above_limit)

			keep plantid date ever_pol_reading ever_above_limit readings_above_limit n_pol_readings
			
			bys plantid date: g n = _n
			keep if n == 1
			bys plantid: g number_inspections = _N
			drop date n
			duplicates drop
			sort plantid 
			
			lab var number_inspections "Number of inspections at plant during treatment"
			lab var ever_pol_reading "Pollution reading ever collected at plant (=1)"
			lab var ever_above_limit "Any pollution reading above limit at plant (=1)"
			lab var n_pol_readings       "Pollution readings"
			lab var readings_above_limit "Pollution readings above limit"

                        // Scale number of readings at an annual rate
                        replace n_pol_readings = n_pol_readings * 12/22
                        // replace readings_above_limit = readings_above_limit * 12/22
			
			tempfile readings
			save `readings' 

		restore	
		
		merge plantid using `readings'
		isid plantid 

		foreach var of varlist ever_pol_reading ever_above_limit n_pol_readings readings_above_limit number_inspections {
			replace `var' = 0 if `var' == .
		}

		foreach var of varlist directions guarantees equipments shutoffs {
			local reglist "`reglist'  (`var' ins_treatment)"
			local testlist "`testlist'  [`var']ins_treatment"
		}
		sureg `reglist'
		test `testlist'
		local p = substr(string(r(p)),1,4)
		local chi2 = substr(string(r(chi2)),1,4)
		
		cd "`PAPERTABLES'"
		// TABLE FOR PANEL C
     		local TESTVARS ever_pol_reading ever_above_limit readings_above_limit showcauses cites_water cites_air notices directions guarantees equipments shutoffs
                // local TESTVARS ever_pol_reading ever_above_limit n_pol_readings showcauses notices directions guarantees equipments shutoffs


		diffTest `TESTVARS', by(ins_treatment)
		esttab using Table1_PanelC_regulatory_actions.tex, title(Regulatory Interactions During Experiment\label{tab:balance}) ///
			nomtitles nonumbers collabels("Control" "Treatment" "Difference") varwidth(32) label replace booktabs ///
			cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N1 N2, labels(Observations) layout("@ @")) ///
			addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01" "Potentially ambiguous regulatory interactions are defined as followed:" ///
			"Citations are a request for written response on high pollution levels;" ///
			"air and water citations specifically name a pollutant." ///
			"Bank guarantees are the forced posting of a bond that is forfeited" ///
			"for high future pollution levels,or failure to install equipment." ///
			"Four most serious infractions are not jointly significant," ///
			"with a Wald statistic of `chi2' and a p-value of `p'." ) 
	}
	
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table 2: Endline Pollution and Compliance on Treatments
//   Panel A. Costs
//   Panel B. Pollution
if `Table2_PanelA_CostOnTreat' == 1 {

// Add baseline air pollution control and maintenance equipment controls
//	Now use assignments dataset
cd "`WORK'"
use treatment_assignment_inspection.dta, clear
// Drop firms not in inspection sample
keep if ins_treatment < .
gen apcm_scr = regexm(apcm,"SCR")==1
label var apcm_scr "Scrubber installed (=1)"
gen apcm_cyc = regexm(apcm,"CY")==1
label var apcm_cyc "Cyclone installed (=1)"
gen apcm_fil = regexm(apcm,"FIL")==1
label var apcm_fil "Bag filter installed (=1)"
keep apcm_* plantid
tempfile apcm
save `apcm'	
	
// Wehther any maintenance costs
use "`WORK'/endline_abatement_cost", clear
preserve
	keep plantid maintain_etp*
	reshape long maintain_etp, i(plantid) j(j)
	drop j
	replace maintain_etp=0 if maintain_etp==.
	collapse (sum) maintain_etp, by(plantid)
	gen any_etp = maintain_etp>0 
	label var maintain_etp "~~~of ETP"
	label var any_etp "Any ETP maintenance cost"
	tempfile etp
	save `etp'
restore
        
keep plantid maintain_apcm*
reshape long maintain_apcm, i(plantid) j(j)
drop j
replace maintain_apcm=0 if maintain_apcm==.
collapse (sum) maintain_apcm, by(plantid)
gen any_apcm = maintain_apcm>0 
label var maintain_apcm "~~~of any APCM"
label var any_apcm "Any APCM maintenance cost" 
merge 1:1 plantid using `etp'
drop _merge

gen maintain=maintain_etp+maintain_apcm
label var maintain "Maintenance costs"
gen any_maintain= maintain>0
label var any_maintain "Any maintenance costs"
tempfile main
save `main'

// Combine maintenance with capital costs
use "`WORK'/endline_abatement_cost", clear
keep plantid ins_treat Operations Raw_Materials Electricity Fuel Chemicals APCM_Boiler_Maintain APCM_Process_Maintain 
merge 1:1 plantid using `main'
drop _merge 
local OPERATION_VARS	Operations Raw_Materials Electricity Fuel Chemicals
local MAINTAIN_VARS	maintain maintain_etp maintain_apcm APCM_Boiler_Maintain APCM_Process_Maintain 
// Change currency to USD (1 USD = 50 INR)
	foreach i of varlist `OPERATION_VARS' APCM_Boiler_Maintain APCM_Process_Maintain {
		replace `i' = `i'/50
	}
		foreach i of varlist maintain maintain_etp maintain_apcm {
		replace `i' = `i'/50000
	}
local OPMAINT_VARS `OPERATION_VARS' `MAINTAIN_VARS' any_*

// Get ETP maintenance cost data
use "`WORK'/endline_abatement_cost", clear
preserve
	keep plantid maintain_etp*
	reshape long maintain_etp, i(plantid) j(j)
	drop j
	drop if mi(maintain_etp)
	ren mainta maint_cost
	g etp = 1
	tempfile etp
	save `etp'
restore
keep plantid maintain_apcm*
reshape long maintain_apcm, i(plantid) j(j)
drop j
drop if mi(maintain_apc)
ren mainta maint_cost
g apcm = 1	
append using `etp'
replace apcm=0 if apcm==.
tempfile main
save `main'

// By plant
preserve
	use "`WORK'/endline_plant_survey", clear
	keep plantid
	tempfile list
	save `list'
restore
preserve
	use "`WORK'/treatment_assignment_inspection", clear
	keep plantid ins_treatment aud_* reg* 
	sort plantid
	tempfile assignment
	save `assignment'
restore
use "`WORK'/admin_plant_cost_factors", clear
g cost = exp(lcost)	
collapse (firstnm) EL-high (mean) cost, by(plantid)
g lcost = ln(cost)
merge 1:m plantid using `main'
drop _merge
replace maint_cost = 0 if mi(maint)
replace maint_cost = maint/50000
gsort plantid -apcm   

collapse (firstnm) EL-high apcm (sum) maint_cost, by(plantid)
rename apcm any_apcm_maintenance
replace any_apcm_maintenance=0 if any_apcm_maint==.
gen any_main= maint_cost!=0

* drop plants not in endline
merge 1:1 plantid using `list'
keep if _merge==3
drop _m

merge 1:1 plantid using `assignment'
keep if _merge==3
drop _m

foreach i of varlist size2 EL highww {
	g tX`i' = ins_tre * `i'
}

lab var EL "Coal or lignite as fuel (=1)"
lab var size "Medium size industry (=1)"
lab var high "Waste water generated $>$ 100 kl/day (=1)"
lab var tXE "Coal or lignite as fuel $\times$ Inspection treatment (=1)"
lab var tXsi "Medium size industry $\times$ Inspection treatment (=1)"
lab var tXh "Waste water generated $>$ 100 kl/day $\times$ Inspection treatment (=1)"
	
// Creating audit and inspection sample and treatment controls
g aud_sample = aud_treatment!=9
label var aud_sample "Audit sample (=1)"
replace aud_treatment = 0 if aud_treatment==9

g audXins = aud_treatment*ins_treatment
label var audXins "Audit X inspection treatment (=1)"
	
g insXaudsample = ins_treatment * aud_sample
lab var insXaudsample "Inspection treatment X Audit sample (=1)"

g reg_sur = region=="SUR"
	lab var reg_sur "Region: Surat (=1)"
g reg_abd = region=="ABD"
	lab var reg_abd "Region: Ahmedabad (=1)" 
	
tempfile temp
save `temp'

use "`WORK'/endline_abatement_cost", clear
forvalues i=1/8 {
	g capital_etp`i' = c08b`i'_etp_invest_quantity/2 if c08h`i'==0 & c08b`i'<.
}

forvalues i=1/5 {
	g capital_apcm`i' = c10b`i'_apcm_invest_quantity/2 if c10h`i'==0 & c10b`i'<.
}
preserve
	keep plantid capital_etp*
	reshape long capital_etp, i(plantid) j(j)
	drop j
	drop if mi(capital_etp)
	ren capital capital_cost
	g etp = 1
	tempfile etp_capital
	save `etp_capital'
restore
keep plantid capital_apcm*
reshape long capital_apcm, i(plantid) j(j)
drop j
drop if mi(capital_apc)
ren capital capital_cost
g apcm = 1	
append using `etp_capital'
replace apcm=0 if mi(apcm)
preserve
	use "`WORK'/endline_plant_survey", clear
	keep plantid
	tempfile list
	save `list'
restore
merge m:1 plantid using `list'
drop _merge
replace capital_cost = 0 if mi(capital_cost)
replace capital_cost = capital_cost/50000

gsort plantid -apcm 
collapse (firstnm) apcm etp (sum) capital_cost, by(plantid)
rename apcm any_apcm_capital
drop etp 
replace any_apcm_capital=0 if any_apcm_capital==.

gen annual_capital_cost = ((1-(5/6))/(1-((5/6)^11)))*capital_cost
label var annual_capital_cost "Amortized Annual Capital Cost, in Thousands of USD"
gen any_capital= annual_capital_cost!=0

merge 1:1 plantid using `temp'		
drop _merge
	
// Put capital and maintenance cost regressions in one table
drop size2 EL highww
preserve
	use "`WORK'/treatment_assignment_inspection", clear
	drop if mi(ins_treat)
	g size2 = size=="Medium"
	g highww = wwg>100 
	g coallignite = (coal == 1 | lignite == 1)
	label var coallignite "Coal or lignite as fuel (=1)"
	keep plantid size2 highww coallignite
	tempfile plant_characteristics
	save `plant_characteristics'  
restore 
merge 1:1 plantid using `plant_characteristics'
drop if _merge!=3
drop _merge
		// First stage: Maintenance cost on treatment
		// Regressors:
			/* Inspections treatment */ loc ins ins_treat
			/* Audit treatment */ loc aud aud_samp aud_treatment
			/* Region FEs */ loc region reg_sur reg_abd
			/* Abatement cost characteristics */ loc abate size2 coal highww
	eststo clear
	foreach r in "`aud' `region' `abate'" {
			reg maint_ `ins' `r', robust
				eststo
				sum maint_
				estadd scalar Smean = r(mean)
				sum maint_ if ins_tr==0
				estadd scalar Cmean = r(mean)
	}
	foreach r in "`aud' `region' `abate'" {
			reg any_main `ins' `r', robust
				eststo
				sum any_main
				estadd scalar Smean = r(mean)
				sum any_main if ins_tr==0
				estadd scalar Cmean = r(mean)
	}
tempfile temp
save `temp'



use "`WORK'/endline_abatement_cost", clear
forvalues i=1/8 {
	g capital_etp`i' = c08b`i'_etp_invest_quantity/2 if c08h`i'==0 & c08b`i'<.
}

forvalues i=1/5 {
	g capital_apcm`i' = c10b`i'_apcm_invest_quantity/2 if c10h`i'==0 & c10b`i'<.
}
preserve
	keep plantid capital_etp*
	reshape long capital_etp, i(plantid) j(j)
	drop j
	drop if mi(capital_etp)
	ren capital capital_cost
	g etp = 1
	tempfile etp_capital
	save `etp_capital'
restore
keep plantid capital_apcm*
reshape long capital_apcm, i(plantid) j(j)
drop j
drop if mi(capital_apc)
ren capital capital_cost
g apcm = 1	
append using `etp_capital'
replace apcm=0 if mi(apcm)
preserve
	use "`WORK'/endline_plant_survey", clear
	keep plantid
	tempfile list
	save `list'
restore
merge m:1 plantid using `list'
drop _merge
replace capital_cost = 0 if mi(capital_cost)
replace capital_cost = capital_cost/50000

gsort plantid -apcm 
collapse (firstnm) apcm etp (sum) capital_cost, by(plantid)
rename apcm any_apcm_capital
drop etp 
replace any_apcm_capital=0 if any_apcm_capital==.

gen annual_capital_cost = ((1-(5/6))/(1-((5/6)^11)))*capital_cost
label var annual_capital_cost "Amortized Annual Capital Cost, in Thousands of USD"
gen any_capital= annual_capital_cost!=0

merge 1:1 plantid using `temp'		
drop _merge

	foreach r in "`aud' `region' `abate'" {
			reg annual_capital_cost `ins' `r', robust
				eststo
				sum annual_capital_cost
				estadd scalar Smean = r(mean)
				sum annual_capital_cost if ins_tr==0
				estadd scalar Cmean = r(mean)
	}
	foreach r in "`aud' `region' `abate'" {
			reg any_capital `ins' `r', robust
				eststo
				sum any_capital
				estadd scalar Smean = r(mean)
				sum any_capital if ins_tr==0
				estadd scalar Cmean = r(mean)
	}
	esttab using "`PAPERTABLES'/Table2_PanelA_costs_on_treatment.tex", ///
		title("Plant-level Costs"\label{plantCosts}) ///
		se lab stats(r2 Smean Cmean N,labels("R2" "Mean" "Control Mean" "Observations")) ///
		varwidth(32) wrap nomtitles compress nogap replace ///
		addnote("Costs in USD thousands. Robust standard errors in parentheses." ///
		"Plant characteristics include dummies for size, use of coal or lignite as fuel," ///
		"high waste water generated, and region.  Audit experiment includes dummies for audit" ///
		"treatment and audit sample.") ///
		indicate("Plant characteristics = reg_sur reg_abd size2 coallignite highww" ///
			"Audit experiment = aud_sample aud_treatment") ///
		booktabs star(* .1 ** .05 *** .01)
		
}

if `Table2_PanelB_PollOnTreat' == 1 {
  
	use "`WORK'/endline_pollution_readings",clear
	g reg_sur = region=="SUR"
	g reg_abd = region=="ABD"
	
	// Dependent variable standardized just by the backcheck sd
	g pol_std_zero = pol/sd
	
	// Creating audit and inspection sample and treatment controls
	g aud_sample = aud_treatment!=9
	label var aud_sample "Audit sample (=1)"
	replace aud_treatment = 0 if aud_treatment==9

	g audXins = aud_treatment*ins_treatment
	label var audXins "Audit X inspection treatment (=1)"
		
	g insXaudsample = ins_treatment * aud_sample
	lab var insXaudsample "Inspection treatment X Audit sample (=1)"
	
	eststo clear
	xi: reg pol_std_zero ins_treatment aud_treatment audXins aud_sample reg_sur reg_abd, cluster(plantid)
		qui sum pol_std_zero if aud_treatment==0 & ins_treatment == 0
		estadd scalar cmean = r(mean)
		eststo, title("Pollution"):

        test ins_treatment + aud_treatment + audXins = 0
        test aud_treatment + audXins - ins_treatment = 0
	pause on
	
	xi: reg comply ins_treatment aud_treatment audXins aud_sample reg_sur reg_abd, cluster(plantid)
		qui sum comply if aud_treatment==0 & ins_treatment == 0
		estadd scalar cmean = r(mean)
		eststo, title("Compliance"):

	cd "`PAPERTABLES'"
	esttab using Table2_PanelB_pollution_on_treatment.tex, ///
		title("Plant-by-pollutant level pollution"\label{PollutionTreatment2}) ///
		varwidth(32) label se mtitles("Pollution" "Compliance") nonum booktabs width(0.8\hsize) replace ///
		addnote("Pollution standardized by backcheck standard deviation." "Includes audit treatment and treatment interaction controls," "and year and region fixed effects") /// 
		drop(reg_sur reg_abd _cons aud_sample)  ///
		stats(cmean N, fmt(3 0) labels("Inspection and audit control mean" "Observations")) ///
		star(* 0.10 ** 0.05 *** 0.01)  
	eststo clear	
}

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table 3: Structure of Penalty Stage Actions
if `Table3_PenaltyStageActions' == 1 {
	
	// get inspection treatment
	use "`WORK'/treatment_assignment_inspection",clear
	keep plantid ins_treatment
	sort plantid
	tempfile ins_treatment
	save `ins_treatment'

	use "`WORK'/admin_chains_raw",clear
	sort plantid 
	merge plantid using `ins_treatment'
	assert _merge != 1
	drop if _merge == 2
	drop _merge
		
	sort plantid chain date samedatesort

	// Simplify categories for display
	clonevar actionBig_show = actionBig
	replace actionBig = 5 if actionBig == 6
	replace actionBig_show = 5 if actionBig_show == 6
	drop action 
	
	// Collapse for output
	levelsof actionBig_show, local(levels)
	forv var = 1/7 {
		g output`var' = actionBig_show == `var'
		local newlabel : label (actionBig_show) `var'
		label var output`var' "`newlabel'"
		
		if `var' != 6 {
			local labelstring `"`labelstring' "`newlabel'""' 
			local outstring "`outstring' output`var'(fmt(1))"
		}
	}

	// Control actions only
	*keep if ins_treatment == 0
	
	// Create total variable and total ex inspections variable
	expand 3 if _n == _N
	replace chain_n = 98 if _n == _N - 1
        replace chain_n = 99 if _n == _N
		label def chain_n 98 "Total" 99 "Total ex inspection"
		label val chain_n chain_n
	g count = 1 
	replace count = _N - 2 if _n == _N - 1

        egen inspections = total(output1)
        replace count = inspections if _n == _N
        drop inspections
	
	foreach var of varlist output* {
		egen junk = total(`var')
		replace `var' = junk if _n == _N - 1 | _n == _N
		drop junk
	}
        replace output1 = 0 if _n == _N // Ex-inspection totals

	collapse (sum) output* count , by(chain_n)

	// Create % remaining variable
	g percent_remaining = count[1] // running sum
	replace percent_remaining = 100*count/percent_remaining
	replace percent_remaining = . if _n == _N
	label var count "N"
	label var percent_remaining "% remaining"
	replace percent_remaining = . if mod(_n,2) == 0 

	// Convert from action counts into percentages
	egen rowtotal = rowtotal(output*)
	foreach var of varlist output* {
		replace `var' = 100*`var'/rowtotal
	}
	
	// Cleaner presentation by zeroing out the nonrelevant categories
	count
	local to1 = r(N) - 1
	local to2 = r(N) - 2
		
	forv j = 1(2)`to1' {
		forv k = 5(1)7 {
			replace output`k' = . if _n == `j'
		}
	}
	
	forv j = 2(2)`to2' {
		forv k = 1(1)4 {
			replace output`k' = . if _n == `j'
		}
	}
	
	drop output6 /* Dropping firm "protest"; now counts as firm "ignore" */

	* Collapsing all rounds in rounds 15+ into one line
	forv k = 1/4 {
		replace output`k' = (output`k'[15] * count[15] + output`k'[17] * count[17] + output`k'[19] * count[19] ) / ( count[15] + count[17] + count[19] ) if chain_n == 15
	}
	forv k = 5(2)7 {
		replace output`k' = (output`k'[16] * count[16] + output`k'[18] * count[18] ) / ( count[16] + count[18]) if chain_n == 15
	}
	forv k = 16/19 {
		drop if chain_n == `k'
	}
	
	cd "`PAPERTABLES'"
	estpost tabstat output* count percent_remaining, by(chain_n) nototal
	esttab using Table3_Penalty_Stage_Actions.tex, c("`outstring' count(fmt(0)) percent_remaining(fmt(1))") ///
		style(tex) booktabs label compress replace ///
		title("Control Actions, by Round in Chain"\label{ActionByRoundBothControl}) noobs nonum collabels(`labelstring' "N~" "\% left") mlabels(none) ///
		addnote("Round 15+ summarizes actions from rounds 15 through 19")
	eststo clear
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table 4: Multinomial Logit Model of Action Choice Conditional on State
if `Table4_PenaltyStagePolicy' == 1 {
  
// Prepare variables for multinomial logit estimation
use "`WORK'/admin_chains_estimation", clear

// Create and label pollution vars for easy output
//   polBz are categories of pollution levels
// 1 is 0-1 times allowed level of pollution
// 2 is 1-2 times allowed level of pollution, etc.: 2-5x, 5x+ times 
forv j = 1(1)4 {
	g polBz`j' = polBin == `j'
	local newlabel : label (polBin) `j'
	label var polBz`j' "`newlabel'"
}

// Adjust labels for action variables to indicate lags
foreach var of varlist action0_l1 action0_l2 action1_l1 action1_l2  {
	foreach j of numlist 2 3 5 6 7 {
		g `var'_Z`j' = `var' == `j'
		su `var'_Z`j'
			if r(max) == 0 drop `var'_Z`j'
		local newlabel : label actionBig `j'
		local lag = substr("`var'",10,1)
		cap label var `var'_Z`j' "`newlabel', lag `lag'"
	}
}

// Interactions of actions and pollution
forv j = 1(1)4 {
   g a0_l1_Z7_X_pol`j' = action0_l1_Z7 * polBz`j'
   label var a0_l1_Z7_X_pol`j' "Firm: Comply, l1 X pol=`j'"
 }
  
// Create additional time variables
*g later = chaint != 1
*g chaint2 = chaint^2
foreach j of numlist 3 5 7 {
	g time_dum`j' = chaint > `j'
	label var time_dum`j' "t $>$ `j'"
}

// Interactions of actions and round
forv j = 3(2)7 {
	g a0_l1_Z7_X_t`j' = action0_l1_Z7 * time_dum`j'
	label var a0_l1_Z7_X_t`j' "Firm: Comply, l1 X time=`j'"
}

*label var later    "Not first in chain" 
label var chaint   "Time"
*label var chaint2  "Time, squared"
label var polCont  "Pollution"
*label var polCont2 "Pollution, squared"


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Conditional choice probabilities : multinomial logit specifications
// Binary firm choice specifications

// GPCB, base outcome "Accept", rounds 3 and later
mlogit actiont action1_l1_Z2 action1_l1_Z3 action0_l1_Z7 ///
			   polBz* time_dum3 time_dum5 time_dum7 ///
			   if actiont <= 4 & chaint >= 3, baseoutcome(4)
est store M1

// Plant, base outcome "Ignore"
g comply = actiont == 7
lab var comply "Comply"
logit comply action1_l1_Z2 action1_l1_Z3 action0_l1_Z7 ///
			   polBz* time_dum3 time_dum5 time_dum7 ///
			   if actiont >= 5
est store M2
		

cd "`PAPERTABLES'"
esttab M1 M2 using Table4_Penalty_Stage_Policy.tex, replace        ///
	title("Multinomial Logit Models for Action Choice") ///
	cells( b(fmt(a2) star) se(par) )                    ///
	stats( r2_p N, labels("Pseudo R-squared" "Observations") )     ///
	starlevels(* 0.10 ** 0.05 *** 0.01)                 ///
	style(tex) booktabs label unstack collabels(none)   ///
	order(action1_l1_Z2 action1_l1_Z3 action0_l1_Z7 polBz* _cons time_dum3 time_dum5 time_dum7) ///
	mlabels(, none nodepvars span prefix(\multicolumn{3}{c}{) suffix(})) ///
	addnote("Omitted action for firm is Ignore"       ///
		"Omitted action for regulator is Inspect" ///
		"Omitted pollution reading is null (no reading taken)")

}




//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//                               APPENDIX EXHIBITS
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A2: Sample Chain of Plant and Regulator Actions
if `TableA2_SampleChain' == 1 {
  
	use "`WORK'/admin_chains_raw.dta", clear

	* Relabel for the table
	lab define actionBigT ///
		0 "Null" ///
		1 "Inspect" ///
		2 "Warn" ///
		3 "Punish" ///
		4 "Accept" ///
		5 "Ignore" ///
		6 "Protest" ///
		7 "Comply" 
	lab val actionBig actionBigT
	
	* Relabel documents and only show document if not imputed
	g action_ni = action if imputed~=1
	
	label define actionLabelsT	///
		10	"Inspection report"	///
		21	"CCA: Amendment"	///
		22	"CCA: Approval"	///
		23	"CCA: Further details required"	///
		24	"CCA: Rejection"	///
		25	"CCA: Other"	///
		31	"Letter"	///
		33	"Show Cause Notice"	///
		34	"Closure Notice"	///
		35	"Closure Direction"	///
		39  "Ignore" ///
		40	"Revocation of Closure Direction"	///
		50	"Monitoring direction"	///
		51	"Third-party response"	///
		60	"Industry response"	///
		61	"Contestation"	///
		62	"Equipment installed"	///
		63	"Process installed"	///
		64	"Bank guarantee posted"	///
		69	"Ignore" ///
		98	"Other"
	
	label val action_ni actionLabelsT
	
	* Choose one sample chain, which contains a varied sequence of actions.
        * Many other chains are similarly rich (20823, 21356, 10639)
	sort plantid chain chain_n
	*br chain_n player actionBig action_ni date if plantid == 20823 & chain_max == 13
	sort plantid chain chain_n

	eststo clear
	cd "`PAPERTABLES'"
	#delimit ; 
	listtab chain_n player actionBig action_ni date using TableA2_Sample_Chain.tex if plantid == 20823 & chain_max == 13, 
		headlines(	"\begin{table}[htbp]\centering"
					"\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"
					"\caption{Sample Chain \label{SampleChain}}"
					"\begin{tabular*}{.99\hsize}{@{\hskip\tabcolsep\extracolsep\fill}c*{1}{cclc}}"
					"\toprule"
					"\multicolumn{1}{c}{Round} & \multicolumn{1}{c}{Player} & \multicolumn{1}{c}{Action} & \multicolumn{1}{c}{Document}& \multicolumn{1}{c}{Date} \\"
					"\multicolumn{1}{c}{(1)} &\multicolumn{1}{c}{(2)} &\multicolumn{1}{c}{(3)} &\multicolumn{1}{c}{(4)} &\multicolumn{1}{c}{(5)} \\"
					"\midrule")
		footlines(	"\bottomrule"
					"\multicolumn{5}{p{0.95\hsize}}{\footnotesize The table displays a 13-round chain of interactions between GPCB and one plant during the experiment. Column (3) indicates the category of action, while Column (4) reports the underlying document to which the action corresponds. \emph{Ignore} actions by the plant in Rounds 2, 6 and 8 have been imputed based on adjacent actions in the chain and hence Column (4) is left blank in these rounds.  All chains begin with a regulatory inspection, \emph{Inspect}. The players then alternate moves in until the regulator decides to \emph{Accept} the plant's compliance for the time being, which terminates the chain. Table 1 in the paper describes the way in which the actions are mapped to the underlying documents, and the Data Appendix provides a full explanation of the rules used to construct the chains.}\\"
					"\end{tabular*}"
					"\end{table}")
		delimiter(" & ") 
		end(" \\ ") 
		replace ;
	#delimit cr
	
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A3: Experimental Design - Treatment Assignments
if `TableA3_TreatmentAssignments' == 1 {
  
use "`WORK'/treatment_assignment_inspection.dta", clear
keep plantid ins_treatment aud_treatment region

keep if !missing(ins_treatment)
lab def aud_treatment_label 9 "Not audit eligible", modify
label var ins_treatment "Inspection treatment (=1)"

estpost tabulate aud_treatment ins_treatment

cd "`PAPERTABLES'"
esttab using TableA3_Treatment_Assignments, ///
  title("Experimental Design: Treatment Assignments"\label{tab:design}) ///
  cell( b(fmt(0) keep(Total)) ) ///
  varwidth(32) label replace booktabs width(0.7\hsize) ///
  unstack noobs nonumber nomtitle ///
  addnote("The table reports the number of plants assigned to each combination of the" ///
          "inspection treatment and the audit treatment of Duflo et al.~(2013)." ///
          "Inspection treatment status is either control or treatment. With" ///
          "respect to audit, only some plants are audit-eligible (see text)." ///
          "Conditional on being eligible for audit plants are assigned to" ///
          "treatment or control.")

}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A4: Inspection Treatment Covariate Balance
if `TableA4_CovariateBalance' == 1 {

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    //  Prepare number of inspections
    use "`WORK'/admin_inspection_received.dta",replace
    keep plantid inspections_prescribed  notinspected0708 inspectionsPRE_scaled
    sort plantid
    tempfile totalinspections
    save `totalinspections'
    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    //	Prepare assignments to merge in
    use "`WORK'/treatment_assignment_inspection.dta", clear
    keep plantid ins_treatment
    keep if ins_treatment<.
    tempfile assignments
    save "`assignments'"
    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    //	Prepare GPCB actions
    use "`WORK'/admin_regulator_actions.dta", clear
    merge m:1 plantid using "`assignments'"
    keep if _merge==3
    drop _merge
    tab action_doc_type ins_treatment
    keep plantid doc_year action_doc_type action_reasons_03 action_reasons_04
    tempfile actions
    save "`actions'"
    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    //	Prepare industry bank guarantees
    use "`WORK'/admin_plant_actions.dta", clear
    merge m:1 plantid using "`assignments'"
    keep if _merge==3
    drop _merge
    gen doc_year = year(date)
    keep plantid doc_year doctype guar_amount
    keep if doctype=="Guarantee" | doctype=="Equipment" | doctype=="Third-Party"
    replace doctype="Bank guarantee" if doctype=="Guarantee"
    replace doctype="Equipment installed" if doctype=="Equipment"
    replace doctype="Utility disconnection" if doctype=="Third-Party"
    tempfile guarantees
    save "`guarantees'"
    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    //	Prepare inspections and citations
    use "`WORK'/admin_inspection_outcomes", clear
    sort plantid
    merge m:1 plantid using "`assignments'"
    keep if _merge==3
    drop _merge
    foreach var of varlist year month day {
    	rename `var' doc_`var'
    }
    keep plantid doc_year doc_month doc_day 
    g category = "Inspection Report"
    tempfile inspections
    save "`inspections'"
    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    //	Append together, reshape, create indicator variables
    clear
    append using "`actions'" "`guarantees'" "`inspections'"
    keep if doc_year==2008 | category=="Inspection Report"
    merge m:1 plantid using "`assignments'"
    
    keep if ins_treatment<.		// audit sample
    sort plantid
    gen letter 		= action_doc_type==1 | action_doc_type==2
    gen showcause 	= action_doc_type==3
    gen cite_water	= action_doc_type==3 & action_reasons_03==1
    gen cite_air	= action_doc_type==3 & action_reasons_04==1
    gen cite_other	= action_doc_type==3 & action_reasons_03!=1 & action_reasons_04!=1
    gen notice 		= action_doc_type==4
    gen direction 	= action_doc_type==5
    gen guarantee	= doctype=="Bank guarantee"
    gen equipment	= doctype=="Equipment installed"
    gen shutoff2	= doctype=="Utility disconnection"

    gen inspection07 = category=="Inspection Report" & doc_year==2007
    gen inspection08 = category=="Inspection Report" & doc_year==2008
    gen inspection09 = category=="Inspection Report" & doc_year==2009 & doc_month<=7
    gen inspection_yearpretreat = category == "Inspection Report" & ((doc_year = =2008 & doc_month >= 8) | (doc_year == 2009 & doc_month <=7))

    by plantid: egen letters 	= total(letter)
    by plantid: egen showcauses 	= total(showcause)
    by plantid: egen cites_water = total(cite_water)
    by plantid: egen cites_air 	= total(cite_air)
    by plantid: egen cites_other = total(cite_other)
    by plantid: egen notices	= total(notice)
    by plantid: egen directions 	= total(direction)
    by plantid: egen guarantees 	= total(guarantee)
    by plantid: egen equipments	= total(equipment)
    by plantid: egen inspections07 = total(inspection07)
    by plantid: egen inspections08 = total(inspection08)
    by plantid: egen inspections09 = total(inspection09)
    by plantid: egen shutoffs	= total(shutoff2)

    keep plantid letters-shutoffs
    duplicates drop

    label var showcauses        "Citations"
    label var cites_air         "Citations, air"
    label var cites_water       "Citations, water"
    label var cites_other       "Citations, other"
    label var notices           "Closure warnings"
    label var directions        "Closure directions"
    label var guarantees        "Bank guarantees posted"
    label var equipments        "Equipment mandates"
    label var shutoffs	 	"Utility disconnections"

    gen letter 		= letters > 0
    gen showcause 	= showcauses > 0
    gen cite_water	= cites_water > 0
    gen cite_air 	= cites_air > 0
    gen cite_other 	= cites_other > 0
    gen notice 		= notices > 0
    gen direction 	= directions > 0
    gen guarantee	= guarantees > 0
    gen equipment	= equipments > 0
    gen inspection07	= inspections07 > 0
    gen inspection08	= inspections08 > 0
    gen inspection09	= inspections09 > 0
    egen any = rowmax(letter-inspection09)

    label var showcause 	"Any citation issued (=1)"
    label var cite_water	"Any water citation issued (=1)"
    label var cite_air		"Any air citation issued (=1)"
    label var cite_other	"Any other citation issued (=1)"
    label var notice		"Any closure warning (=1)"
    label var direction		"Any closure direction (=1)"
    label var guarantee		"Any bank guarantee posted (=1)"
    label var equipment		"Any equipment mandated (=1)"
    label var shutoff           "Any utility disconnection (=1)"

    label var inspection07	"Any inspection conducted in 2007 (=1)"
    label var inspection08	"Any inspection conducted in 2008 (=1)"
    label var inspection09	"Any inspection conducted in 2009 to 30-Jul (=1)"
    label var inspections07	"Number of inspections in 2007"
    label var inspections08	"Number of inspections in 2008"
    label var inspections09	"Number of inspections in 2009 to 30-Jul"
    
    keep plantid inspections* ///
      showcause cite_water cite_air notice direction guarantee equipment shutoff ///
      showcauses cites_water cites_air notices directions guarantees equipments shutoffs
    
    tempfile actions
    save "`actions'"

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Prep pollution readings
    clear 
                
    // get limits
    use "`WORK'/admin_pollution_limits.dta", clear
    sort par cetp
    tempfile limits
    save `limits'
    
    // get inspection treatment
    use "`WORK'/treatment_assignment_inspection",clear
    keep plantid ins_treatment cetp_status
    rename cetp_status cetp
    sort plantid
    tempfile ins_treatment
    save `ins_treatment'
    
    // get reports which had no parameter taken
    use "`WORK'/admin_inspection_outcomes", clear
    keep plantid date
    duplicates drop
    sort plantid date 
    tempfile allreports
    save `allreports'
    
    // merge in inspection treatment indicators
    use "`WORK'/admin_pollution_readings", clear
    sort plantid
    merge plantid using `ins_treatment'
    keep if _merge == 3 
    drop _merge
    
    // merge in limits and create relative measures
    replace cetp = -97 if par == "nox" | par == "so2" | par == "spm"
    sort par cetp
    merge par cetp using `limits'
    keep if _merge == 3 
    drop _merge
    
    sort plantid date
    merge plantid date using `allreports' // this gives a missing pol for reports with no analysis
    g pol_reading = (_merge == 3)
    g above_limit = (pol > limit)
    drop _merge
    		
    // keep if (doc_year == 2009 & doc_month>=8) | doc_year==2010 | (doc_year==2011 & doc_month<=6)
    // keep if date >= 18110 & date <=18808 /* Period of experiment */

    gen inspection_yearpretreat = (date >= td(01aug2008)) & (date <= td(31jul2009))
    keep if inspection_yearpretreat
    
    lab var above_limit "Pollution reading is above the allowed limit"
    lab var pol_reading "Inspection included a pollution reading"
    		
    bys plantid: egen ever_above_limit = max(above_limit)
    bys plantid: egen ever_pol_reading = max(pol_reading)
    bys plantid: egen n_pol_readings = sum(pol_reading)
    bys plantid: egen readings_above_limit = sum(above_limit)
    		
    keep plantid date ever_pol_reading ever_above_limit readings_above_limit n_pol_readings
    
    bys plantid date: g n = _n
    keep if n == 1
    drop date n
    duplicates drop
    
    lab var ever_pol_reading "Pollution reading ever collected (=1)"
    lab var ever_above_limit "Any pollution reading above limit (=1)"
    lab var n_pol_readings "Number of pollution readings"
    lab var readings_above_limit "Number of pollution readings above limit"
    
    sort plantid 
    tempfile readings
    save `readings' 

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    //	Now use assignments dataset
    cd "`WORK'"
    use treatment_assignment_inspection.dta
    
    // Drop firms not in inspection sample
    keep if ins_treatment < .
    
    // Merge back in the set of regulatory actions
    merge plantid using "`actions'", _merge(mergeActions)
    drop mergeActions

    // Merge back in pollution readings
    sort plantid
    merge plantid using `readings', _merge(mergeReadings)
    drop mergeReadings
    isid plantid

    // Replace missing readings with null
    foreach var of varlist ever_pol_reading ever_above_limit n_pol_readings readings_above_limit {
    	replace `var' = 0 if missing(`var')
    }
    
    // Generate new variables based on XGN data for fuel, APCM, etc. to be
    //   used in the test of randomization balance.
    gen emission_fge = regexm(emission_sources,"FGE")==1
    label var emission_fge "Air emissions from flue gas (=1)"
    gen emission_boiler = regexm(emission_sources,"BOI")==1
    label var emission_boiler "Air emissions from boiler (=1)"
    gen emission_tfh  = regexm(emission_sources,"TFH")==1
    label var emission_tfh "Air emissions from thermic fluid heater (=1)"
    gen emission_dgs = regexm(emission_sources,"DGS")==1
    label var emission_dgs "Air emissions from diesel generator (=1)"
    
    gen apcm_scr = regexm(apcm,"SCR")==1
    label var apcm_scr "Scrubber installed (=1)"
    gen apcm_cyc = regexm(apcm,"CY")==1
    label var apcm_cyc "Cyclone installed (=1)"
    gen apcm_fil = regexm(apcm,"FIL")==1
    label var apcm_fil "Bag filter installed (=1)"
    
    gen cetp = effluent_outlet=="Common E.T.P"
    label var cetp "Effluent to common treatment (=1)"
    
    gen medium = size=="Medium"
    label var medium "Capital investment Rs. 50m to Rs. 100m (=1)"
    
    gen audSamp = aud_treatment<9
    gen audTreat = aud_treatment==1
    label var audSamp "Audit sample (=1)"
    label var audTreat "Audit treatment (=1)"
    
    gen estate_dum = 0
    label var estate_dum "Located in industrial estate (=1)"
    replace estate_dum = 1 if regexm(estate,"Naroda")==1
    replace estate_dum = 1 if regexm(estate,"Odhav")==1
    replace estate_dum = 1 if regexm(estate,"Palsana")==1
    replace estate_dum = 1 if regexm(estate,"Pandesara")==1
    replace estate_dum = 1 if regexm(estate,"Sachin")==1
    replace estate_dum = 1 if regexm(estate,"Vatva")==1
    
    // Missing fuel for water-act variables
    replace coal=0 if coal==.
    replace diesel=0 if diesel==.
    
    // merge in total number of inspections
    sort plantid
    merge plantid using `totalinspections'
    assert _merge == 3
    drop _merge

    // Indicator for whether inspections insufficient
    g num_inspections_low = inspections08 < 1
    replace num_inspections_low = inspections08 < 4 if medium
    label var num_inspections_low "Inspections below prescribed (=1)"
    
    // Generate Table 1 on covariate balance
    foreach var of varlist cite_water cite_air {
    	local newlab : variable label `var'
    	label var `var' "~~`newlab'"
    }
    
    // Produce the final table
    cd "`PAPERTABLES'"
    g reg_sur = region == "SUR"
    g reg_abd = region == "ABD"
    lab var inspections08 "Number of inspections" 
    
    // local TESTVARS1 medium estate_dum sec_textiles sec_dyes cetp wwg coal diesel emission_boiler apcm_fil apcm_cyc apcm_scr
    local TESTVARS1 medium estate_dum sec_textiles sec_dyes cetp wwg emission_boiler
    local TESTVARS2 ever_pol_reading ever_above_limit n_pol_readings 
    // local TESTVARS3 showcause notice direction guarantee equipment shutoff
    local TESTVARS3 showcauses notices directions guarantees equipments shutoffs

    diffTest3 `TESTVARS1' inspections08 num_inspections_low `TESTVARS2' `TESTVARS3', by(ins_treatment) strata(reg_sur reg_abd audSamp)
    
    esttab using TableA4_Covariate_Balance.tex, ///
        title("Inspection Treatment Covariate Balance"\label{tab:"balanceAud"}) ///
    	nomtitles nonumbers collabels("Control" "Treatment" "Difference") ///
          varwidth(32) label replace booktabs width(0.9\hsize) ///
    	order("\emph{Plant Characteristics}" medium estate_dum sec_textiles sec_dyes cetp wwg emission_boiler ///
              "\emph{Regulatory Interactions}" inspections08 num_inspections_low n_pol_readings ever_pol_reading ever_above_limit showcauses notices directions guarantees equipments shutoffs) ///
    	cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") star(* 0.10 ** 0.05 *** 0.01) ///
        stats(N1 N2, labels(Observations) layout("@ @")) ///
    	addnote("\footnotesize The table tests for the balance of covariates across inspection treatment using administrative data from the regulator" ///
    		"covering the year prior to the experiment. Columns (1) and (2) show means with standard deviations in brackets." ///
    		"Column (3) shows the coefficient on treatment from regressions of each characteristic on treatment, region fixed effects," ///
    		"and an audit sample control. * p lt 0.10, ** p lt 0.05, *** p lt 0.01") nogap compress obs
    clear
    
}

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A5: Attrition in the Endline Survey
if `TableA5_EndlineAttrition' == 1 {

        use "`WORK'/endline_survey_completion"
        
	** Grouping together certain outcomes for the table
	replace endline_outcome = 7 if endline_outcome == 6
	replace endline_outcome = 6 if endline_outcome == 3 | endline_outcome == 4 | endline_outcome == 8
	replace endline_outcome = 101 if endline_outcome == 5
	g endline_attrited = (endline_outcome != 1)
	
	lab def REASONS 1 "Survey completed" ///
			6 "Plant closed" ///
			7 "Plant refused survey" ///
			101 "Other" 
	lab val endline_outcome REASONS
	lab var endline_attrited "Not in endline survey"
	lab var endline_outcome "Endline survey status"
	
	cd "`PAPERTABLES'"
	estpost tab endline_outcome
	esttab using TableA5_Endline_Attrition.tex, cells("b pct(fmt(1))") ///
		title("Attrition in the Endline Survey"\label{EndlineAttritionOutcomes}) ///
		label width(0.5\hsize) nomtitles alignment(rr) compress nogap replace mlabels(none) noobs nonum booktabs ///
		collabels("~~~~~~~~~~~N~~" "~~~~~\%~~") ///
		addnotes("\emph{Plant closed} includes plants that were permanently" ///
			 "closed (111), plants that were temporarily closed, and" ///
			 "plants where production was temporarily suspended." ///
			 "\emph{Refused survey} includes plants that were operating" ///
			 "at the time of the visit, but that refused to respond to" ///
			 "the questions in the survey." ///
			 "\emph{Other} includes plants that moved to an unknown address," ///
			 "and plants for which an incorrect address had been recorded")	
	eststo clear
        clear
	
}

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A6: Attrition by Treatment Status
if `TableA6_AttritionByTreatment' == 1 {

        use "`WORK'/endline_survey_completion.dta"
  
	di " Setting order for use in the tables"
	replace endline_outcome = 7 if endline_outcome == 6
	replace endline_outcome = 6 if endline_outcome == 3 | endline_outcome == 4 | endline_outcome == 8
	replace endline_outcome = 101 if endline_outcome == 5
	lab var endline_outcome "Endline survey status"

	tempfile AttritionData
	save `AttritionData'

	use "`WORK'/treatment_assignment_inspection.dta", clear
	drop if missing(aud_treatment)
	g audSamp=(aud_treatment!=9)
	g reg_sur = region == "SUR"
	g reg_abd = region == "ABD"
	lab var audSamp "Audit Sample"
	lab var reg_sur "Surat Region"
	lab var reg_abd "Ahmedabad Region"
	keep plantid reg_sur reg_abd ins_treatment audSamp
	
	merge 1:1 plantid using `AttritionData'
	assert _merge == 3
	drop _merge
	tab endline_outcome, g(end_outcome)
	
	lab var end_outcome1 "Survey completed" 
	lab var end_outcome2 "Plant closed" 
	lab var end_outcome3 "Plant refused survey" 
	lab var end_outcome4 "Other"
	
	cd "`PAPERTABLES'"
	diffTest3 end_outcome*, by(ins_treatment) strata(reg_sur reg_abd audSamp)
	esttab using TableA6_Attrition_By_Treatment.tex, title("Endline Attrition by Inspection Treatment Status"\label{tab:"EndlineAttritionInspection"}) ///
		nomtitles obs nonumbers collabels("Treatment" "Control" "Difference") varwidth(45) label replace booktabs width(0.7\hsize) ///
		cells("mu_1(fmt(%9.3f)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(%9.3f) par([ ])) sd_2(par([ ])) d_se(par)") star(* 0.10 ** 0.05 *** 0.01) b(star a12 fmt(%12.3g)) ///
		addnote("Columns (1) and (2) show means with standard deviations in brackets. Column (3) shows" ///
			"the coefficient on treatment from regressions of each characteristic on inspection treatment," ///
			"region fixed effects, and audit sample control. * p lt 0.10, ** p lt 0.05, *** p lt 0.01" ///
			"Reported are treatment effects, with region controls." ///
			"\emph{Plant closed} includes plants where production. was temporarily suspended, and plants that" ///
			"were temporarily or permanently closed." ///
			"\emph{Refused survey} includes plants that were in production at the time of the visit, but that" ///
			"refused to respond to the questions in the survey." ///
			"\emph{Other} includes plants that moved to an unknown address, and plants for which an incorrect" ///
			"address had been recorded") ///
		nogap compress ///
		stats(N1 N2, labels(Observations) layout("@ @") fmt(%12.0g))
	eststo clear
        clear
        
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A7: Probability of Regulator Acceptance by Treatment and Round
//   A test for the similarity of regulatory follow-up by treatment arms.
if `TableA7_FollowupByTreatment' == 1 {

    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Pull in data sets on treatment assignment and standardized pollution

    // Get inspection treatment assignment
    use "`WORK'/treatment_assignment_inspection.dta",clear
    keep plantid ins_treatment
    sort plantid
    tempfile ins_treatment
    save `ins_treatment'
    
    // To create categorical dummies for pollution readings
    //   Categorize most recent pollution reading as 0-1xlimit,
    //   1-2xlimit, 2-5xlimit, 5+ x limit.
    use "`WORK'/admin_inspection_outcomes.dta",clear
    
    // create dummies
    g maxpolcat = 0
    egen maxpol = rowmax(`allparams_std')
    
    // divide by limit for each pollutant 
    local maxlist ""
    foreach par of local allparams {
    	g `par'_rel = `par'/limit`par'
    	local maxlist "`maxlist' `par'_rel"
    }
    egen polrelmax = rowmax(`maxlist')
    replace maxpolcat = 1 if polrelmax >= 0 & polrelmax <= 1
    replace maxpolcat = 2 if polrelmax >  1 & polrelmax <= 2
    replace maxpolcat = 3 if polrelmax >  2 & polrelmax <= 5
    replace maxpolcat = 4 if polrelmax >  5 & polrelmax <  .
    
    keep plantid date maxpolcat /*maxpol*/
    sort plantid date
    
    tempfile pollutiondata
    save `pollutiondata'
    
    // Get data on GPCB actions within chains;
    //   merge treatment assignments
    use "`WORK'/admin_chains_raw",clear
    sort plantid 
    merge plantid using `ins_treatment'
    assert _merge != 1
    drop if _merge == 2
    drop _merge
    	
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Create state variables that may influence regulatory actions
    sort plantid chain date samedatesort
    
    // simplify categories for display
    clonevar actionBig_show = actionBig
    
    // Testing for correlation between likelihood of "accept" and
    //   treatment status
    sort plantid chain date samedatesort
    
    // To get firm and regulator actions in previous rounds 
    g lag1 = actionBig[_n-1] if plantid == plantid[_n-1] & chain == chain[_n-1] 
    g lag2 = actionBig[_n-2] if plantid == plantid[_n-2] & chain == chain[_n-2] 
    lab var lag1 "Firm Action in Previous Round"
    lab var lag2 "Regulator Action in Previous Round"
    
    lab def actionBigLabel 1 "Inspect" 2 "Warn" 3 "Punish" 4 "Accept" 5 "Ignore" 6 "Protest" 7 "Comply" 
    lab val lag1 actionBigLabel
    lab val lag2 actionBigLabel
    
    // To get most recent pollution reading within each chain
    sort plantid date
    merge m:1 plantid date using `pollutiondata'
    drop if _merge == 2
    drop _merge
    
    // For missing pollution data, carry forward data from previous inspection (in same chain)
    // Default for maxpolcat is 0 , which means that there was no inspection done or no reading taken/analyzed at the inspection
    sort plantid chain chain_n
    replace maxpolcat = 0 if missing(maxpolcat)
    replace maxpolcat = maxpolcat[_n-1] if maxpolcat == 0 & ///
      maxpolcat[_n-1] != 0 & maxpolcat[_n-1] != . & plantid == plantid[_n-1] & ///
      chain == chain[_n-1] 
    
    rename maxpolcat pollution 
    label def pollution 0 "Missing" 1 "0-1x" 2 "1-2x" 3 "2-5x" 4 "$>$5x"
    label val pollution pollution
    
    // Keeping only regulator actions 
    keep if actionBig == 1 | actionBig == 2 | actionBig == 3 | actionBig == 4 
    keep plantid chain date chain_n ins_treatment samedatesort actionBig lag1 lag2 pollution
    
    g accept = (actionBig == 4)
    lab var accept "Regulator Accepted"
    
    // Exclude first round, since these are all inspections
    drop if chain_n == 1
    
    // To make dummies for rounds and treatment-round interactions
    local rounds ""
    local ints ""
    foreach n in 3 5 7 {
    	g round`n' = (chain_n>`n')
    	g round`n'Xins = round`n' * ins_treatment
    	lab var round`n' 		"~~~t $>$ `n'"
    	lab var round`n'Xins 	"~~~t $>$ `n' X Inspection Treatment"
    	local rounds "`rounds' round`n'"
    	local ints "`ints' round`n'Xins"
    }
    
    // To get most recent pollution reading within each chain
    sort plantid date
    merge m:1 plantid date using `pollutiondata'
    drop if _merge == 2
    drop _merge
    		
    tab pollution, g(pollutioncat_)		
    local polcats ""
    local polints ""
    
    forv n = 2/5 /* Pollution categories are mutually exclusive, so exclude 1st category (missing) */ {
    	g pollutionint_`n' = pollutioncat_`n' * ins_treatment
    	
    	local label : variable label pollutioncat_`n'
    	local label = subinstr("`label'","pollution==","",.)
    	lab var pollutioncat_`n' "~~~~`label'"
    	lab var pollutionint_`n' "~~~~`label' X Inspection Treatment" 
    	
    	local polcats "`polcats' pollutioncat_`n'" 
    	local polints "`polints' pollutionint_`n'" 
    }
    
    local polcats2 = subinstr("`polcats'","pollutioncat_2","",.)
    local polints2 = subinstr("`polints'","pollutionint_2","",.)
    
    // To get firm and regulator actions in previous rounds 
    forv m = 1/2 {
    	tab lag`m', g(lag`m'_)
    	local lag`m's ""
    	forv n = 2/3 /* Three categories are mutually exclusive, so dropping the first (ignore and inspect) for consistency */ {
    		local lag`m's "`lag`m's' lag`m'_`n'" 
    	}
    }
    
    lab var lag1_1 "~~~~Firm: Ignore, lag 1"
    lab var lag1_2 "~~~~Firm: Protest, lag 1"
    lab var lag1_3 "~~~~Firm: Comply, lag 1"
    lab var lag2_1 "~~~~Inspect, lag 1"
    lab var lag2_2 "~~~~Warn, lag 1"
    lab var lag2_3 "~~~~Punish, lag 1"

    
    //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    // Estimate regressions of regulatory action accept on state variables,
    //   treatment assignment and interactions.  Test for the joint significance
    //   of the inspection treatment and interactions.
    
    * COLUMN (1) 
    reg accept ins_treatment, cluster(plantid)
    su accept if ins_treatment == 0 
    estadd scalar cmean = r(mean)
    test ins_treatment==0
    estadd scalar Fpval = r(p)
    eststo, title("")
    
    * COLUMN (2) 
    reg accept ins_treatment `rounds' `ints', cluster(plantid)
    su accept if ins_treatment == 0
    estadd scalar cmean = r(mean)
    test (ins_treatment==0) (round3Xins=0) (round5Xins=0) (round7Xins=0)
    estadd scalar Fpval = r(p)
    eststo, title("")
    		
    * COLUMN (3)
    reg accept ins_treatment `polcats', cluster(plantid)
    su accept if ins_treatment == 0
    estadd scalar cmean = r(mean)
    test ins_treatment==0
    estadd scalar Fpval = r(p)
    eststo, title("")
    
    * COLUMN (4) 
    reg accept ins_treatment `polcats' `polints', cluster(plantid)
    su accept if ins_treatment == 0
    estadd scalar cmean = r(mean)
    test (ins_treatment==0) (pollutionint_2=0)  (pollutionint_3=0) ///
       (pollutionint_4=0)  (pollutionint_5=0)
    estadd scalar Fpval = r(p)
    eststo, title("")
    
    * COLUMN (5) 
    reg accept ins_treatment `rounds' `lag1s' `lag2s' `polcats', cluster(plantid)
    su accept if ins_treatment == 0 
    estadd scalar cmean = r(mean)
    test ins_treatment==0
    estadd scalar Fpval = r(p)
    eststo, title("")
    
    * COLUMN (6) 
    reg accept ins_treatment `rounds' `ints' `lag1s' `lag2s' `polcats2' `polints2' if pollution != 0, cluster(plantid)
    su accept if ins_treatment == 0
    estadd scalar cmean = r(mean)
    test (ins_treatment==0) (round3Xins=0) (round5Xins=0) (round7Xins=0) ///
         (pollutionint_3=0) (pollutionint_4=0) (pollutionint_5=0)
    estadd scalar Fpval = r(p)
    eststo, title("")
    
    cd "`PAPERTABLES'"
    esttab using TableA7_Followup_By_Treatment.tex, ///
    	varwidth(35) label wrap se num nomtitles booktabs compress ///
        longtable replace ///
    	title("Probability of Regulator Acceptance by Treatment"\label{ChainActionsTreatmentPol}) ///
    	addnote("Does not include region fixed effects. Standard effects clustered at plant level." ///
    		"Omitted actions are Ignore (for Regulator) and Inspect (for Firm)." ///
    		"Omitted pollution reading for column (6) is No Pollution Reading Taken.") ///
    	stats(Fpval cmean N, fmt(3 3 0) ///
              labels("Treatment F-test p-value" "Inspection control mean" "Observations")) ///
              varlabels(_cons "~~~Constant") ///
    	star(* 0.10 ** 0.05 *** 0.01) ///
    	order("ins_treatment" ///
    	      "\emph{Period}" _cons `rounds' ///
    	      "\emph{Period X Treatment}" `ints' ///
    	      "\emph{Lagged regulatory actions}" `lag2s' ///
    	      "\emph{Lagged plant actions}" `lag1s' ///
    	      "\emph{Last pollution reading}" `polcats' ///
    	      "\emph{Pol Reading X Treatment}" `polints') 
    eststo clear

}



//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A8: Endline Pollution and Compliance on Letter Treatment
if `TableA8_LetterTreatment' == 1 {
  
use "`WORK'/endline_pollution_readings",clear
	g reg_sur = region=="SUR"
	g reg_abd = region=="ABD"

merge m:1 plantid using "`WORK'/treatment_assignment_letters"
	drop if _merge==2
	g cca_treatment=(_merge==3)
	lab var cca_treatment "CCA Treatment (=1)"
        tab cca_treatment
			
// Dependent variable standardized just by the backcheck sd
g pol_std_zero = pol/sd

// Creating audit and inspection sample and treatment controls
g aud_sample = aud_treatment!=9
label var aud_sample "Audit sample (=1)"
replace aud_treatment = 0 if aud_treatment==9

g audXins = aud_treatment*ins_treatment
label var audXins "Audit X inspection treatment (=1)"
	
g insXaudsample = ins_treatment * aud_sample
lab var insXaudsample "Inspection treatment X Audit sample (=1)"

g insXcca = ins_trea * cca_tr
	lab var insXcca "Inspection treatment X CCA treatment (=1)"

eststo clear
xi: reg pol_std_zero ins_treatment cca_treatment insXcca reg_sur reg_abd, cluster(plantid)
	qui sum pol_std_zero if cca_treatment==0 & ins_treatment == 0
	estadd scalar cmean = r(mean)
	eststo, title("Pollution"):

xi: reg comply ins_treatment cca_treatment insXcca reg_sur reg_abd, cluster(plantid)
	qui sum comply if cca_treatment==0 & ins_treatment == 0
	estadd scalar cmean = r(mean)
	eststo, title("Compliance"):

cd "`PAPERTABLES'"
esttab using TableA8_Letter_Treatment.tex, ///
	title("Endline Pollution on Inspection and CCA Treatment"\label{PollutionTreatmentCCA}) ///
	varwidth(32) label se mtitles("Pollution" "Compliance") nonum booktabs width(0.8\hsize) replace ///
	addnote("Pollution standardized by backcheck standard deviation." "Includes audit treatment and treatment interaction controls," "and year and region fixed effects") /// 
	drop(reg_sur reg_abd _cons)  ///
	stats(cmean N, fmt(3 0) labels("Inspection and CCA control mean" "Observations")) ///
	star(* 0.10 ** 0.05 *** 0.01)  
eststo clear	
	
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A9: Placebo Check of Alternate Compliance Thresholds
if `TableA9_PlaceboCompliance' == 1 {
	
	use "`WORK'/endline_pollution_readings",clear
	g reg_sur = region=="SUR"
	g reg_abd = region=="ABD"

	g aud_sample = aud_treatment!=9
	replace aud_treatment = 0 if aud_treatment==9
	g audXins = aud_treatment*ins_treatment
	label var aud_sample "Audit sample (=1)"
	label var audXins "Audit X inspection treatment (=1)"

	g pol_limit = pol/limit
	lab var pol_limit "Pollution As A Multiple of the Pollution Limit"
	
	drop comply
	foreach n in 1 2 5 10 {
		g comply`n' = pol_limit <= `n'
		lab var comply`n' "Endline reading <`n'x limit"
		xi: reg comply`n' ins_treatment aud_treatment audXins aud_sample reg_sur reg_abd, cluster(plantid)
			qui sum comply`n' if aud_treatment==0 & ins_treatment == 0
			estadd scalar cmean = r(mean)
			eststo, title("`n'x Limit"):
	}
	
	cd "`PAPERTABLES'"
	esttab using TableA9_Placebo_Compliance.tex, ///
		title("Placebo Check of Alternate Compliance Thresholds"\label{ComplianceTreatmentLimits}) ///
		varwidth(32) label se mtitles nonum booktabs width(1.0\hsize) replace ///
		addnote("Includes audit treatment and treatment interaction controls" ///
                        " and year and region fixed effects." ///
			"Compliance is defined as pollution being below N times the limit," ///
                        "with N being 1, 2, 3, 5 and 10 respectively." ///
			"Pollution standardized by backcheck standard deviation.") /// 
		drop(reg_sur reg_abd _cons aud_sample)  ///
		stats(cmean N, fmt(3 0) labels("Inspection and audit control mean" "Observations")) ///
		star(* 0.10 ** 0.05 *** 0.01)  
}


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Table A10: Regulatory Targeting on Unobserved Pollution in the Control Group
if `TableA10_TargetingOnUnobs' {

	// get plantid status 
	use "`WORK'/treatment_assignment_inspection", clear
	keep plantid cetp_status ins_treatment
	rename cetp_status cetp
	sort plantid 
	tempfile cetpstatus
	save `cetpstatus'
	
	use "`WORK'/admin_pollution_readings", clear
	sort plantid
	merge m:1 plantid using `cetpstatus'
	keep if _merge == 3
	drop _merge

	// merge in limits and make polbin
	replace cetp = -97 if par == "nox" | par == "so2" | par == "spm"
	sort par cetp
	merge par cetp using "`WORK'/admin_pollution_limits"
	drop if _merge == 2
	drop _merge
	g max_pol_std_limit = pol/limit
	tempfile readings
	save `readings'

	use "`WORK'/endline_plant_survey", clear
	keep plantid _06a_survey_date_D _06b_survey_date_M _06c_survey_date_Y
	g endline_date = mdy(_06b_survey_date_M, _06a_survey_date_D,  _06c_survey_date_Y)
		lab var endline_date "Date of endline survey"
		format %td endline
	keep plantid endl
	tempfile endline_date
	save `endline_date'

	// Inspections
	use "`WORK'/admin_chains_raw", clear
	keep if actionBig==1 & imputed ==0
	keep plantid date
	ren date inspection_date
	merge m:1 plantid using `endline_date'
		drop if _m == 1
		drop _m
		
	drop if insp>endline
	
	loc lags = 6  /* Number of past inspections to keep */
	
	bys plantid (inspection_date): keep if _n > _N-`lags'
	
	forv i = 1/`lags' {
		loc j = `i' - 1
		bys plantid (inspection_date): g inspection_date_lag`i' = inspection_date if _n==_N -`j'
		lab var inspection_date_lag`i' "Inspection Date, lag `i'"
	}
		sort plantid inspection_date
		format %td inspection_date_l* 
		
	ren inspection_date date
	drop endline_date
	** Bring in pollution readings
	merge 1:m plantid date using `readings'
		drop if _m==2
		g pol_read = _m==3
	
	collapse (max) max_pol_std_lim (firstnm) inspection_d* pol_re, by(plantid date)
	forv i = 1/`lags' {
		g plag`i' = max_pol if inspection_date_lag`i'~=.
		g read_lag`i' = pol_read if inspection_date_lag`i'~=.
	}
	collapse (firstnm) inspection* plag* read*, by(plantid)
	
	tempfile lag_pol
	save `lag_pol'

// Assignments and regions	
	use "`WORK'/treatment_assignment_inspection", clear
	keep plantid  ins_treat aud_el size aud_treatment cetp_status wwg sec_* region coal lign
	g size2 = size=="Medium"
	g wwg100 = wwg>100 
	g coallignite = (coal == 1 | lignite == 1)
	label var coallignite "Coal or lignite as fuel (=1)"
	sort plantid
	drop if mi(ins_treat)
	tempfile assignment
	save `assignment'

// Get endline date
use "`WORK'/endline_plant_survey", clear
keep plantid _06a_survey_date_D _06b_survey_date_M _06c_survey_date_Y
g endline_date = mdy(_06b_survey_date_M, _06a_survey_date_D,_06c_survey_date_Y)
format %td endline_date
drop _06*
tempfile endline_date
save `endline_date'	
	
// Chain outcomes
	use "`WORK'/admin_chains_raw", clear
	g punish = actionBig==3
	g warn = actionBig==2
	drop comply
	g comply = actionBig==7
	g inspect = actionBig==1
	
	merge m:1 plantid using `endline_date'
	keep if _merge==3
	drop _m
	
	drop if date>endline_date
	
	forv i = 1/3 {
		foreach j in "comply" "warn" "punish" "inspect" {
			g `j'_y`i' = `j' ==1 & date> (endline_date - (`i'*365))
			lab var `j'_y`i' "`j's in `i' years before endline"
			tab `j'_y`i'
		}
	}
	collapse (sum) punish_* comply_* warn_* inspect_*, by(plantid) 
	
	tempfile chain_outcomes
	save `chain_outcomes'
	
// Recent inspections
	use "`WORK'/admin_inspection_received.dta", clear
	keep plantid inspections2007 inspections2008 inspections2009 inspections2010 ///
		inspections2011 inspectionstotal_scaled
	tempfile past_inspections
	save `past_inspections'

// Get endline pollution reading
use "`WORK'/endline_pollution_readings",clear
		g reg_sur = region=="SUR"
		g reg_abd = region=="ABD"

g endline_pol_mean = pol/limit
g endline_pol_max = pol/lim

g endline_pol_restricted_mean = pol/limit if inlist(par, "bod", "cod", "tds", "spm")
g endline_pol_restricted_max = pol/limit if inlist(par, "bod", "cod", "tds", "spm")  

collapse (mean) endline_pol_mean endline_pol_restricted_mean (max) endline_pol_restricted_max endline_pol_max, by(plantid)
tempfile pol_end
save `pol_end'

// Pollution readings
use "`WORK'/admin_chains_raw", clear
keep if actionBig==1
keep if imputed==0
keep plantid date
tempfile inspections_chains
save `inspections_chains'

// Inspection Reports
	// get plantid status 
	use "`WORK'/treatment_assignment_inspection", clear
	keep plantid cetp_status ins_treatment
	rename cetp_status cetp
	sort plantid 
	tempfile cetpstatus
	save `cetpstatus'
	
	use "`WORK'/admin_pollution_readings", clear
	sort plantid
	merge m:1 plantid using `cetpstatus'
	keep if _merge == 3
	drop _merge

	// merge in limits and make polbin
	replace cetp = -97 if par == "nox" | par == "so2" | par == "spm"
	sort par cetp
	merge par cetp using "`WORK'/admin_pollution_limits"
	drop if _merge == 2
	drop _merge
	g max_pol_std_limit = pol/limit
	g mean_pol_std_limit = pol/limit
	
	collapse (max) max_pol_std_limit (mean) mean_, by(plantid date)
	lab var max_pol_std_limit "Max Standardized Pollution, from inspection"
	lab var mean_pol_std_limit "Mean Standardized Pollution, from inspection"

merge 1:1 plantid date using `inspections_chains'
drop if _merge==1
g pol_read = _merge==3
	lab var pol_read "Pollution reading taken (=1)"
drop _merg
ren date inspection_date

tempfile reports
save `reports'

// Merge together
use `endline_date', clear
merge 1:m plantid using `reports' 
	drop if _m ==2
	drop _merge
keep if (inspect-endline_date<=365 & inspect>endline_date)	
	
merge m:1 plantid using `endline_date'
	drop _merge
merge m:1 plantid using `pol_end'
	g no_endline_sample = _merge==1
		lab var no_endline_sample "Pollution reading not taken in endline (=1)"
	drop _merge
merge m:1 plantid using `assignment'
	keep if _merge==3
	drop _merge
merge m:1 plantid using `chain_outcomes'
	foreach v of varlist punish_y1-inspect_y3 {
		replace `v' = 0 if _m ==1
	}
	drop _m
	
	merge m:1 plantid using `lag_pol'
	g no_inspection_lag1 = _merge==1
	g no_inspection_lag2 = mi(inspection_date_lag2)
	drop if _m==2
	drop _m

	forv i = 1/`lags' {
		g p`i'_1 = mi(plag`i') & !mi(inspection_date_lag`i')
		g p`i'_2 = plag`i'<1 & !mi(inspection_date_lag`i')
		g p`i'_3 = plag`i'>=1 & plag`i'<2 & !mi(inspection_date_lag`i')
		g p`i'_4 = plag`i'>=2 & plag`i'<5 & !mi(inspection_date_lag`i')
		g p`i'_5 = plag`i'>=5 & !mi(inspection_date_lag`i') & !mi(plag`i')
	}
	g no_lags = no_inspection_lag1
	g one_lag = no_inspection_lag1==0 & no_inspection_lag2==1
		lab var one_lag "Only one past inspection on record (=1)"	
	
// Endline pollution bins
foreach m in "mean" "max" {	
	g p_1_`m' = no_endline_sample
	g p_2_`m' = endline_pol_`m'<1
	g p_3_`m' = endline_pol_`m'>=1 & endline_pol_`m'<2
	g p_4_`m' = endline_pol_`m'>=2 & endline_pol_`m'<5
	g p_5_`m' = endline_pol_`m'>=5 & !mi(endline_pol_`m')
	g p_`m' =.
		lab var p_`m' "Endline Pollution Bin"
		lab var p_1_`m' "`m' Endline Pollution Reading Not Taken (=1)"
		lab var p_2_`m' "`m' Endline Pollution $<$1x (=1)"
		lab var p_3_`m' "`m' Endline Pollution $\in$ $[$1x,2x) (=1)"
		lab var p_4_`m' "`m' Endline Pollution $\in$ $[$2x,5x) (=1)"
		lab var p_5_`m' "`m' Endline Pollution $\geq$5x (=1)"
	
	forv i = 1/5 {
		replace p_`m' = `i' if p_`i'_`m' == 1 
	}
}

	collapse (count) inspection_date (sum) pol_read (mean) max_po mean_po (firstnm) ///
		endline_pol_max p_* ins_tr punish_y1-inspect_y3 ///
		aud_el size2 wwg100 aud_treatment cetp_status wwg sec_* coalli region p1_1-p`lags'_5 one_lag no_lags ///
		plag*, by(plantid)
	g reg_abd = region=="ABD"
	g reg_sur = region=="SUR"		
	g read_rate = pol_read/inspection
	ren inspection_d inspections
	format %4.0f inspection
	
		// regressors
	/* Firm and abatement cost characteristics */ loc chars size2 sec_tex sec_dy wwg100 coallig
	/* Region Fixed Effects */ loc reg_fe reg_abd reg_sur
	/* Treatment variables */ loc treat ins_treat aud_treat
	/* Lagged regulatory actions */ loc actions punish_y1 comply_y1 warn_y1
	label var punish_y1 "Punish's in 1 year before endline"
	label var comply_y1 "Comply's in 1 year before endline"
	label var warn_y1 "Warn's in 1 year before endline"
	/* Lagged regulatory pollution readings */ loc lag_insp p1_*

gen p_bin = 0 
replace p_bin = 1 if p_2_max==1
replace p_bin = 2 if p_3_max==1
replace p_bin = 3 if p_4_max==1
replace p_bin = 4 if p_5_max==1
label var p_bin "Endline pollution bin"
        
// Added Nov 23 to fix omitted dummy issue AND add inspections x audit dummy AND run version limiting to control group
        
		eststo clear
		local treat aud_treatment 

		keep if ins_treat==0
		eststo clear
		loc k ""
		foreach r in "inspections" /*"pol_read"*/ {	
			foreach i in /* "mean" */ "max" {
				foreach j in "`reg_fe' " "`treat' " "`actions' " "`lag_insp' " {
					loc k `k' `j'
					di "`k'"
					reg `r' p_bin p_1_`i' size2 sec_tex sec_dy wwg100 coallig `k', robust 
						eststo
						sum `r'
						estadd scalar Smean = r(mean)
				}
			}
		}
		foreach r in "inspections" /*"pol_read"*/ {	
			foreach i in /* "mean" */ "max" {
					reg `r' p_1_`i' p_3_`i' p_4_`i' p_5_`i' `chars' `reg_fe' `actions' `treat' `lag_insp', robust
						eststo
						test p_1_`i' p_3_`i' p_4_`i' p_5_`i'
							*Changed p_2 (lowest category) to p_1 (no reading)
							*Now p_2 is the omited category and we'll get rid of p_1 as a reported control in the table
						estadd scalar pval = r(p)
						sum `r'
						estadd scalar Smean = r(mean)
						
						//Test for Nick, added Nov 21, 2016
						reg `r' p_1_`i' p_3_`i' p_4_`i' p_5_`i' `chars' `reg_fe' `actions' `treat', robust
						test p_1_`i' p_3_`i' p_4_`i' p_5_`i'
						
						gen plag_nomi=plag1
						replace plag_nomi=0 if plag1==.
						reg endline_pol_max plag_nomi p1_1
						
						gen mi = (endline_pol_max==.)
						gen temp=endline_pol_max 
						replace temp=0 if endline_pol_max==.
						reg temp mi plag_nomi p1_1
							
						drop mi temp plag_nomi
			}
		}
		label var coallignite "Coal or lignite as fuel (=1)"
		lab var size2 "Medium size industry (=1)"
		lab var sec_tex "Textiles (=1)"
		lab var sec_dyes "Dyes (=1)"
		lab var wwg100 "Waste water generated $>$ 100 kl/day (=1)"
		lab var reg_sur "Region: Surat (=1)"
		lab var reg_abd "Region: Ahmedabad (=1)"
		lab var ins_treat "Inspections treatment (=1)"
		lab var aud_treat "Audit treatment (=1)"
		esttab using "`PAPERTABLES'/TableA10_Regulatory_Targeting.tex", ///
		varwidth(32) wrap label se compress nogap replace nomtitles ///
		addnote("Robust standard errors in parentheses. Pollution bin is a categorical variable that" ///
		"takes the value of 1 if pollution is in the smallest bin, 2 in the next bin, 3 in the next, and 4 in the largest bin." ///
		"For firms with no pollution readings, pollution bin is 0.  Each specification also includes a dummy for having no" /// 
		"pollution reading." ///
		"Column 5 separates pollution bin into a series of dummies.  The omitted dummy is having a pollution reading" ///
		" in the lowest bin.  A dummy for having no pollution reading is also included." ///
		"The F test is for the joint significance of these endline pollution bin dummies." ///
		"Plant characteristics include dummies for size, use of coal or lignite as fuel," ///
		"high waste water generated, dye sector, textile sector,  and region." ///
		"Treatment includes dummies for audit, inspections, and an interaction between the two." ///
		"Recent regulatory actions include the number of punishes, complies, and warns in year before endline." ///
		"Recent pollution readings include dummies for pollution bins at the most recent inspection before endline.") ///
		stats(Smean pval r2 N,labels("Mean" "F stat p-value" "R2" "Observations")) ///
		indicate("Plant characteristics = reg_sur reg_abd size2 coallignite wwg100 sec_textiles sec_dyes" ///
		"Audit treatment = aud_treatment" ///
		"Recent regulatory actions = punish_y1 comply_y1 warn_y1" ///
		"Recent pollution readings = p1_1 p1_2 p1_3 p1_4 p1_5") ///
		star(* 0.10 ** 0.05 *** 0.01)  booktabs	
	
}

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// End
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
