function [ Vs, vas, Pas ] = backsolveRound( thetaUP, sigma, kappa, ...
                               beta, S, Pras, fPsas, fRsas, tC, tp, ...
                               Vsf2, payoff )
% backsolveRound.  Solve values of each state and action in a round, taking
%   as given the values of rounds t+1 and t+2.
% 
% INPUT:
%   S     - |aR| X |aP| X |pol| matrix of all possible states, in 2-D
%   Pras  - |S| X |aR| X |sRt|  matrix of predicted probabilities 
%           for each action of the regulator conditional on the state.
%   fPsas - |S| X |S| X |aP| state transition matrix (deterministic).  
%   fRsas - |S| X |S+1| X |aR| X |sRt| state transition matrix (stochastic,
%           and dependent on the time dimension of state).
%   tC      - Cut-offs for discrete time dummies.
%   tp      - round being simulated, tp=1,...,6 for plant moves with t=2*tp
%   thetaUP - Plant's utility parameters.
%   beta    - Plant's discount factor.
%   sigma   - Scaling factor for variance of unobserved action shocks.
%   Vsf2    - |S| X 1 values for each state the next round when the plant
%             has the chance to move
%   payoff  - choice of per-round payoff function when regulator moves
%
% OUTPUT:
%   Vs     - |S| X 1 values for each state, ex ante before an action is 
%            taken in a given round.
%   vas    - |S| X |aP| values for each possible action and state, in a
%            given round
%   Pas    - |S| X |aP| X T/2 probabilities for each action cond. on state.

%% Initialize values to zero
NS  = size(Pras,1);
NaP = size(fPsas,3);
vas = zeros(NS,NaP);
Vs  = zeros(NS,1);

% Time index of the round in question
%ti  = find( tp*2+1 > tC, 1, 'last' ) + 1;
ti  = int32( sum(tp*2+1 > tC) + 1 );

% Whether state transition after regulator moves depends on time
% tif = ti;  % If fRsas to depend on time, allow its own time index
tif = 1;     % If it is not to, use first panel for all

% Per-period payoff function when regulator moves
%   1 - Penalty on punishment, constant 
%   2 - Penalty on punishment, function of pollution
%   3 - Penalty on punishment, constant + Bribe on inspection, constant
%   4 - Penalty on punishment, constant + Bribe on pollution, variable
if nargin < 12
    payoff = 2;
end

%% Create |S| X |aP| values for profit today, tomorrow and the day after

% t: Today's one-period profit, when the plant moves
%   Profit only non-zero if plant chooses comply (action 1).  
pit = [ -kappa zeros(1,NaP-1) ]; % Depends on action choices
pit = pit( ones(NS,1), : );

% t+1: Tomorrow's one-period profit, when the regulator moves
%   Profit only non-zero if regulator chooses punish (action 1). 
%   Calculate profit and take expectation today over tomorrow's states
%   using the state transition matrix after the plant moves.

    % Payoff I: Punishment for three highest pollution readings
    if payoff == 1
        pif1 = - Pras(:,1,ti) .* ( thetaUP(1) );
    elseif payoff == 2
        pif1 = - Pras(:,1,ti) .* ( S(:,end-2:end) * thetaUP' );     

    % Payoff II: Punishment constant across pollution readings
    %   Pay bribe if inspection, high pollution and no compliance
    elseif payoff == 3
        pif1 = - Pras(:,1,ti) .* ( thetaUP(1) ) ...
               - Pras(:,3,ti) .* (S(:,4)==0) .* ...
                                 ( S(:,end-2:end)*thetaUP(2*ones(3,1))' );
    elseif payoff == 4                         
        pif1 = - Pras(:,1,ti) .* ( thetaUP(1) ) ...
               - Pras(:,3,ti) .* (S(:,4)==0) .* ...
                                 ( S(:,end-2:end)*thetaUP(2:end)' ); 
    end
   
pif1 = [ fPsas(:,:,1)*pif1 fPsas(:,:,2)*pif1 ]; % Integrate payoff over aP

% t+2: Next day's value, when the plant moves again
%   Sum value of each action today over t+1 state and action and over value
%     of t+2 states.
%   Vasf1 - Value to plant of t+2 state expected in t+1, for reg. actions
%   Vsf1  - Value to plant of t+2 state expected in t+1, over reg. actions
%   fRsas - How regulatory action affects future state
%   Vsf2  - Value of future state
%   fPsas - What state we end up in tomorrow
%   Pras  - Probability of regulatory action in different states
Vasf1 = [ fRsas(:,1:end-1,1,tif)*Vsf2 ...
          fRsas(:,1:end-1,2,tif)*Vsf2 ...
          fRsas(:,1:end-1,3,tif)*Vsf2 ]; 
Vsf1  = sum( Pras(:,1:3,ti) .* Vasf1, 2 );
vasf2 = [ fPsas(:,:,1)*Vsf1 fPsas(:,:,2)*Vsf1 ];

% Sum the three periods into today's action-specific value.  Then sum 
%   across values using the structure of shocks for ex ante value.
vas    = pit + beta*pif1 + beta^2*vasf2;
exvas  = exp( vas / sigma );
Sexvas = sum( exvas, 2 );
Pas    = exvas ./ Sexvas(:,ones(1,size(pit,2)));

Pas( isnan(Pas) ) = 1; % Correct NaN probabilities as a result of large 
                       %   exponentials for one value or the other
                      
% Calculate total ex ante value 
%   Either including action shock / unobserved state variable in value 
%   or not including it.
% Eeas   = sigma * ( 0.5772 - log(Pas) );  % Expectation of action shock
% Vs     = sum( Pas .* ( vas + Eeas ), 2 );
Vs     = sum( Pas .* vas, 2 );

if any( Pas(:) < 0 ) || any( Pas(:) > 1 )
    err = MException('ResultChk:OutOfRange',...
                     'Probability outside of expected range');
    throw(err)
end

end
