function [ Vs, vas, Pas, Vs_c, Vs_h, vas_c, vas_h ] = ...
    backsolveValuesSplit( thetaUP, sigma, kappa, ...
                           beta, S, Pras, fPsas, fRsas, tC, payoff )
% backsolveValues.  Solve values of every possible state using backwards
%   induction from values of terminal states.
% 
% INPUT:
%   S     - |aR| X |aP| X |pol| matrix of all possible states, in 2-D
%   Pras  - |S| X |aR| X |sRt|  matrix of predicted probabilities 
%           for each action of the regulator conditional on the state.
%   fPsas - |S| X |S| X |aP| state transition matrix (deterministic).  
%   fRsas - |S| X |S+1| X |aR| X |sRt| state transition matrix (stochastic,
%           and dependent on the time dimension of state).
%   tC      - Cut-offs for discrete time dummies.
%   thetaUP - Plant's utility parameters for being punished
%   sigma   - Scaling factor for variance of unobserved action shocks.
%   kappa   - Plant's cost of compliance.
%   beta    - Plant's discount factor.
%
% OUTPUT:
%   Vs     - |S| X T/2 values for each possible state
%   vas    - |S| X |aP| X T/2 values for each possible action and state.
%   Pas    - |S| X |aP| X T/2 probabilities for each action cond. on state.

% Last round observed in any chain in the data
capT = 35; 

% Initialize action-specific values to zero
T    = floor(capT/2);
NS   = size( Pras,1);
NaP  = size(fPsas,3);
vas  = zeros(NS,NaP,T);
Pas  = zeros(NS,NaP,T);
Vs   = zeros(NS,  1,T);

% Values split out by abatement cost and regulatory penalties
vas_c = zeros(NS,NaP,T);
vas_h = zeros(NS,NaP,T);
Vs_c  = zeros(NS,  1,T);
Vs_h  = zeros(NS,  1,T);

% t = T   : Regulator move, always accept.  All values zero for plant.

% t = T-1 : Plant move.  Value of each action equal to current profit.
%          1 = Comply, 2 = Protest, 3 = Ignore
%          1 = Comply, 2 = Not comply (Protest/Ignore)
pit        = [ -kappa zeros(1,NaP-1) ]; % Depends on action choices
vas(:,:,T) = pit( ones(NS,1), : );
exvas      = exp( vas(:,:,T) / sigma );
Sexvas     = sum( exvas, 2 );
Pas(:,:,T) = exvas ./ Sexvas(:,ones(1,size(pit,2)));

% Calculate total value either including action shock / unobserved state 
%   variable in value or not
% Eeas       = sigma * ( 0.577 - log(Pas(:,:,T)) ); % E(action shock|action)
% Vs(:,:,T)  = sum(  Pas(:,:,T) .* ( vas(:,:,T) + Eeas ), 2); 
Vs(:,:,T)  = sum(  Pas(:,:,T) .* vas(:,:,T), 2);

Vs_c(:,:,T) = Vs(:,:,T);
Vs_h(:,:,T) = 0;

% t = T-2 : Regulator move, as in data.

% t = T-3 . . 2 : Plant move.  Value of each action equal to present value,
%          t+1 value when regulator moves, and t+2 value when the plant
%          moves again.  
for t = (capT-3)/2:-1:1
    [ Vs(:,:,t), vas(:,:,t), Pas(:,:,t), ...
      Vs_c(:,:,t), Vs_h(:,:,t), vas_c(:,:,t), vas_h(:,:,t) ] = ...
        backsolveRoundSplit( thetaUP, sigma, kappa, beta, ...
                             S, Pras, fPsas, fRsas, tC, t, ...
                             Vs(:,:,t+1), Vs_c(:,:,t+1), Vs_h(:,:,t+1), ...
                             payoff );
end

end