%% ========================================================================
%          Dynamic estimation of penalty stage
%%=========================================================================

%   This file reads the data on chained interactions between the regulator
%   and regulated plants and estimates a dynamic model of plant action
%   choice to recover the parameters of regulatory penalties. 

%   The output of this analysis used in the paper is
%     Table 5: Estimates of Plant Utility Parameters
%     Figure 4: Value of Environmental Regulation to Plants
%
%   The steps below are:
%      1. Read and organize the chained interactions
%      2. Demonstrate the estimation of transition matrices and policy
%         functions
%      3. Draw bootstrap samples at the chain level, where a chain is a set
%         of linked interactions between regulators and plants.
%      4. Use bootstrap samples to estimate penalty parameters.
%      5. Create table and figure of output from the estimates (4.).


%% ========================================================================
%%============================= Data prep =================================
%%=========================================================================

%% Load data on chains

% Path to data
clear;
cd ../../;
root = pwd;

dataPath   = [root,'/data/02_penalty_stage'];
modelPath  = [root,'/code/02_penalty_stage'];
figurePath = [root,'/output/figures'];
tablePath  = [root,'/output/tables'];

% Chains estimation data file, most recent
cd(dataPath);
file   = 'chains_estimation.csv';
chains = dlmread(file,',',1,0);
vnames = textread(file,'%s',size(chains,2),'delimiter',',');
cd(modelPath)

ids        = chains(:,1:3);  % Chain, plant, chain within plant
t          = chains(:,4);    % Round within game
plantMove  = mod(t,2)==0;    % Dummy for plant moves
regulMove  = ~plantMove;     % Dummy for regulator moves
regulMove3 = ~plantMove & t ~= 1; % Omit first round, where regulator
                                  % always chooses inspect by construction
date       = chains(:,5);    % Date of action
a          = chains(:,6:10); % Current; Plant l1, l2; Regulator l1, l2
p          = chains(:,11);   % Pollution bins
gamma      = [ chains(:,14) chains(:,16:17) ]; % Covars: med, wwg, coal
revenue    = chains(:,18);   % Revenue in INR millions


%% Put action vectors in a form useful for estimation 
% Actions of the parties in the input data
%   Regulatory actions
%     1 = Inspect
%     2 = Warn
%     3 = Punish
%     4 = Accept
%   Plant actions
%     5 = Ignore
%     6 = Protest
%     7 = Comply 
%   Regulatory actions 

% Action for plant, simplified for CCP estimation such that omitted
%   category in estimation is last (as required by mnrfit).
%  1 = Comply
%  2 = Protest
%  3 = Ignore
aP              = zeros(size(a(:,1)));
aP(plantMove,:) = 8 - a(plantMove,1); 
aP(plantMove & aP==3,:) = 2; % Recode (Ignore / Protest) as one action
fprintf('\nPlant moves\n');
tabulate(aP(plantMove));

% Action for regulator, simplified for CCP estimation such that omitted
%   category in estimation is last (as required by mnrfit).
%  1 = Punish
%  2 = Warn
%  3 = Inspect
%  4 = Accept
aR              = zeros(size(a(:,1)));
aR( a(:,1)==1 ) = 3;
aR( a(:,1)==2 ) = 2;
aR( a(:,1)==3 ) = 1;
aR( a(:,1)==4 ) = 4;
fprintf('\nRegulator moves\n');
tabulate(aR(regulMove));

%% Create state matrix for each observation
% State core matrix
%   <Prior action of regulator> <Prior action of plant> <Pollution>
%   Where each variable is represented in binary form as below:
%   Regulator = <d=1(Punish), d=1(Warn),    d=1(Inspect)>
%   Plant     = <d=1(Comply), d=1(Protest or Ignore)>
%   Pollution = <d=0 . . . d=4>
s = [  a(:,4)==3  a(:,4)==2  a(:,4)==1   ...
       a(:,2)==7  (a(:,2)==6|a(:,2)==5)  ...  % If two plant actions
       dummyOut( p ) ];
% a(:,2)==7  a(:,2)==6  a(:,2)==5   ...    % If three plant actions
       
uniqueStates = unique( s, 'rows' );
uniqueStates = sortrows( uniqueStates, -[1:size(uniqueStates,2)] );
stateNames = {'aR_l1 = Punish','aR_l1 = Warn','aR_l1 = Inspect',  ...
              'aP_l1 = Comply','aP_l1 = Ignore',...
              'p = null','p < 1','1 < p < 2','2 < p < 5','5 < p'};
         
% 'aP_l1 = Comply','aP_l1 = Protest','aP_l1 = Ignore',...
          
% Note that Accept is a valid action but never appears in the state
%   when a player is deciding, since if the Regulator accepts the game 
%   ends. State will additionally include <t> for both parties and 
%   <kappa> for plant, measuring indiosyncratic costs of abatement.
       
% Time component of state
sPt = [ true(size(t)) t>3 t>5 t>7 ];
sRt = [ true(size(t)) t>3 t>5 t>7 ];
tC  = [ 3 5 7 ];

% Tabulate unique states observed in data          
file = 'uniqueStates.txt';
colHeads = {'Reg. action','','','Plant action','',...
            'Pollution','','','',''};
rowHeads = [1:size(uniqueStates,1)];        
format   = repmat('%5.0f ',1,size(uniqueStates,2)+1);
cd(modelPath);
tableDisplay( 1, 'Unique States in Data', colHeads, rowHeads, ...
    uniqueStates, format);

% Tabulate all unique states, whether observed or not
S  = genStateSpace( 3, max(aP), 5 ); % Regul. lag, plant lag, pollution
T  = size(sRt,2);
St = [ kron(S,ones(T,1)) repmat(tril(ones(T)),size(S,1),1) ];
rowHeads = [1:size(S,1)];    

tableDisplay( 1, 'Unique States in State Space', ...
              colHeads, rowHeads, S, format);

% Assign state indices for current and next state
%   Useful for estimating state transition probabilities
[ si, sif ] = genFutureState( s, S, ids );


%% ========================================================================
%%================== Data objects used in estimation ======================
%%=========================================================================

% Most of these objects are re-estimated with each bootstrap draw, below.
% We estimate them here as a demonstration in the full sample.

%% Estimate state transition probabilities using count estimator

% State transition conditional on plant action 
%   f_P(s_t+1|aP_t,sP_t)
% |S| X |S| X |aP| state transition matrix
fPsas = genStateTransCount( plantMove, aP, S, si, sif, sPt, false );

% State transition when regulator moves (stochastic)
%   f_R(s_t+1|aR_t,sR_t)
% |S| X |S| X |aR| X |sRt| state transition matrix, if time-dim
% |S| X |S| X |aR|                                , if no time-dim
fRsas = genStateTransHybrid( regulMove3, aR, S, si, sif, t );

%% Estimate multinomial logit models of action choice 

% Plant actions conditional on state
omit        = [ 3 5 6 11 ]; % If two plant moves
% omit        = [ 3 6 7 12 ]; % If three plant moves
sP          = [ s sPt ];
[ bP, seP ] = estimCcpPlant( aP(plantMove), sP(plantMove,:), omit );

% Regulator actions conditional on state
sR          = [ s sRt ];
[ bR, seR ] = estimCcpRegul( aR(regulMove3), sR(regulMove3,:), omit );

% Predicted probabilities for each state in the state space
timeDim  = size(sRt,2);
[ Pras ] = predCcpRegul( bR, St, omit, timeDim );

% Predicted probabilities for each state in the state space
[ Prasj ] = predCcpRegul( bP, St, omit, timeDim );


%% Tabulate results of CCP estimation for plant and regulator

colHeads = {'Comply','Protest'};
statePlant = {stateNames{:},'1','t > 3','t > 5','t > 7',};
tabCcp( 1, 'Plant Action Conditional on State', colHeads, ...
        bP, seP, statePlant, omit );
    
colHeads = {'Punish','Warn','Inspect'};
stateRegul = {stateNames{:},'1','t > 3','t > 5','t > 7'};
tabCcp( 1, 'GPCB Action Conditional on State', colHeads, ...
        bR, seR, stateRegul, omit );

%% Estimate discount factor beta of plant
%  Marginal return on capital from Banerjee and Duflo (2012), 
%    "Do Firms Want to Borrow More?"
r    = 0.89; 
beta = estimateBeta( ids, date, plantMove, r );
fprintf('\nDiscount factor estimated is %4.3f\n',beta);


%% =========================================================================
%%=======================Plant Estimation =================================
%%=========================================================================

%% Draw bootstrap samples
%    The bootstrap is at the 'chain' level, where a chain is a set of
%    related actions of both the regulator and plants

% Set random number stream
rng(20140813);       

% Draw sample of chains
B            = 100;
[ ~, ~, ci ] = unique( ids(:,1) );
NC           = max(ci);
chainsB      = cell(NC,B); 
boots        = cell(B,1);

% Create max pollution in chain to use to stratify groups
pmax   = accumarray( ci, p, [], @max);
nbyg   = tabulate(pmax);
nbyg   = nbyg(:,2);
cstart = [ 0; cumsum(nbyg,1) ];
chainsAssigned = 0;

for g = 1:5
    gci = find( pmax == g-1 );      % Indices of chains with given max p
    gbi = randi(nbyg(g),nbyg(g),B); % Random numbers for draw w/in group
    
    for b = 1:B
       for c = 1:nbyg(g)   
           % Add a single chain
           chainsB{cstart(g) + c,b} = find( ids(:,1) == gci(gbi(c,b)) );
           chainsAssigned = chainsAssigned+1;
       end
    end
end
fprintf('Total %6.0f chains assigned each iteration\n',chainsAssigned/B);

% Assign boots cell array of indices for each replication
sampleSizes = zeros(B,1);
for b = 1:B
    boots{b}       = vertcat(chainsB{:,b});
    sampleSizes(b) = size(boots{b},1);
end

%% Bootstrap estimates for multiple payoff specifications

% Initialize estimation
foptions = optimset('Display','none','TolFun',1e-14,'TolX',1e-14,...
                    'MaxIter',500,'MaxFunEvals',1e5,'LargeScale','off');
sigma0  =   300;    % Scale of action-specific utility shocks
kappa   = 852.5;    % Mean cost of aP = 1(Comply) in cost sample
thetas  = zeros( 9, 4, B );

% Select sample of plant moves for dynamic estimation
sample = plantMove & t > 2;

for b = 1:B

    % Draw sample of data
    [ plantMoveB, aPB, siB, sifB, sPtB, regulMove3B, aRB, tB, ...
      sB, sRtB, idsB, dateB, sampleB ] = ...
          subset( boots{b}, plantMove, aP, si, sif, sPt, regulMove3, ...
          aR, t, s, sRt, ids, date, sample );

    % Estimate state transition probabilities 
    fPsasB = fPsas;  % Deterministic, does not change with b
    fRsasB = genStateTransHybrid( regulMove3B, aRB, S, siB, sifB, tB );

    % Estimate multinomial logit models of regulator action choice 
    sRB        = [ sB sRtB ];
    [ bRB, ~ ] = estimCcpRegul( aRB(regulMove3B), sRB(regulMove3B,:), omit );
    % sP          = [ s sPt ];
    % [ bPB, ~ ] = estimCcpPlant( aP(plantMove), sP(plantMove,:), omit );
    [ PrasB ]  = predCcpRegul( bRB, St, omit, size(sRtB,2) );

    % Estimate discount factor beta of plant
    r     = 0.89; 
    betaB = estimateBeta( idsB, dateB, plantMoveB, r );
    fprintf('Bootstrap iteration b = %3.0f: Discount factor %4.3f\n',b,betaB);
    
    % Maximize likelihood with mean cost
    payoff = 1;
    theta0 = [ 1000*ones(1,1) log(sigma0) ];
    g  = @(x) likelihood( x, kappa, betaB, S, PrasB, fPsasB, fRsasB, ...
                          tC, idsB(sampleB,1), aPB(sampleB), ...
                          siB(sampleB,:), tB(sampleB), payoff );
    [ thetaHat ] = fminunc( g, theta0, foptions );
    thetas(1,1,b)   = thetaHat(1);
    thetas(end,1,b) = thetaHat(end);
    
    % Alternate bribe payoff functions
    payoff = 2;
    theta0 = [ 1000*ones(1,3) log(sigma0) ];
    g  = @(x) likelihood( x, kappa, betaB, S, PrasB, fPsasB, fRsasB, ...
                          tC, idsB(sampleB,1), aPB(sampleB), ...
                          siB(sampleB,:), tB(sampleB), payoff );
    [ thetaHat ] = fminunc( g, theta0, foptions );
    thetas(2:4,2,b) = thetaHat(1:3);
    thetas(end,2,b) = thetaHat(end);
 
    payoff = 3;
    theta0 = [ 1000*ones(1,2) log(sigma0) ];
    g  = @(x) likelihood( x, kappa, betaB, S, PrasB, fPsasB, fRsasB, ...
                          tC, idsB(sampleB,1), aPB(sampleB), ...
                          siB(sampleB,:), tB(sampleB), payoff );
    [ thetaHat ] = fminunc( g, theta0, foptions );
    thetas(1,3,b)   = thetaHat(1);
    thetas(5,3,b)   = thetaHat(2);
    thetas(end,3,b) = thetaHat(end);
    
    payoff = 4;
    theta0 = [ 1000*ones(1,4) log(sigma0) ];
    g  = @(x) likelihood( x, kappa, betaB, S, PrasB, fPsasB, fRsasB, ...
                          tC, idsB(sampleB,1), aPB(sampleB), ...
                          siB(sampleB,:), tB(sampleB), payoff );
    [ thetaHat ] = fminunc( g, theta0, foptions );
    thetas(1,4,b) = thetaHat(1);
    thetas(6:8,4,b) = thetaHat(2:4);   
    thetas(end,4,b) = thetaHat(end);
    
    display( thetas(:,:,b) );   
end

% Save bootstrap estimates
cd(dataPath);
file = sprintf('thetas_boots_samptgt2_%1.0f.mat',B);
save(file,'boots','thetas');
fprintf(1,'Saved file   : %s\n', file);
fprintf(1,'In directory : %s\n', pwd);


%% ========================================================================
%                            Exhibits for paper 
%==========================================================================

%% Table 5: Estimates of Plant Utility Parameters

% currency = 'INR';
currency = 'USD';

cd(dataPath);
load thetas_boots_samptgt2_100.mat

% Summary statistics across bootstrap estimates
thetasExp = [ thetas(1:end-1,:,:); exp(thetas(end,:,:)) ];
thetaHat  = mean(thetasExp,3);
thetaSe   = std(thetasExp,0,3);
thetaCI   = prctile(thetasExp,[2.5 97.5],3);

thetaTab   = reshape([thetaHat(:) thetaSe(:)]',2*size(thetaHat,1), []);

thetaCIlow = thetaCI(:,:,1);
thetaCIhig = thetaCI(:,:,2);
thetaCITab = reshape([thetaHat(:) thetaCIlow(:) thetaCIhig(:)]',...
                     3*size(thetaHat,1), []);
         
if currency == 'USD'
    thetaTab = thetaTab / 50;
    thetaCITab = thetaCITab / 50;
end
         
% Output tables 
fprintf(1,'\nPrinting tables in currency: %s\n\n',currency);

cd(tablePath);
file   = sprintf('Table5_Estimates_of_Plant_Utility_%s.tex',currency);
fid    = fopen(file,'w');
format = ['%15s',repmat('\t%10.2f',1,size(thetaTab,2))];
tabLatex( fid, 'Estimates of Plant Utility Parameters', ...
             {'','(1)','(2)','(3)','(4)'}, ...
             {'tau0','','tau1','','tau2','','tau3','',...
              'nu0', '','nu1', '','nu2', '','nu3', '',...
              'sigma',''}, ...
             thetaTab, format )
fclose(fid);     

fprintf(1,'Saved table  : %s\n', file);
fprintf(1,'In directory : %s\n', pwd);


%% Plot relation between state value and pollution reading, separating
%    the value of penalties from the value of compliance
cd(dataPath);
load thetas_boots_samptgt2_100.mat  % Parameters with bribes

thetasExp = [ thetas(1:end-1,:,:); exp(thetas(end,:,:)) ];
thetaHat  = mean(thetasExp,3);

payoff = 2;
if payoff == 2
    thetaUP = [ thetaHat(2:4,payoff)' ];
elseif payoff == 4
    thetaUP = [ thetaHat(1,payoff)' thetaHat(6:8,payoff)' ];
end
sigma   = thetaHat(end,payoff);  % Sd of action shock
kappa   = 852.5;                 % Mean cost of aP = 1(Comply)

currency = 'USD';
time     = 6;
bribe    = 0;
[ Vp, Vp_c, Vp_h ] = predValueOfPollutionSplit( thetaUP, sigma, ...
                               kappa, beta, S, Pras, fPsas, ...
                               fRsas, tC, time, payoff );

cd(figurePath)
file = sprintf('Figure4_Value_of_Environmental_Regulation_t%1.0f_cur%s_bribe%1.0f.pdf',...
               time, currency, bribe );
plotValueOfPollutionSplit( file, Vp, Vp_c, Vp_h, time, currency );


currency = 'USD';
time     = 2;
bribe    = 0;
[ Vp, Vp_c, Vp_h ] = predValueOfPollutionSplit( thetaUP, sigma, ...
                               kappa, beta, S, Pras, fPsas, ...
                               fRsas, tC, time, payoff );

cd(figurePath)
file = sprintf('Figure4_Value_of_Environmental_Regulation_t%1.0f_cur%s_bribe%1.0f.pdf',...
               time, currency, bribe );
plotValueOfPollutionSplit( file, Vp, Vp_c, Vp_h, time, currency );

fprintf(1,'Saved figure : %s\n', file);
fprintf(1,'In directory : %s\n', pwd);


%% ========================================================================
%                            Further statistics
%==========================================================================

%% Weighted-average value of state
Vp   = Vp / 50;
Vp_c = Vp_c / 50;
Vp_h = Vp_h / 50;

dummies = ones(sum(t==time),1);
aRlag1  = [ 0; aR(1:end-1) ];
aRlag1  = aRlag1( t == time );
pidx    = p( t == time ) + 1;

W = accumarray( [ pidx aRlag1 ], dummies );                 
W = W ./ sum(W(:));

value_total = sum(sum( W .* Vp ));
value_penal = sum(sum( W .* Vp_h ));
value_abate = sum(sum( W .* Vp_c ));

fprintf('\nWeighted value of t = %2.0f inspection: USD %8.3f\n', ...
         time, value_total );
fprintf('   Of which penalty value is : USD %8.3f, %3.2f percent\n', ...
         value_penal, value_penal/value_total *100 );
fprintf('   Of which cost value is    : USD %8.3f, %3.2f percent\n', ...
         value_abate, value_abate/value_total *100  );
   
% Save Vp matrix for use in targeting
cd(dataPath);
file = sprintf('penalty_function.mat');
save(file,'Vp');

%% ========================================================================
%                            END
%==========================================================================


                       