function [ fsas ] = genStateTransCount( It, aI, S, si, sif, sIt, time )
% genStateTransCount Estimate state transition after a single player moves
%                    using a count estimator on states in the data 
% 
% INPUT:
%   It   - turns where party moves
%   aI   - party's action choice
%   S - |aP| X |aR| X |pol| matrix of all possible states, in 2-D
%   si   - N X 1 vector of state indices, giving the row of S to which 
%          the current round of s belongs.
%   sif  - N X 1 vector of state indices, giving the row of S to which 
%          the next round of s belongs, or 0 if the chain terminates.
%   sIt  - matrix of time component of state for party
%   time - dummy for whether time component of state is to be included in
%          the state transition or state transition is assumed to be the
%          same across time periods.
%
% OUTPUT:
%   fsas  - |S| X |S| X |aR| X |sti| state transition matrix.  
%          Stochastic, because pollution reading may change if R inspects.  
%          Row gives index of starting state, column gives index of ending 
%          state, and entry gives probability of transition between states. 

%% Transition based on count estimator 
%    S X S X aR X sIt
[ aI, si, sif, sIt ] = subset( It, aI, si, sif, sIt ); 

% Add time index for fourth dimension of transition if needed
if time
    [ ~, ~, tJ ] = unique(sIt,'rows'); 
else
    tJ = ones(size(sIt,1),1);          
end

% Index 'Accept' with max state index + 1
sif( sif==0 ) = max(sif) + 1;          

% Calculate probabilities of transition from each row state
Nsas = accumarray( [ si, sif, aI, tJ ], ones(size(si)) );
if size(Nsas,2) < size(S,1) % Add zeros if states not observed in future
   newcols = size(S,1) - size(Nsas,2);
   Nsas(:,end:end+newcols,:) = 0;
end
Nas  = sum( Nsas, 2 );
fsas = Nsas ./ Nas(:,ones(1,size(Nsas,2)),:,:);

%% Deterministic transition for states not observed in the data
%   With count estimator, question arises of transition probabilities from
%   states that are not observed in the data.  These are NaN due to
%   division by zero.  Assume here that states not observed in the data
%   transition deterministically in actions and keep the same pollution
%   reading as before.
numberOfActions = max( aI );
plantTransition = numberOfActions < 4;
N               = size(S,1);
if plantTransition 
    player = 'Plant';
    if numberOfActions == 3
        Sf = cat(3, [S(:,1:3) ones(N,1)            zeros(N,2) S(:,7:end)],...
                    [S(:,1:3) zeros(N,1) ones(N,1) zeros(N,1) S(:,7:end)],...
                    [S(:,1:3) zeros(N,2)           ones(N,1)  S(:,7:end)] );
    else 
        Sf = cat(3, [S(:,1:3) ones(N,1)  zeros(N,1) S(:,6:end)],...
                    [S(:,1:3) zeros(N,1) ones(N,1)  S(:,6:end)] );    
    end
else
    player = 'Regulator';
    Sf = cat(3, [ones(N,1)             zeros(N,2) S(:,4:end)],...
                [zeros(N,1) ones(N,1)  zeros(N,1) S(:,4:end)],...
                [zeros(N,2)            ones(N,1)  S(:,4:end)] );
end

% Populate transition.  Do not fill accept, which would be i=4
fsasd = zeros(N,N,numberOfActions,max(tJ));                 
for i = 1:min(numberOfActions,3) 
    eq = sum(S(:,:,ones(N,1)) == ...
             permute(Sf(:,:,i*ones(N,1)),[3 2 1]),2);
    fsasd(:,:,i) = permute( eq == size(S,2), [3 1 2]);      
end   

%% Assign all transitions for a_R=accept to an absorbing state indexed one
%   beyond the maximum state index, if it is the regulator's turn
if ~plantTransition
    fsasd(:,end+1,:) = 0;
    fsasd(:,  end,end) = 1;
end

%% Use deterministic state transition for states not observed in the data
notObserved         = isnan( fsas );
fprintf('\nShare of states not observed: %4.3f',mean(notObserved(:)));
fprintf('  After %s moves.\n',player);

fsas( notObserved ) = fsasd( notObserved );

%% Alternately could assume that states not observed in the data
%   always transition to accept, which has a value of zero.
% accept                = fsas(:,end,:,:);
% acceptIsNan           = isnan( accept );
% accept( acceptIsNan ) = 1;
% fsas(:,end,:,:)       = accept;
% fsas( isnan(fsas) )   = 0;

% Checksum: probability of some future state should sum to 1
%   sum(fsas,2)

end