function [ fsas ] = genStateTransHybrid( It, aI, S, si, sif, t )
% genStateTransHybrid Estimate state transition after the regulator moves
%                    with a hybrid of deterministic moves and the overall
%                    stochastic pollution transition, after any regulator
%                    move.
% 
% INPUT:
%   It   - turns where party moves
%   aI   - party's action choice
%   S - |aP| X |aR| X |pol| matrix of all possible states, in 2-D
%   si   - N X 1 vector of state indices, giving the row of S to which 
%          the current round of s belongs.
%   sif  - N X 1 vector of state indices, giving the row of S to which 
%          the next round of s belongs, or 0 if the chain terminates.
%   t    - N X 1 vector giving round t of chain
%
% OUTPUT:
%   fsas  - |S| X |S| X |aR| state transition matrix.  
%          Stochastic, because pollution reading may change if R inspects.  
%          Row gives index of starting state, column gives index of ending 
%          state, and entry gives probability of transition between states. 

%% Transition based on count estimator 
%    S X S X aR X sIt
[ aI, si, sif, t ] = subset( It, aI, si, sif, t ); 

% Matrix of pollution transitions conditional on inspect and t >= 3
%   Appropriate since transitions in t == 1 never lie ahead when a firm
%   is deciding its action.
% display('State transition: After regulator moves | inspect and t >= 3');
pT  = tabStateTransition( aI == 3 & t >= 3, si, sif, S );
pTN = sum( pT, 2 );
pT  = pT ./ pTN(:,ones(1,size(pT,2)));

% Index 'Accept' with max state index + 1
sif( sif==0 ) = max(sif) + 1;          

%% Make hybrid transition matrix based on deterministic state transitions
%    and stochastic pollution transitions pT
A = max( aI ) - 1;
N = size(S,1);
Z = zeros(size(pT));

fsas1 = [ [ eye(N/A); eye(N/A); eye(N/A) ] zeros(N,N/A*(A-1)+1) ];
fsas2 = [ zeros(N,N/A) [ eye(N/A); eye(N/A); eye(N/A) ] zeros(N,N/A+1) ];
fsas3 = [ zeros(N,N/A*(A-1)) repmat([pT Z; Z pT],3,1) zeros(N,1) ];
fsas4 = [ zeros(N,N) ones(N,1) ];
fsas  = cat(3, fsas1, fsas2, fsas3, fsas4 );

% Checksum: probability of some future state should sum to 1
% sum(fsas,2);

if any( sum(fsas,2) ~= 1 )
    display('Probabilities do not sum to one.');
    keyboard
end

end