function [ L ] = likelihood( theta, kappa, beta, S, Pras, fPsas, fRsas, ...
                             tC, ci, a, s, t, payoff )
%likelihood Log likelihood of observing choice probabilities in data as a
%   function of the parameter vector theta
%   
% INPUT :
%   theta - vector of parameters for plant utility and standard deviation
%           sigma of unobserved utility shock.
%   kappa - plant's cost of compliance.
%   beta  - discount factor of the plant
%   S     - |aP| X |aR| X |pol| matrix of all possible states, in 2-D
%   Pras  - |S| X |aR| X |sRt|  matrix of predicted probabilities 
%           for each action of the regulator conditional on the state.
%   fPsas - |S| X |S| X |aP| state transition matrix (deterministic).  
%   fRsas - |S| X |S+1| X |aR| X |sRt| state transition matrix (stochastic,
%           and dependent on the time dimension of state).
%   tC      - Cut-offs for discrete time dummies.
%   ci - chain index c=1,...,C
%   a  - N X 1 vector of actions, where N is the number of turns at which
%        the plant can move 
%   si - state index at turns where plant moves.
%   t  - round number at turns where plant moves.
%   payoff  - choice of per-round payoff function when regulator moves
%
% OUTPUT :
%   L - negative log likelihood of observing the data

[ thetaUP, sigma ] = unpackThetaUP( theta );

% Backwards induction to calculate probability of observing each action in
% each state given parameters
[ ~, ~, Pas ] = backsolveValues( thetaUP, sigma, kappa, beta, ...
                                 S, Pras, fPsas, fRsas, tC, payoff );

% From the probabilities calculated above, assign the appropriate
% theoretical probability to the actions observed in the data
tP      = floor(t/2);
d       = size(Pas);
i       = s + d(1)*(a-1) + prod(d(1:2))*(tP-1);
Prast   = Pas(i);

% Take the product of probabilities over chains
[ ~, ~, ci ] = unique(ci);
Prasc        = accumarray( ci, Prast, [], @prod );
L            = - sum( log( max(Prasc,realmin('double')) ) );
% L            = - sum( log( Prasc ) );

if isnan(L) || isinf(L)
    display('Help! Objective invalid');
    keyboard
end
    
end

