function [ ] = plotValueOfPollutionSplit( file, Vp, Vp_c, Vp_h, time, ...
                                          currency )
% plotCournotClearing  Plot aggregate residual demand and smoothed version
%   along with cleared cournot solution.
% file      : filename in which to print or 1 to indicate print to screen
% Vp        : matrix of values
% Vp_c      : values due to abatement cost
% Vp_h      : values due to regulatory penalties
% time      : period at which value is being evaluated
% currency  : currency in which to scale, of {USD,INR}

%% Create lines to plot
if time > 2
    data = [ Vp_c(1,end:-1:1)' Vp_h(1,end:-1:1)' ;
             zeros(1,2) ; 
             Vp_c(2,end:-1:1)' Vp_h(2,end:-1:1)' ;
             zeros(1,2) ; 
             Vp_c(3,end:-1:1)' Vp_h(3,end:-1:1)' ;
             zeros(1,2) ; 
             Vp_c(4,end:-1:1)' Vp_h(4,end:-1:1)' ;
             zeros(1,2) ; 
             Vp_c(5,end:-1:1)' Vp_h(5,end:-1:1)' ];     
else
    data = [ Vp_c(1,end)' Vp_h(1,end)' ;
             zeros(3,2) ; 
             Vp_c(2,end)' Vp_h(2,end)' ;
             zeros(3,2) ; 
             Vp_c(3,end)' Vp_h(3,end)' ;
             zeros(3,2) ; 
             Vp_c(4,end)' Vp_h(4,end)' ;
             zeros(3,2) ; 
             Vp_c(5,end)' Vp_h(5,end)' ]; 
             zeros(2,2) ; 
end            

scale = 1;
if currency == 'USD'
    data = data / 50;
    scale = 50;
end

fprintf(1,'Data on plant valuation:');
display([ data sum(data,2) ]);
     
%% Formatting options
textProp = {'fontsize'    , 18, ...
            'FontName'    , 'Arial'};
labProp  = {'fontsize'    , 14, ...
            'FontName'    , textProp{4}};
        
grayscale = [ 0.7 0.7 0.7;
              0.4 0.4 0.4 ];
         
%% Plot supply, demand and the clearing price
hseries = bar(data,'stacked');
hold on;

ylim([-1500/scale 0]);

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'XTick'       , 2:4:18              , ...
         'YTick'       , -1500/scale:500/scale:0        , ...
         'LineWidth'   , 1.5                , ...
         'XTickLabel'  , ...
             {'None','$<\overline{p}$','$[\overline{p},2\overline{p})$', ...
             '$[2\overline{p},5\overline{p})$','$\geq 5\overline{p}$'});
colormap(grayscale);

% Axis labels
xlabel('Pollution Component of State',textProp{:})
ylabel(sprintf('Value to Plant (%s 1000s)',currency), textProp{:})   

% Text label positions
labels = {'I','W','P'};
ypos   = 50/scale;
xpos   = [ 1 2 3 5 6 7 9 10 11 13 14 15 17 18 19]; 
lpos   = repmat([1 2 3],1,5);

% Apply text labels
for i = 1:length(xpos)
    text(xpos(i),ypos,labels{lpos(i)},textProp{:},'rotation',0,...
        'HorizontalAlignment','center');
end

AX = legend(hseries, {'Cost due to abatement','Cost due to penalties'},...
           'Location','South',textProp{:});
legend(gca,'boxoff');

plotTickLatex2D('XLabelDy',.02,'YLabelDx',.01);
hold off;

%% Export figure to file
if ischar( file )
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end