function [ Vp, Vp_c, Vp_h ] = predValueOfPollutionSplit( thetaUP, sigma, ...
                                  kappa, beta, S, Pras, fPsas, fRsas, tC, ...
                                  t, payoff )
% predValueOfPollution Estimate value of pollution states given parameters
%                      keeping track of the value of abatement and
%                      penalties separately.
% 
% INPUT:
%   S     - |aR| X |aP| X |pol| matrix of all possible states, in 2-D
%   Pras  - |S| X |aR| X |sRt|  matrix of predicted probabilities 
%           for each action of the regulator conditional on the state.
%   fPsas - |S| X |S| X |aP| state transition matrix (deterministic).  
%   fRsas - |S| X |S+1| X |aR| X |sRt| state transition matrix (stochastic,
%           and dependent on the time dimension of state).
%   tC      - Cut-offs for discrete time dummies.
%   thetaUP - Plant's utility parameters for being punished
%   sigma   - Scaling factor for variance of unobserved action shocks.
%   kappa   - Plant's cost of compliance.
%   beta    - Plant's discount factor.
%   t       - Time period at which to evaluate state value
%   payoff  - choice of per-round payoff function when regulator moves
%
% OUTPUT:
%   Vs     - |S| X T/2 values for each possible state
%   vas    - |S| X |aP| X T/2 values for each possible action and state.
%   Pas    - |S| X |aP| X T/2 probabilities for each action cond. on state.
%   Vp     - Value of pollution (rows) across rounds of the game (columns)

[ Vs, ~, Pas, Vs_c, Vs_h, vas_c, vas_h ] = ...
    backsolveValuesSplit( thetaUP, sigma, kappa, beta, S, ...
                          Pras, fPsas, fRsas, tC, payoff );

% {Punish, warn and inspect} and Plant ignore in state
Pi = S(:,1) == 1 & S(:,5) == 1;                                
Wi = S(:,2) == 1 & S(:,5) == 1;
Ii = S(:,3) == 1 & S(:,5) == 1;

% Time component of state
pt = floor(t/2);

Vp   = [ Vs( Pi, :, pt ) Vs( Wi, :, pt ) Vs( Ii, :, pt ) ];
Vp_c = [ Vs_c( Pi, :, pt ) Vs_c( Wi, :, pt ) Vs_c( Ii, :, pt ) ];
Vp_h = [ Vs_h( Pi, :, pt ) Vs_h( Wi, :, pt ) Vs_h( Ii, :, pt ) ];

display(Vp);
display(Vp_c);
display(Vp_h);

end