function [ Nineq, Neq ] = abateBudgetPhi( lambda, beta, sig1, rho, ...
                                          XT, XTwt, Nbar, group )
%abateBudget Calculate total inspection budget needed to follow inspection
% targeting rule x.
%   
% INPUTS:
%   lambda - Parameters of targeting function theta_t =
%            {beta_0,beta_3}.
%   beta   - {beta_1,beta_2} additional coefficients on observables in
%            argument of inspection targeting function.
%   These inputs define step-like function for inspection
%       targeting rule. Given these parameters, the inspections given to
%       any plant as a function of its pollution shock u_1 are :
%         I(u_1;x) = beta_3 * Phi( beta_0 + beta_1*X + beta_2*T + u_1 / 
%                                  rho*sig1 ) 
%
% Plant observables:
%   XT   - Plant-level covariates and treatment assignment, by type
%   XTwt - Weights for plant types, in the same order as XT
%
% Parameters
%   sig1 - standard deviation of observable pollution shock
%   rho  - targeting error parameter, as a fraction of sig1
%
% OUTPUT:
%   N - The total excess inspections used by the rule X on a per-plant basis.

if nargin < 8
    group = 0;
end

%% Calculate design matrix and weights for the targeted group of plants
XTb  = XT*beta;

if group == 0     % All plants
    
elseif group == 1 % Control plants
    ctrl   = XT(:,end) == 0;
    XT     = XT( ctrl, : );
    XTb    = XTb( ctrl );
    XTwt   = XTwt( ctrl );

elseif group == 2 % Representative plant
    XTb    = 0;
    XTwt   = sum(XTwt);
end

% % Calculate expected inspection expenditure given observables
% Nineq = lambda(2) * (1 - normcdf( (-(lambda(1) + XTb)/sig1) ...
%                   / (rho^2+1)^0.5) ) - Nbar;
% Nineq = lambda(2) * normcdf(((lambda(1) + XTb)/sig1) / (rho^2+1)^0.5) - Nbar;

Nineq   = lambda(2) * normcdf((lambda(1) + XTb)/(rho^2+sig1^2)^0.5) - Nbar;
Nineq   = XTwt' * Nineq / sum(XTwt(:));  
Neq     = [];

end

