function [ aval ] = abatement2Ds( lambda, beta, phi, XT, XTwt, u1, u2, ...
                                  muc, sigc, sig1, rho, AbsV, group, Nc )
% abateProb2Ds Expected value of pollution abatement, probability of
% compliance or probability of abatement, given targeting function.
%   
% INPUTS:
%   lambda - Parameters of targeting function theta_t =
%            {beta_0,beta_3}.
%   beta   - {beta_1,beta_2} additional coefficients on observables in
%            argument of inspection targeting function.
% Plant observables:
%   XT   - Plant-level covariates and treatment assignment, by type
%   XTwt - Weights for plant types, in the same order as XT
% Pollution shocks
%   u1   - Observed pollution shocks at which to evaluate 
%          abatement decision
%   u2   - Unobserved pollution shocks at which to evaluate abatement 
%          decision
% Parameters
%   muc  - mean of log abatement cost
%   sigc - standard deviation of log abatement cost
%   phi3 - abatement from decision to run equipment
%   sig1 - standard deviation of observable pollution shock
%   rho  - targeting error parameter, as a fraction of sig1
%   AbsV - absolute penalty function applicable to pollution levels
%   Nc   - constant level of inspections to add
%
% OUTPUTS
%   aval - Overall probability of abatement

% Constant level of non-discretionary inspections assumed to be zero
%   unless passed to the abatement function
if nargin < 14
    Nc = 0;
end

%% Calculate design matrix and weights for the targeted group of plants
XTb  = XT*beta;
lnPs = [ ones(size(XT,1),1) XT(:,1:end-1) ] * phi(1:end-1);

if group == 0     % All plants
    types  = size(XT,1);
    
elseif group == 1 % Control plants
    ctrl   = XT(:,end) == 0;
    XT     = XT( ctrl, : );
    types  = size(XT,1);
    XTb    = XTb( ctrl );
    XTwt   = XTwt( ctrl );
    lnPs   = lnPs( ctrl );

elseif group == 2 % Representative plant
    types  = 1;
    XTb    = 0;
    XTwt   = sum(XTwt);
    lnPs   = mean(lnPs);
end

%% Get pollution shock as sum of observed and unobserved components
%    For each combination of observable plant type and shocks
%    Each row is: Observable characteristics X obs. u1 X unobs. u2
u    = kron(u1,  ones(size(u2))) + repmat(u2,length(u1), 1);
u    = kron(lnPs,ones(size(u ))) + repmat(u,length(lnPs),1);

ps   = exp(u);           % Pollution without abatement (Run==0)
p    = ps*exp(phi(end)); % Pollution with abatement (Run==1)

%% Calculate inspections for each observable plant type and shock
Is = targetPhiFun( lambda, sig1, rho );

% Evaluate targeting function at each X, u1 combination
xu1 = Is( kron(XTb,ones(size(u1))) + kron(ones(size(XTb)),u1) );                      

% Replicate for each value of (u1,u2)
Iu1u2 = repmat(xu1,length(u2),1);  % Expand inspection values, which depend on 
                                 %   u1 alone, to apply to each u = u1 + u2

%% Probability of abatement for each pollution shock combination
%    and each value of observables
Delp   = ppval(AbsV,p) - ppval(AbsV,ps);

%    Log-normal cost distribution
phiArg = ( log((Iu1u2+Nc) .* Delp) - muc ) / sigc; 
Prabu  = normcdf( phiArg );

%    Exponential cost distribution
% Prabu  = 1 - exp( - (Iu1u2+Nc) .* Delp / muc );

% Abatement for each pollution shock combination
Abatu  = Prabu .* (ps - p);
Abatmn = accumarray( kron([1:types]',ones(length(u1)*length(u2),1)),...
                     Abatu, [], @mean );
aval   = XTwt'/2 * Abatmn;

end