function [ fval, grad ] = abatement2DsGrad( lambda, beta, phi, ...
                                            XT, XTwt, u1, u2, ...
                                            muc, sigc, sig1, ...
                                            rho, AbsV, group )
% abateProb2Ds Expected value of pollution abatement, probability of
% compliance or probability of abatement, given targeting function.
%   
% INPUTS:
%   lambda - Parameters of targeting function theta_t =
%            {beta_0,beta_3}.
%   beta   - {beta_1,beta_2} additional coefficients on observables in
%            argument of inspection targeting function.
% Plant observables:
%   XT   - Plant-level covariates and treatment assignment, by type
%   XTwt - Weights for plant types, in the same order as XT
% Pollution shocks
%   u1   - Observed pollution shocks at which to evaluate 
%          abatement decision
%   u2   - Unobserved pollution shocks at which to evaluate abatement 
%          decision
% Parameters
%   muc  - mean of log abatement cost
%   sigc - standard deviation of log abatement cost
%   phi3 - abatement from decision to run equipment
%   sig1 - standard deviation of observable pollution shock
%   rho  - targeting error parameter, as a fraction of sig1
%   AbsV - absolute penalty function applicable to pollution levels
%   control - flag equal to 1 if evaluation restricted to control group
%
% OUTPUTS
%   aval - Overall amount of abatement
%   grad - Vector of derivatives including df/dlam_0, df/dlam_1

%% Calculate design matrix and weights for the targeted group of plants
XTb  = XT*beta;
lnPs = [ ones(size(XT,1),1) XT(:,1:end-1) ] * phi(1:end-1);

if group == 0     % All plants
    types  = size(XT,1);
    
elseif group == 1 % Control plants
    ctrl   = XT(:,end) == 0;
    XT     = XT( ctrl, : );
    types  = size(XT,1);
    XTb    = XTb( ctrl );
    XTwt   = XTwt( ctrl );
    lnPs   = lnPs( ctrl );

elseif group == 2 % Representative plant
    types  = 1;
    XTb    = 0;
    XTwt   = sum(XTwt);
    lnPs   = mean(lnPs);
end

%% Get pollution shock as sum of observed and unobserved components
%    For each combination of observable plant type and shocks
%    Each row is: Observable characteristics X obs. u1 X unobs. u2
u    = kron(u1,ones(size(u2))) + repmat(u2,length(u1),1);
u    = kron(lnPs,ones(size(u))) + repmat(u,length(lnPs),1);

ps   = exp(u);
p    = ps*exp(phi(end));

%% Calculate inspections for each observable plant type and shock
% Is = targetPhiFun( lambda, sig1, rho );
% Is = @(u) lambda(2) * normcdf( u, -lambda(1), rho*sig1 );

% Evaluate targeting function at each X, u1 combination
XTbu1 = kron(XTb,ones(size(u1))) + kron(ones(size(XTb)),u1);
% Iarg  = (lambda(1) + XTbu1)/(rho*sig1);
Iarg  = (lambda(1) + XTbu1)/rho;

Iu1   = max(1e-10,lambda(2) * normcdf(Iarg)); % Min number of inspections
% Iu1 = Is( XTbu1 );                      

% Replicate for each value of (u1,u2)
Iu1u2 = repmat(Iu1,length(u2),1);  % Expand inspection values, which depend on 
                                   %   u1 alone, to apply to each u = u1 + u2

%% Quantity of abatement for each pollution shock combination
%    and each value of observables
Delp   = ppval(AbsV,p) - ppval(AbsV,ps);

%    Log-normal cost distribution
phiArg = ( log(Iu1u2 .* Delp) - muc ) / sigc; 
Prabu  = normcdf( phiArg );

% %    Exponential cost distribution
% Prabu  = 1 - exp( - Iu1u2 .* Delp / muc );

% Total abatement for each pollution shock combination
Abatu  = Prabu .* (ps - p);
subs   = kron([1:types]',ones(length(u1)*length(u2),1));
Abatmn = accumarray( subs, Abatu, [], @mean );

fval  = - XTwt' * Abatmn / 2;

%% Gradient of abatement for each pollution shock combination 

%    Log-normal cost distribution
dAdlamC = normpdf( phiArg ) .* (ps - p);
dAdlam0 = dAdlamC * 1/sigc * 1/lambda(2);

phiIargu1   = normpdf(Iarg);
phiIargu1u2 = repmat(phiIargu1,length(u2),1);
dAdlam1     = dAdlamC .* 1/sigc * lambda(2)./Iu1u2 .* phiIargu1u2 ./ rho;

%    Exponential cost distribution
% dAdlamC = exp(-Iu1u2 .* Delp / muc ) .* (ps - p);
% 
% dAdlam0 = dAdlamC .* Iu1u2/lambda(2) .* Delp / muc;
% 
% phiIargu1   = normpdf(Iarg);
% phiIargu1u2 = repmat(phiIargu1,length(u2),1);
% dAdlam1     = dAdlamC .* lambda(2) .* phiIargu1u2 .* Delp / muc ./ rho;

%% Abatement gradient vector for total abatement

dAdlam  = [ accumarray( subs, dAdlam1, [], @mean ) ...
            accumarray( subs, dAdlam0, [], @mean )  ];
grad    = - ( XTwt'/2 * dAdlam )';

if any(isnan(grad)) || any(isinf(grad))
    fprintf('Wait!');
end
     
end