function [ grad ] = abatement2DsGradCon( lambda, beta, phi, ...
                                         XT, XTwt, u1, u2, ...
                                         muc, sigc, sig1, ...
                                         rho, AbsV, group )
% abateProb2Ds Expected value of pollution abatement, probability of
% compliance or probability of abatement, given targeting function.
%   
% INPUTS:
%   lambda - Parameters of targeting function theta_t =
%            {beta_0,beta_3}.
%   beta   - {beta_1,beta_2} additional coefficients on observables in
%            argument of inspection targeting function.
% Plant observables:
%   XT   - Plant-level covariates and treatment assignment, by type
%   XTwt - Weights for plant types, in the same order as XT
% Pollution shocks
%   u1   - Observed pollution shocks at which to evaluate 
%          abatement decision
%   u2   - Unobserved pollution shocks at which to evaluate abatement 
%          decision
% Parameters
%   muc  - mean of log abatement cost
%   sigc - standard deviation of log abatement cost
%   phi3 - abatement from decision to run equipment
%   sig1 - standard deviation of observable pollution shock
%   rho  - targeting error parameter, as a fraction of sig1
%   AbsV - absolute penalty function applicable to pollution levels
%   control - flag equal to 1 if evaluation restricted to control group
%
% OUTPUTS
%   aval - Overall amount of abatement
%   grad - Vector of derivatives including df/dlam_0, df/dlam_1

%% Unpack parameters
% gamma  = lambda(end);
% lambda = lambda(1:2);


%% Designate group of plants for gradient calculation
%    0 all, 1 ctrl, 2 representative
XTb  = XT*beta;
lnPs = [ ones(size(XT,1),1) XT(:,1:end-1) ] * phi(1:end-1);

if group == 0     % All plants
    types  = size(XT,1);
    
elseif group == 1 % Control plants
    ctrl   = XT(:,end) == 0;
    XT     = XT( ctrl, : );
    types  = size(XT,1);
    
    XTb    = XTb( ctrl );
    XTwt   = XTwt( ctrl );
    lnPs   = lnPs( ctrl );

elseif group == 2 % Representative plant
    types  = 1;
    
    XTb    = 0;
    XTwt   = sum(XTwt);
    lnPs   = mean(lnPs);
end

%% Get pollution shock as sum of observed and unobserved components
%    For each combination of observable plant type and shocks
%    Each row is: Observable characteristics X obs. u1 X unobs. u2
u    = kron(u1,ones(size(u2))) + repmat(u2,length(u1),1);
u    = kron(lnPs,ones(size(u))) + repmat(u,length(lnPs),1);

ps   = exp(u);
p    = ps*exp(phi(end));

%% Calculate inspections for each observable plant type and shock
% Is = targetPhiFun( lambda, sig1, rho );
% Is = @(u) lambda(2) * normcdf( u, -lambda(1), rho*sig1 );

% Evaluate targeting function at each X, u1 combination
XTbu1 = kron(XTb,ones(size(u1))) + kron(ones(size(XTb)),u1);
% Ijs   = (lambda(1) + XTbu1)/(rho*sig1);
Ijs   = (lambda(1) + XTbu1)/rho;

Iu1   = lambda(2) * normcdf(Ijs); % Max number of inspections

% Replicate for each value of (u1,u2)
Iu1u2 = repmat(Iu1,length(u2),1);  % Expand inspection values, which depend on 
                                   %   u1 alone, to apply to each u = u1 + u2

% Useful arguments for targeting function
Delp  = ppval(AbsV,p) - ppval(AbsV,ps);
subs  = kron((1:length(XT))',ones(length(u1)*length(u2),1));

%% Gradient of constrained abatement problem

% EIarg   = (lambda(1) + XTb)/(sig1*(rho^2+1)^0.5);
EIarg   = (lambda(1) + XTb)/(rho^2+sig1^2)^0.5;
 
% A. Assuming log-normal costs

%   With respect to lambda0 (max inspections)
Cjs   = ( log(Iu1u2 .* Delp) - muc ) / sigc; 
dLdlamC = normpdf(Cjs) .* (ps - p);
dLdlam2 = dLdlamC * 1/sigc * 1/lambda(2);  

%   With respect to lambda1 (inspection shift)
phiIargu1   = normpdf(Ijs);
phiIargu1u2 = repmat(phiIargu1,length(u2),1);
% dLdlam1     = dLdlamC.*1/sigc * lambda(2)./Iu1u2 .* phiIargu1u2./(rho*sig1);
dLdlam1     = dLdlamC.*1/sigc * lambda(2)./Iu1u2 .* phiIargu1u2/rho;

% % B. Assuming exponential costs
% 
% %   With respect to lambda0 (max inspections)
% dLdlamC = exp(-Iu1u2 .* Delp / muc ) .* (ps - p);
% dLdlam2 = dLdlamC .* Iu1u2/lambda(2) .* Delp / muc;
% 
% %   With respect to lambda1 (inspection shift)
% phiIargu1   = normpdf(Ijs);
% phiIargu1u2 = repmat(phiIargu1,length(u2),1);
% dLdlam1     = dLdlamC .* lambda(2) .* phiIargu1u2 .* Delp / muc ./ rho;

% C. Terms of derivative with respect to constraint
dCdlam2 = normcdf(EIarg);
% dCdlam1     = lambda(2) * normpdf(EIarg) * 1/(sig1*(rho^2+1)^0.5);
dCdlam1 = lambda(2) * normpdf(EIarg) * 1/(rho^2+sig1^2)^0.5;

%% Overall gradient vector with constraint
dLdlam  = [ accumarray( subs, dLdlam1, [], @mean ) ...
            accumarray( subs, dLdlam2, [], @mean )  ];
dCdlam  = [ dCdlam1 dCdlam2 ];

% Back out gamma implied by FOC with respect to lambda2
dLdlam = XTwt' * dLdlam;
dCdlam = XTwt' * dCdlam;
gamma  = dLdlam(2) ./ dCdlam(2);

% Calculate FOC with respect to lambda1, using implied gamma
grad   = dLdlam(1) - gamma * dCdlam(1);

%% Catch indefinite gradient values
if any(isnan(grad)) || any(isinf(grad))
    fprintf('Wait!');
end
     
end
