function [sigma, OmegaHat, Lambda]=computeSensitivityMatrix(gmm, ...
                                                   thetaHat, del, signs )
%covarianceTargetingMoments Calculate covariance matrix and Gentzkow 
%sensitivity matrix of targeting moments.
%
% INPUT: 
%  gmmTheta - Objective function
%  thetaHat - Parameter estimates at which to calculate objective 
%  del      - Finite difference in parameters to use in calculating
%             gradient.
%  signs    - vector of indicators -1, 0, 1 for whether parameters have
%             been log-transformed in estimation to preserve sign.
%
% OUTPUT:
%  sigma    - Standard errors of parameters (corrected for possible log-
%             transformation
%  OmegaHat - Cov. matrix for moments 
%  Lambda   - Gentzkow sensitivity matrix

[ ~, ~, OmegaHat, N ] = gmm( thetaHat );

m = size(OmegaHat,1);
p = length(thetaHat);

signs = signs(1:p);
gpT   = exp(abs(signs).*thetaHat);

dGdT = zeros(m,p);
for j = 1:p
        
    delj    = zeros(size(thetaHat));
    delj(j) = del;

    [ ~, gp, ~, ~ ] = gmm( thetaHat + delj );    
    [ ~, gm, ~, ~ ] = gmm( thetaHat - delj );

    dGdT(:,j) = (gp - gm)./(2*del);
        
end

%Compute the inverses only twice
W = inv(OmegaHat);
invGWG = inv( dGdT' * W * dGdT );
Lambda = (-invGWG * dGdT' * W).*gpT(:,ones(1,m));
Vhat   = invGWG ./ N;
sigma  = sqrt(diag(Vhat)) .* gpT;

end

