import numpy as np
import matplotlib.pyplot as plt

def signColors(S):
    """Assigns colors to values:
       Black if positive,
       White/hollow if negative
    """
    colors = []
    for s in S:
        if s < 0:
            colors.append('None')
        else:
            colors.append('black')
    return colors

def figSensitivity(fname, Lambda, Omega, sig1, sig2):
    """Generates Figure 5
    INPUT:
        fname  : String, file to save figure under
        Lambda : (Unnormalized) Sensitivity Matrix
        Omega  : Cov. of GMM moments (for normalization)
        sig1, sig2 : Estimates for sigma1 and sigma2

    OUTPUT:
        Figure 5, saved to fname
    """

    SMatrix = Lambda*(np.sqrt(np.diag(Omega)))
    
    #Delta Mathod to get sensitivity for s1^2/(s1^2+s2^2)
    D = np.zeros(18)
    D[14] = (2*sig1*(sig2**2))/((sig1**2+sig2**2)**2)
    D[15] = (-2*sig2*(sig1**2))/((sig1**2+sig2**2)**2)
    
    #Overwrites senstivity of sig2 with sensitivity for s1^2/(s1^2+s2^2)
    SMatrix[15] = np.dot(D, SMatrix)
    
    paramNames = [r'$\lambda_1$', r'$\lambda_2$', r'$\sigma_1^2/(\sigma_1^2 + \sigma_2^2)$', r'$\phi_2$'] 
    paramIDs   = [16, 17, 15, 12]

    momentNames = (r'Pollution Resid.$\times T$', r'Pollution Resid.', r'Pollution Resid.$\times X_1$',
                   r'Pollution Resid.$\times X_2$', r'Pollution Resid.$\times X_3$', r'Pollution Resid.$\times X_4$',
                   r'Pollution Resid.$\times X_5$', r'Inspection Mean$\times T$', r'Inspection Mean',
                   r'Inspection Mean$\times X_1$',  r'Inspection Mean$\times X_2$', r'Inspection Mean$\times X_3$', 
                   r'Inspection Mean$\times X_4$', r'Inspection Mean$\times X_5$', r'Insp. Squared Mean$\times T$', 
                   r'Insp. Squared Mean', r'Prob($Run$)', r'$E[c_j | Run]$', r'Var(Pollution)', r'Cov(Pollution, Insp.)')

    #Select Moments to display
    selectMomentIDs = [0, 1, 7, 8, 14,15,16,17,18,19]
    selectMomentNames = [momentNames[ID] for ID in selectMomentIDs]
    selectSMatrix = np.array([[SMatrix[i][ID] for ID in selectMomentIDs]
                                for i in range(len(SMatrix))])

    y_pos = np.arange(len(selectMomentNames))
    x_pos = [[0,2,4],
             [0,100,200],
             [0,0.25,0.5],
             [0,4,8]]
    

    #plt.rc('text', usetex=True)
    plt.rc('font', family='serif')

    fig, ax = plt.subplots(1,4)
    fig.suptitle("Sensitivity of Parameter")
    
    for i in range(len(paramIDs)):
        sensitivity = selectSMatrix[paramIDs[i]]
        name        = paramNames[i]

        C = signColors(sensitivity)

        xMax = np.amax(abs(sensitivity))

        ax[i].barh(y_pos, abs(sensitivity), color=C, edgecolor='black')
        ax[i].set_yticks(y_pos)
        ax[i].set_xticks(x_pos[i])
        if i == 0:
            ax[i].set_yticklabels(selectMomentNames)
            ax[i].set_ylabel("Selected Moments")
        else:
            ax[i].set_yticklabels(['' for j in range(len(selectMomentNames))])
        ax[i].invert_yaxis()
        ax[i].set_title(name)

    fig.subplots_adjust(left=0.25,right=0.9)
    fig.set_size_inches(10,5)
    plt.savefig(fname)
    plt.close()


   

