function [ I, lnP, Run, c ] = ...
    generateRunData( S, X, T, u, AbsV, rho, sigc, beta, phi, muc, sigma, lambda )
%generateRunData Calculate inspections, pollution and costs given plant
%  observable characteristics, pollution and cost shocks and a vector of
%  model parameters.
%
% INPUTS:
%   S    - number of datasets (simulated draws from the DGP)
%   u    - N x S x 3 array of N(0,1) errors for u_1, u_2 and u_c (cost)
%   X    - design matrix  
%   beta - inspection equation coefficients
%   phi  - pollution equation coefficients
%   muc   - mean of log cost distribution
%   sigma - {sig1, sig2, sigc} where sig1 = standard deviation, common
%           error, sig2 = standard deviation, pollution-only error and 
%           sigc = standard deviation, log maintenance cost
%   lambda - parameters of targeting function
% 
% OUTPUTS:
%   X  - Plant covariate of 'dirtiness'
%   T  - Treatment assignment

% Transform errors from N(0,1) to scaled distributions, given parameters.
%   Need this step to hold draws fixed as we adjust parameters across 
%   simulations
u(:,:,1) = sigma(1) * u(:,:,1);
u(:,:,2) = sigma(2) * u(:,:,2);
c        = exp( muc + sigc * u(:,:,3) ); % Log-normal cost
% c        = - muc * log( 1 - u(:,:,3) );    % Exponential cost

% N x S datasets of pollution and inspections [slowest lines repmats here]
%   Latent pollution
lnPsHat = repmat( X * phi(1:end-1), [1 S]);
lnPs    = lnPsHat + u(:,:,1) + u(:,:,2);

%   Latent inspections
Is    = targetPhiFun( lambda, sigma(1), rho );
IHat  = repmat([X(:,2:end) T] * beta, [1 S]);

% Calculate inspections for each plant given observable shock
I  = Is( IHat + u(:,:,1) );

% Run decision and pollution
Ps  = exp(lnPs);
Run = ( I .* ( ppval(AbsV,Ps*exp(phi(end))) - ppval(AbsV,Ps) ) > c );  

c   = Run .* c;
lnP = lnPs + phi(end)*Run;

end
