function [ prRun, EcRun, Ec15Run, Ec2Run, Ec3Run ] = generateRunDataObservedP( ...
                                    u, phi, sig1, sig2, muc, sigc, ...
                                    lnPsHat, IHat, Is, AbsV )
%generateRunDataObserved Use latent pollution and inspections, draws of 
%   pollution and cost shocks and optimal inspection targeting rule to
%   produce data on runs, costs and errors to match to observed moments.
%
% INPUTS:
%   AbsV - penalty function giving V_0(p) where p is in units of standard
%   u    - N x S x 3 array of N(0,1) errors for u_1, u_2 and u_c (cost)
%   phi  - pollution equation coefficients
%   muc   - mean of cost distribution, which may be assumed log normal or
%           exponential depending on the code used below
%   sigma - {sig1, sig2, sigc} where sig1 = standard deviation, common
%           error, sig2 = standard deviation, pollution-only error and 
%           sigc = standard deviation, log maintenance cost.  If using the
%           exponential distribution of cost this parameter is ignored.
%   lnPsHat - Predicted value of latent log pollution
%   IHat    - Predicted value of latent inspections
%   Nbar    - Mean per plant inspections in control
%   Is      - optimal level of residual inspections for each u1 shock
%             Expressed as a spline in pp form from shock to inspections.
%   u1      - vector of observable pollution shocks at which I*(u1) is
%             evaluated.
% 
% OUTPUTS:
% New outputs:
%   I       - N x S matrix of inspections for each plant and simulation
%   lnP     - N x S matrix of log pollution for each plant and simulation
%
% Old outputs:
%   Run     - N x S matrix of run decisions for each plant and simulation
%   cs      - N x S matrix of cost, conditional on running, for each plant
%   e1      - N x S matrix of error in inspection equation I*(u1)
%   e2      - N x S matrix of error in pollution equation u1 + u2

%% Calculate abatement cost for each plant

% Transform shocks to have correct variance
%   Transform errors from N(0,1) to scaled distributions, given parameters.
%   This holds draws fixed as we adjust parameters across simulations.
u(:,:,1) = sig1 * u(:,:,1);
u(:,:,2) = sig2 * u(:,:,2);
% c        = exp( muc + sigc * u(:,:,3) ); % Not needed; analytic form 

%% Calculate inspections for each plant
I  = Is( IHat + u(:,:,1) );

%% A. Cost distribution log normal
% Probability of running equipment and expected cost
%    - Calculate analytic value for each combination of pollution shocks
%    - Sum across pollution shocks

% Latent pollution
e2   = u(:,:,1) + u(:,:,2);
lnPs = lnPsHat + e2;
Ps   = exp(lnPs);

% Threshold of highest cost at which abatement would be observed
cbar  = I .* ( ppval(AbsV,Ps*exp(phi(end))) - ppval(AbsV,Ps) );
b0    = max( (log(cbar)-muc)/sigc, -20 );  % Truncate b0 to avoid NaN

% Probability of Run, in a single simulation draw
if ~isreal( b0 )
   fprintf(1,'Wait!'); 
end
prRun = normcdf( b0 );

% Expected maintenance cost and cost squared, conditional on Run
EcRun   = exp(muc + sigc^2/2) * normcdf(-sigc + b0) ./ normcdf(b0);
Ec15Run = exp(1.5*muc + 2.25*sigc^2/2) * normcdf(-1.5*sigc + b0) ./ normcdf(b0);
Ec2Run  = exp(2*muc   + 4*sigc^2/2) * normcdf(-2*sigc + b0) ./ normcdf(b0);
Ec3Run  = exp(3*muc   + 9*sigc^2/2) * normcdf(-3*sigc + b0) ./ normcdf(b0);

%% B. Cost distribution exponential
% Probability of running equipment and expected cost
%    - Calculate analytic value for each combination of pollution shocks
%    - Sum across pollution shocks

% % Latent pollution
% Ps   = exp(lnPsHat + u(:,:,1) + u(:,:,2));
% 
% % Threshold of highest cost at which abatement would be observed
% cbar  = I .* ( ppval(AbsV,Ps*exp(phi(end))) - ppval(AbsV,Ps) );
% cbar  = max( cbar, 1e-10 );
% 
% % Probability of Run, in a single simulation draw
% prRun = 1 - exp( -cbar / muc );
% 
% % Expected maintenance cost and cost squared, conditional on Run
% k      = cbar / muc;
% EcRun  = muc * (1 - (k+1).*exp(-k)) ./ (1 - exp(-k));
% Ec2Run = 2 * muc^2 * (1 - 0.5*(k.^2 + 2*k + 2).*exp(-k)) ./ (1 - exp(-k));
% Ec15Run = Ec2Run; % Do not use this moment; just a placeholder for output

%% Run decision and observed pollution in the model
% Run = ( I .* ( ppval(AbsV,Ps*exp(phi(end))) - ppval(AbsV,Ps) ) > c );  
% lnP = lnPs - phi(end).*Run;

end
