function [ f, g, Omega, N ] = gmm7( theta, W, rho, sigc, ...
                                    lnP, I, IJ, J, Run, c, X, T, XT, XTwt, ...
                                    AbsV, us, uI, signs, lengths )
% gmm6 Objective function for IV estimation
%    
% INPUTS:
%   theta - Parameter values for:
%             Inspection equation beta = {beta_X beta_T}
%             Pollution equation phi = {phi0 phi1 phi2}
%             Error parameters: kc log(sigmac) sigma1 sigma2
%             Targeting parameters: lambda_0, lambda_1
%   lnP   - log plant pollution vector N x 1
%   I     - plant inspection vector N x 1
%   IJ    - mean plant inspections aggregated by observables
%           IJ(:,1) is mean plant inspections, IJ(:,2) mean plant insp^2.
%   J     - indices for combinations of observables and treatment
%           assignment, at the plant observation level
%   Run   - plant abatement operating decision
%   c     - plant maintenance cost for abatement
%   X     - design matrix for estimation  
%   T     - treatment status to be used in instrument
%   XT    - combinations of observables and treatment assignment, by type
%   XTwt  - numbers of plants with each XT combination
%   AbsV  - value of reducing pollution as a function of pollution level
%   us    - N x S x 3 array of N(0,1) errors for u_1, u_2 and u_c (cost)
%   uI    - 127 x 2 matrix of N(0,1) errors at which to evaluate
%           regulator's objective function on each iteration
%   known - known parameters in the objective function
%
% OUTPUTS:
%   gval - value of objective function
N    = size(X,1);

% Unpack parameters from theta vector
[ beta, phi, muc, sigma, lambda, ~ ] = unpackThetaV3( theta, 1, signs, lengths );
sig1  = sigma(1);
sig2  = sigma(2);
% sigc  = sigma(3); % Uncomment if estimating sigma_c, comment if calibrating

%% Calculate moments

% Instruments
Z1  = ones(N,1);
Z1i = ones(size(Z1,2),1);

Z2  = [ T Z1 ];
Z2i = ones(size(Z2,2),1);

Z3  = [ T X ];
Z3i = ones(size(Z3,2),1);

% Moment 1: pollution reduction orthogonal to treatment, conditional
%   on running equipment
e2hat = lnP - [X Run] * phi;
g1    = Z3' .* e2hat(:,Z3i)'; 

% Simulate inspection targeting.
%   This function takes the parameters lambda of the optimal targeting 
%   function, from the outer loop, then calculates for S simulation draws
%     - The number of inspections the plant will receive
%     - The run decisions and observed costs of each plant
[ Pr, Ec, Ec15, Ec2, Ec3 ] = ...
    simulateRunGivenTargeting( us, uI, X, T, XT, XTwt, AbsV, beta, ...
                              phi, muc, sigc, sig1, sig2, rho, lambda );

% Moment 2: expected values of inspections, by observable characteristics
[ EI, EI2, e2XI, e2XI2 ] = expectedInspectionsP( lambda, beta, sig1, rho, XT, XTwt );

g2 = (I - EI(J) );
g2 = Z3' .* g2(:,Z3i)';

g3 = (I.^2 - EI2(J) );
g3 = Z2' .* g3(:,Z2i)';

% Moment 3: probability of incurring abatement cost and expected cost
%   (3) probability of running equipment 
%   (4) cost conditional on running equipment
g4  =         ( Run  - Pr  )';
g5  = Run' .* ( c    - Ec  )';

% g5  = Run .* ( c    - Ec  );
% g5  = Z2' .* g5(:,Z2i)';

% g6a = Run' .* ( c.^1.5 - Ec15 )';
% g6b = Run' .* ( c.^2   - Ec2 )'; 
% g6c = Run' .* ( c.^3   - Ec3 )';

% Moment 4: variances of pollution shocks and covariance of pol-insp shocks
%   First term in each moment is the simulated value for each plant across
%   S simulations of the model at a fixed set of parameters. Second term in
%   each moment is the analogous statistic in the data.
sigp2 = sig1^2 + sig2^2;
g7    = ( e2hat.^2 - sigp2 )'; % Pollution shock variance
g8    = ( e2hat.*I - e2XI(J) )'; % Pol shock and inspection cov 

% g8    = Z2' .* g8(:,Z2i)';
% g9    = Z1' .* ( e2XI2(J) - e2hat.*I.^2 )'; % Pol shock and inspection^2 cov

%% Calculate objective
gi = [ g1; g2; g3; g4; g5; g7; g8 ];
% gi = [ g1; g2; g3; g4; g5; g6a; g6b; g7; g8 ];

sc = ones(size(gi,1),1);
% sc(end-2)       = 1e2;
% sc(end-1:end)   = 1e2; 
% sc(end-1) = 1e1;
% sc(end)   = 1e-1;
g  = gi * Z1 ./ N .*sc;

if isempty(W)
    W = eye(length(g));
end
f  = g' * W * g;        

% Covariance of moments
Omega = gi * gi' ./ N;
 
end

