function [ cineq, ceq ] = inspectionTargetingFOC( theta, uI, Nbar, ...
                                                  rho, sigc, XT, XTwt, AbsV, ...
                                                  signs, lengths )
%solveInspectionTargetingS Calculate regulator's optimal targeting rule 
%  from residual pollution shocks to residual inspections. This is the "S"
%  or smooth version of the function, in which the targeting rule is a
%  pchip spline (once-continuously-differentiable). The base version of
%  this function solves for a discrete inspection targeting rule.
%
% INPUTS:
%   lamgam - vector of [lambda0; lambda1; gamma] where gamma is Lagrange
%            multiplier on the budget constraint.
%   uI     - 127 x 2 matrix of N(0,1) errors at which to evaluate
%            regulator's objective function on each iteration
%   Nbar    - predicted latent level of inspections
%   lnPsHat - predicted latent level of pollution
%   sig1    - std dev of observable (to regulator) pollution shock
%   sig2    - std dev of unobservable (to regulator) pollution shock
%   muc     - mean of abatement cost shock
%   sigc    - std dev of abatement cost shock
%   phi     - pollution equation coefficients on [constant X Run] 
%   AbsV    - penalty function
%
% OUTPUTS:
%   lamHat  - targeting parameters {lambda0,lambda1}
%   Is      - optimal level of residual inspections for each u1 shock

%% Unpack parameters from theta vector
[ beta, phi, muc, sigma, lambda, ~ ] = unpackThetaV3( theta, 1, signs, lengths );
sig1  = sigma(1);
sig2  = sigma(2);
% sigc  = sigma(3);
% lamgam = [lambda; gamma];

% Scale shocks at which objective function is evaluated
u1e = sig1 * uI(:,1); % u1 draws with estimated variance
u2e = sig2 * uI(:,2); % u2 draws with estimated variance


%% Gradient of the lagrangian (constrained problem)
group    = 1; % Control group
[ grad ] = abatement2DsGradCon( lambda, beta, phi, XT, XTwt, u1e, u2e, ...
                                muc, sigc, sig1, rho, AbsV, group );

                            
%% Inspection budget constraint
Nineq = abateBudgetPhi( lambda, beta, sig1, rho, XT, XTwt, Nbar, group ); 


%% Form FOCs to output dLdLam1, dLdLam2, dLdGam
if group == 1
    N    = sum( XTwt( XT(:,end) == 0 ) );
else
    N    = sum( XTwt(:) );
end
focs = [ grad; N*Nineq ];

cineq = [];
% ceq   = focs;
ceq   = focs.^2;

% fobj = sum(focs.^2);
    
end

