function [ Pr, Ec, Ec15, Ec2, Ec3 ] = ...
    simulateRunGivenTargeting( u, uI, X, T, XT, XTwt, AbsV, beta, phi, ...
                               muc, sigc, sig1, sig2, rho, lambda )
%simulateRunDataWtargeting Function to calculate simulated moments on probability
%  of running equipment and expected value of run cost, conditional on
%  doing so.
%
% INPUTS:
%   u    - N x S x 3 array of N(0,1) errors for u_1, u_2 and u_c (cost)
%   uI    - 127 x 2 matrix of N(0,1) errors at which to evaluate
%           regulator's objective function on each iteration
%   X    - design matrix where dimension of X may vary
%   AbsV - penalty function giving V_0(p) where p is in units of standard
%   beta - inspection equation coefficients
%   phi  - pollution equation coefficients
%   muc  - shape parameter of cost distribution
%   sigc - scale parameter of cost distribution
%   sig1 - standard deviation, common error
%   sig2 - standard deviation, pollution error
%   lambda - targeting parameters
% 
% OUTPUTS:
%   Pr    - Probability of plant running equipment
%   Ec    - Expected cost conditional on running equipment
%   e1_2  - Expected variance of inspection shock
%   e1_e2 - Expected covariance of inspection and pollution shocks
N  = size(X,1);
S  = size(u,2);

% 1. Generate latent pollution and inspection levels given parameters.
%   This data are plant-level means based on parameters and do not require
%   the structure of shocks or differ by simulation run
[ lnPsHat, IHat ] = generateRunDataLatent( X, T, phi, beta, S );

% 2. Set inspection targeting function given parameters.
%   Inspection targeting rule is a function from unobserved pollution
%   shocks to residual inspections.
Is = targetPhiFun( lambda, sig1, rho );                            
                                   
% 3. Generate Run decision and Inspection data given 1. and 2. 
%   Final run decisions and targeting decision depend on shocks and
%   therefore vary across simulations.
[ prRun, EcRun, Ec15Run, Ec2Run, Ec3Run ] = ...
    generateRunDataObservedP( u, phi, sig1, sig2, muc, sigc, lnPsHat, ...
                              IHat, Is, AbsV );               
                                            
% 4. Calculate simulated moments to be used in estimation.  
%   Summing over simulation draws along second dimension.
%      - Probability of Run == 1
%      - Cost of abatement | Run == 1
Pr     = mean(prRun,2);                    % Probability of run
SprRun = sum(prRun,2);
Ec     = sum(prRun .* EcRun,2)   ./ SprRun; % Cost     | Run==1
Ec15   = sum(prRun .* Ec15Run,2) ./ SprRun; % Cost^1.5 | Run==1
Ec2    = sum(prRun .* Ec2Run,2)  ./ SprRun; % Cost^2   | Run==1
Ec3    = sum(prRun .* Ec3Run,2)  ./ SprRun; % Cost^3   | Run==1

end