function [ lambda, cabate, tabate ] = solveInspectionTargetingP( uI, Nbar, ...
                           beta, phi, rho, XT, XTwt, ...
                           sig1, sig2, muc, sigc, AbsV, group )
%solveInspectionTargetingS Calculate regulator's optimal targeting rule 
%  from residual pollution shocks to residual inspections. This is the "S"
%  or smooth version of the function, in which the targeting rule is a
%  pchip spline (once-continuously-differentiable). The base version of
%  this function solves for a discrete inspection targeting rule.
%
% INPUTS:
%   uI    - 127 x 2 matrix of N(0,1) errors at which to evaluate
%           regulator's objective function on each iteration
%   Nbar    - predicted latent level of inspections
%   lnPsHat - predicted latent level of pollution
%   sig1    - std dev of observable (to regulator) pollution shock
%   sig2    - std dev of unobservable (to regulator) pollution shock
%   muc     - mean of abatement cost shock
%   sigc    - std dev of abatement cost shock
%   phi     - pollution equation coefficients on [constant X Run] 
%   AbsV    - penalty function
%   group   - Set of plants to target {0=all, 1=control, 2=representative}
%
% OUTPUTS:
%   lamHat  - targeting parameters {lambda0,lambda1}
%   Is      - optimal level of residual inspections for each u1 shock

% Scale shocks at which objective function is evaluated
u1e = sig1 * uI(:,1); % u1 draws with estimated variance
u2e = sig2 * uI(:,2); % u2 draws with estimated variance

% Set regulatory objective function, as a function of targeting parameters
%   1 probability of abatement 2 probability of compliance 3 pollution
abateObj2 = @(x) abatement2DsGrad( x, beta, phi, XT, XTwt, u1e, u2e, ...
                                   muc, sigc, sig1, rho, AbsV, group );
                             
% Solve optimal targeting rule with 2-dimensions of pollution shock
%   Display 'iter' for troubleshooting; display 'off' for runs
% foptions = optimoptions(@fmincon,'Display','iter',...
%                         'Algorithm','interior-point',...
%                         'TolFun',1e-15,'TolX',1e-15,...
%                         'TolCon' ,1e-15,'MaxIter',1e4,...
%                         'MaxFunEvals',1e6,'GradObj','on',...
%                         'DerivativeCheck','on','FinDiffType','central');

foptions = optimset('Display','iter',...
        'Algorithm','interior-point',...
        'TolFun',1e-15,'TolX',1e-15,...
        'TolCon' ,1e-15,'MaxIter',1e4,...
        'MaxFunEvals',1e6,'GradObj','on',...
        'DerivativeCheck','on','FinDiffType','central');
                    
% Initial targeting and non-linear budget constraint
group = 1;
NL    = @(x) abateBudgetPhi( x, beta, sig1, rho, XT, XTwt, Nbar, group ); 
LB    = [ -10*rho;      0 ];
UB    = [  10*rho;    Inf ];
%lam0  = [       0;      5 ];    
lam0  = [ -0.3826; 32.7101];

% Solve for optimal targeting rule given budget constraint
[ lambda, fval ] = fmincon(abateObj2,lam0,[],[],[],[],LB,UB,NL,foptions); 
cabate = - fval;

% Abatement in both treatment and control groups
group     = 0;
abateObj2 = @(x) abatement2DsGrad( x, beta, phi, XT, XTwt, u1e, u2e, ...
                                   muc, sigc, sig1, rho, AbsV, group );
tabate = - abateObj2( lambda );
                               
end

