function [ ] = tabImportantMoments(fname, Lambda, OmegaHat)
%print the top two most important moments from Genztkow sensitivity matrix 
%   fid     :   File id
%   title   :   String with table title
%   Lambda  :   Genztkow sensitivity matrix to be printed
%   OmegaHat:   The covariance matrix of the moments, for standardization
%%%%%%%%%

fid = fopen(fname, 'w');

%Standardize Lambda: Multiply jth column of Lambda by sqrt(Omega_{jj})
%This allows us to interpret Lambda as the effect of a one standard
%deviation change in a moment on the estimated parameters
Lambda = Lambda*sqrt(diag(diag(OmegaHat)));


%Get the top four largest moments, by absolute value
[~, sortedInd] = sort(abs(Lambda),2,'descend');
topMoments = sortedInd(:,1:4);


%%Formatting
formatH = ['\n %15s',repmat('& %15s',1,8),'\\\\ \n'];
formatN = [repmat('& (%1d) ', 1, 8), '\\\\ \\midrule \n'];
format  = ['%15s & %15s & %15.3f & %15s & %15.3f & %15s & %15.3f & %15s & %15.3f \\\\ \n'];

preamble = ['\\begin{landscape} \n \\begin{table} \n \\centering \n \\ra{1.4} \n \\footnotesize',...
            '\\begin{threeparttable} \n',...
            '\\caption{Most Influential Moments for Selected Parameters} \n',...
            '\\begin{tabular}{ l  @{} C{3.7cm} @{} C{1.3cm} @{}',...
            'C{3.7cm} @{} C{1.3cm} @{} C{3.7cm}  @{}',...
            'C{1.3cm} @{} C{3.7cm} @{} C{1.3cm}  } \\toprule'];
        
            
            
postscript = ['\n \\bottomrule \n \\end{tabular} \n \\begin{tablenotes} \n',...
              '\\footnotesize \n \\item Note: This table presents the names and values of the ',...
              'four moments with the largest absolute value of sensitivity for ',...
              'each parameter. The sensitivities are scaled so that the entries ',...
              'can be read as the effect of a one-standard-deviation violation of ',...
              'the given moment condition on the asymptotic bias of the given parameter. ',...
              'The magnitudes are thus comparable across moments for a given parameter, ',...
              'and can be interpreted as the degree of influence of a moment ',...
              'on the estimated parameter. \n \\end{tablenotes} \n',...
              '\\end{threeparttable} \n \\end{table} \n \\end{landscape}'];


MomentList={'Pollution Resid.$\times T$', 'Pollution Resid.',...
            'Pollution Resid.$\times X_1$', 'Pollution Resid.$\times X_2$'...
            'Pollution Resid.$\times X_3$', 'Pollution Resid.$\times X_4$'...
            'Pollution Resid.$\times X_5$', ...
            'Insp. Mean$\times T$', 'Inspection Mean',...
            'Insp. Mean$\times X_1$', 'Insp. Mean$\times X_2$',...
            'Insp. Mean$\times X_3$', 'Insp. Mean$\times X_4$',...
            'Insp. Mean$\times X_5$', ...
            'Insp. Squared Mean$\times T$', 'Insp. Squared Mean',...
            'Prob($Run$)', '$E[c_j | Run]$', 'Var(Pollution)',...
            'Cov(Pollution, Inspection)'};

colHeads = {'Variable', 'Most Influential Moment', 'Value', ...
                         '2nd Most Influential Moment', 'Value', ...
                         '3rd Most Influential Moment', 'Value',...
                         '4th Most Influential Moment', 'Value'};
                    
rowHeads = {'aud treatment ($\beta_1^1$)','aud $\times$ insp. treat. ($\beta_1^2$)', ...
            'aud sample ($\beta_1^3$)', 'reg abd ($\beta_1^4$)', 'reg sur ($\beta_1^5$)', ...
            'insp. treatment ($\beta_2$)', 'constant ($\phi_0$)', ...
            'aud treatment ($\phi_1^1$)','aud $\times$ insp. treat. ($\phi_1^2$)', ...
            'aud sample ($\phi_1^3$)', 'reg abd ($\phi_1^4$)', 'reg sur ($\phi_1^5$)',...
            'Run ($\phi_2$)', 'Mean Maintenance Cost ($\mu_c$)','SD Observed Shock $\sigma_1$', ...
            'SD Unobserved Shock ($\sigma_2$)', 'Inspection Shift ($\lambda_1$)',...
            'Inspection Level ($\lambda_2$)'};
                    
R = size(Lambda, 1); %Number of rows

SelectedIndices = [6, 13, 17,18, 7, 15, 16, 14];

fprintf(fid,preamble);
fprintf(fid,formatH,colHeads{:});
fprintf(fid,formatN,1:8);
for r=SelectedIndices
    topMoments(r,:);
    m1 = topMoments(r,1);
    m2 = topMoments(r,2);
    m3 = topMoments(r,3);
    m4 = topMoments(r,4);
    n1 = MomentList{m1};
    n2 = MomentList{m2};
    n3 = MomentList{m3};
    n4 = MomentList{m4};
    v1 = Lambda(r, m1);
    v2 = Lambda(r, m2);
    v3 = Lambda(r, m3);
    v4 = Lambda(r, m4);
    
    fprintf(fid, format, rowHeads{r}, n1, v1, n2, v2, n3, v3, n4, v4);
end
fprintf(fid,postscript);

                    
            