function [ ] = printSelectSensitivities(fname, Lambda, OmegaHat)
%print selected standardized Genztkow sensitivity matrix nicely
%   fname     :   File id
%   title   :   String with table title
%   Lambda  :   Genztkow sensitivity matrix to be printed
%   OmegaHat:   The covariance matrix of the moments, for standardization
%%%%%%%%%

fid = fopen(fname, 'w');

%Standardize Lambda: Multiply jth column of Lambda by sqrt(Omega_{jj})
%This allows us to interpret Lambda as the effect of a one standard
%deviation change in a moment on the estimated parameters
Lambda = Lambda*sqrt(diag(diag(OmegaHat)));

%Transpose matrix, rows are moments, columns are params
Lambda = Lambda'; 

% Check format string and apply default
formatHS = ['\n \n  %15s',repmat('& %15s',1,8),'\\\\ \n'];
formatNS = [repmat('& (%1d)', 1,8), '\\\\ \\midrule \n'];
formatS = ['%15s',repmat('& %15.3f', 1, 8), '\\\\ \n'];


R = size(Lambda, 1); %Number of rows

preamble = ['\\begin{table}  \n', ...
            '\\caption{Sensitivities for Selected Parameters}  \n', ...
            '\\begin{threeparttable}  \n', ...
            '\\begin{tabular}{ l  C{1.9cm}  c  c  c  c  c  c  c } \\toprule \n'];
        
postscript = ['\\bottomrule \n \\end{tabular} \n \\begin{tablenotes}', ...
              '\\footnotesize \n \\item Note: This table presents values from ',...
              'the estimated sensitivity matrix $\\Lambda$, scaled so that the ',...
              'entries can be read as the effect of a one-standard-deviation ',...
              'violation of the given moment condition on the asymptotic bias ',...
              'of the given parameter. For the column of corresponding to a given ',...
              'parameter, we can interpret the entries as the sensitivity of the ',...
              'estimated parameter to beliefs about the degree of misspecification ',...
              'of each moment, expressed in standard deviations. Alternatively, we ',...
              'can interpret the estimated sensitivities as a measure of how estimates ',...
              'will respond to changes in the underlying data. While sensitivity is ', ...
              'computed with respect to the complete set of variables, the table ',...
              'shows only a subset of particular interest. \n \\end{tablenotes}',...
              '\n \\end{threeparttable} \n \\end{table}'];




rowHeads = {'Pollution Resid.$\times T$', 'Pollution Resid.',...
            'Pollution Resid.$\times X_1$', 'Pollution Resid.$\times X_2$'...
            'Pollution Resid.$\times X_3$', 'Pollution Resid.$\times X_4$'...
            'Pollution Resid.$\times X_5$', ...
            'Inspection Mean$\times T$', 'Inspection Mean',...
            'Inspection Mean$\times X_1$', 'Inspection Mean$\times X_2$',...
            'Inspection Mean$\times X_3$', 'Inspection Mean$\times X_4$',...
            'Inspection Mean$\times X_5$', ...
            'Insp. Squared Mean$\times T$', 'Insp. Squared Mean',...
            'Prob($Run$)', '$E[c_j | Run]$', 'Var(Pollution)',...
            'Cov(Pollution, Insp.)'};

            
colHeadsS = {'Moment', '$\beta_2$', '$\phi_2$', '$\lambda_1$', '$\lambda_2$', ...
                '$\phi_0$', '$\sigma_1$', '$\sigma_2$', '$\mu_c$'};
 
%Print table with selected parameters 


fprintf(fid, preamble);
fprintf(fid, formatHS,colHeadsS{:});
fprintf(fid,formatNS,1:8);
for r=1:R
    fprintf(fid, formatS, rowHeads{r}, Lambda(r,6), Lambda(r,13), ...
        Lambda(r,17), Lambda(r,18), Lambda(r,7), Lambda(r,15), Lambda(r,16), ...
        Lambda(r,14));
end
fprintf(fid, postscript);



end