%% Monte carlo estimation of regulatory targeting model
%  Author  : Nick Ryan
%  Date    : 13 May, 2015
%            Rev 31 May, 2016
%  Project : Analysis of GPCB inspection intervention.

% Set directories for targeting code and data
%   Call file from /replication/code/03_targeting_stage
clear;
cd ../../;
root = pwd;

code    = [root,'/code/03_targeting_stage/'];
data    = [root,'/data/03_targeting_stage/'];
penalty = [root,'/code/02_penalty_stage/'];
tables  = [root,'/output/tables'];
figures = [root,'/output/figures'];

addpath(code);
addpath(penalty);


%% ========================================================================
% Figure 1, Panel A: Effect of Treatment on Pollution Distribution
%==========================================================================

cd(data);
file = 'binned_regression_pollutant.csv';
x       = dlmread(file,',',1,0);
vnames  = textread(file,'%s',size(x,2),'delimiter',',');
cd(code)

id   = x(:,1);
%P    = log(x(:,4));  % Pollution relative to regulatory limit, limit units
P    = x(:,2);  % Pollution relative to regulanctory limit, sd units
TI   = x(:,3) == 1; % Inspection treatment status

X1      = [ x(:,4:8) ones(length(x),1) ];
X1names = [ vnames(4:8);'constant']; 

% Plot effect of inspection treatment on binned pollution readings
cd(figures)
file = sprintf('Figure1A_Treatment_On_Pollution_Bins.pdf');
plotTreatByBin( file, P, TI, X1 );


%% ========================================================================
%      Load data on inspections, pollution and plant characteristics
%==========================================================================

% Chains estimation data file, most recent
cd(data);
file    = 'targeting_estimation_plant_080515.csv';
x       = dlmread([data,file],',',1,0);
vnames  = textread([data,file],'%s',size(x,2),'delimiter',',');
cd(code);

N    = size(x,1);
id   = x(:,1);
lnP  = log(x(:,4));  % Pollution relative to regulatory limit
I    = x(:,6);       % Chains per year
c    = x(:,9);       % Maintenance cost
TI   = x(:,10) == 1; % Inspection treatment status
TA   = x(:,11) == 1; % Audit treatment status
TAxI = TA .* TI;     % Inspection X audit treatment

X1      = [ TA TAxI x(:,12:14)  ];
X1names = [vnames(11);'Aud X Ins treat';vnames(12:14)]; 
X2      = x(:,15:17);
X2names = vnames(15:17);
X3      = x(:,18:end);
X3names = vnames(18:end);
X4      = [ x(:,21) x(:,27) ];
X4names = [vnames(21); vnames(27)];

X      = [  ones(N,1)  X1      ];
Xnames = [ 'constant'; X1names ];

% Decision to run abatement equipment
Run     = c > 0;

% Create observable 'types' of plants, where J indexes types
[ XT, ~, J ] = unique( [X(:,2:end) TI], 'rows' );
XTwt         = accumarray(J,ones(size(J)));

IJ = [ accumarray(J,I,[],@mean), accumarray(J,I.^2,[],@mean) ];


%% Load penalty function
cd([root,'/data/02_penalty_stage/']);
load('penalty_function.mat');

% Continuous and differentiable spline penalty function
%   Fit additional control points to allow reasonable values outside
%   domain of the original penalty function. Evaluate with ppval(AbsV,p).
pbins   = [ 1.0 1.5 3.5 7.5 ]';
pbinsEx = [0; pbins; 11.5];
VpEx    = [-1; Vp(2:end,3); 2*Vp(end,3)-Vp(end-1,3)];
AbsV    = pchip(pbinsEx,VpEx);



%% ========================================================================
% Figure 7: Model Fit to Inspections and Pollution
%    Panel A. Initial Inspections, Control (Data)
%    Panel B. Initial Inspections, Treatment (Data)
%    Panel E. Pollution (Data)
%==========================================================================

cd(figures)

% Panel A. Initial Inspections, Control (Data)
file = 'Figure7A_Inspections_Control_Data.pdf';
plotInspectionDist( file, I, TI, 'Control' )

% Panel B. Initial Inspections, Treatment (Data)
file = 'Figure7B_Inspections_Treatment_Data.pdf';
plotInspectionDist( file, I, TI, 'Treatment' )

% Panel C. Pollution (Data)
file = 'Figure7E_Pollution_Data.pdf';
plotPollutionDist( file, lnP, [0 10], [0 250], 20 );


%% ========================================================================
%  Simulate targeting model with a single draw of pollution shocks
%%=========================================================================
cd(data)
load('target_theta_gmm2_ctop_constrained_2016_08_13.mat') % Paper estimates, constrained
% load('target_theta_gmm_logn_cost_sigc050_2017_07_26.mat') % Unconstrained, S=200

% If using constrained estimates
chgUnits = 0;
lengths  = [ 6 7 1 2 2 ]'; % Beta phi muc sigma lambda
signs   = [ zeros(1,lengths(1))       ...  % beta
            zeros(1,lengths(2)-1) -1  ...  % phi
            0 1 1 0 0 0 ]';                % muc, sigma, lambda, gamma

% If using unconstrained estimates
% signs   = [ zeros(1,lengths(1))      ...  % beta
%             zeros(1,lengths(2)-1) -1 ...  % phi
%             0 1 1 1 0 0 ]';                 % muc, sigma, lambda       
        
[ beta, phi, muc, sigma, lambda, ~ ] = ...
    unpackThetaV3( thetaHatD, chgUnits, signs, lengths );
rho  = 0.25;
sigc = 0.50; 

% Draw shocks for data generating process
%   u = [ u1, u2, uc ] for common error, pollution error and cost shock
%   t = [ t1, t2 ]     for observable covariates, treatment assignment
% rng(20150830);
rng(20160709);
S = 1;
u = randn(N,S,3);  % Log-normal cost distribution

% Generate data
[ Im, lnPm, ~, ~ ] = generateRunData( S, X, TI, u, AbsV, rho, sigc, ...
                                      beta, phi, muc, sigma, lambda );
                                           
%% ========================================================================
% Figure 7: Model Fit to Inspections and Pollution
%    Panel C. Initial Inspections, Control (Model)
%    Panel D. Initial Inspections, Treatment (Model)
%    Panel F. Pollution (Model)
%=========================================================================
cd(figures)

% Panel C. Initial Inspections, Control (Model)
file = 'Figure7C_Inspections_Control_Model.pdf';
plotInspectionDist( file, Im, TI, 'Control' )

% Panel D. Initial Inspections, Treatment (Model)
file = 'Figure7D_Inspections_Treatment_Model.pdf';
plotInspectionDist( file, Im, TI, 'Treatment' )

% Panel F. Pollution (Model)
file = 'Figure7F_Pollution_Model.pdf';
plotPollutionDist( file, lnPm, [0 10], [0 250], 20 );


%% ========================================================================
%%====================== Counterfactual regimes ===========================
%%=========================================================================
                                                                               
%% ========================================================================
% Figure 6: Observed and Optimal Targeting Rules
%==========================================================================

%% Load parameter estimates
cd(data)

% Unconstrained
load('target_theta_gmm_logn_cost_sigc050_2017_07_26.mat') % Paper, S=200
[ ~, ~, ~, sigmaUnc, lambdaUnc, ~ ] = ...
    unpackThetaV3( thetaHatD, chgUnits, signs, lengths );

% Constrained
load('target_theta_gmm2_ctop_constrained_2016_08_13');
[ beta, phi, muc, sigma, lambdaCon, ~ ] = ...
    unpackThetaV3( thetaHatD, chgUnits, signs, lengths );

% Set of observed and unobserved pollution shocks at which to evaluate
%   regulator's objective function. Use Halton draws to cover possible
%   standard normal shocks with minimal simulation variation.
H  = 31;
h  = haltonset(2,'Skip',1,'Leap',0);
h  = net(h,H);
uI = norminv(h,0,1);

% Create observable 'types' of plants, where J indexes types
[ XT, ~, J ] = unique( [X(:,2:end) TI], 'rows' );
XTwt          = accumarray(J,ones(size(J)));

%% Solve regulator's targeting rule
foptions = optimset('Display','iter','TolFun',1e-13,'TolX',1e-13,...
                     'TolCon' ,1e-13,'MaxIter',1e4,'MaxFunEvals',1e6);

% Inspection budget constraint for *control* inspections 
Nbar = 1.4708;  % 1.4708 in control group in experiment
group = 1;
                     
% Solve optimal targeting rule, with full information
sigpol2  = sigma(1)^2 + sigma(2)^2;
obsFrac  = 1.0;
sig1     = sqrt( obsFrac     *sigpol2 );
sig2     = sqrt( (1-obsFrac) *sigpol2 );

% Scale targeting function so that shape is not dependent on sigma1
scale    = sig1 ./ sigma(1);
scbeta   = scale * beta;
scrho    = scale * rho;

[ lambdaStar50 ] = solveInspectionTargetingP( uI, Nbar, scbeta, phi, scrho, ...
                                             XT, XTwt, sig1, sig2, ...
                                             muc, sigc, AbsV, group );
                                                                            
%% Plot optimal targeting rule under alternate regulatory regimes
%   Optimal rule maximizes abatement subject to budget constraint
%   Note: Targeting is plotted for Is( u ) only, with beta set to zero.
%   zero.  It therefore implicitly captures targeting for a firm with
%   no other covariates.
cd(figures)

% Recenter
XTb  = XT * beta;
ctrl = XT(:,end) == 0;
XTbMn = sum(XTb(ctrl,:) .* XTwt(ctrl)) / sum(XTwt(ctrl)) / rho;

% Targeting rule, unconstrained estimates
Is   = targetPhiFun( lambdaUnc, sigmaUnc(1), rho );

file = sprintf('Figure6_Targeting_Rule_Actual.pdf');
plotInspectionTargeting( file, Is, sigmaUnc(1), [-3.5 3.5], [0 8], 1, 'k-' );
hold on;
export_fig(file,'-painters','-m2');

% Optimal targeting rule
Is   = targetPhiFun( lambdaCon, sigma(1), rho );

file = sprintf('Figure6_Targeting_Rule_Optimal.pdf');
plotInspectionTargeting( file, Is, sigma(1), [-3.5 3.5], [0 8], 1, 'r--' );
hold on;
export_fig(file,'-painters','-m2');

% Optimal targeting rule, full information
Is   = targetPhiFun( lambdaStar50, sig1, scrho );

file = sprintf('Figure6_Targeting_Rule_All.pdf');
plotInspectionTargeting( file, Is, sig1, [-3.5 3.5], [0 8], 1, 'r:' );
hold on;
hist( uI(:,1) + XTbMn, 1000);

export_fig(file,'-painters','-m2');

          
%% ========================================================================
% Figure 8: Value of Discretion
%==========================================================================

% a. Value of discretion by budget constraint
%   Imperfect information (as estimated)
%   Assume a representative plant for targeting purposes.
cd(figures)

Nbar = [ 0.25 : 0.25 : 4 ]; % Overall inspection budget
Ncon = 1.4708;              % Control inspections, discretionary
Ntrt = max(Nbar-Ncon,0);    % Treatment inspections, non-discretionary

% Scale shocks at which objective function is evaluated
u1e = sigma(1) * uI(:,1); % u1 draws with estimated variance
u2e = sigma(2) * uI(:,2); % u2 draws with estimated variance

% Flag for sample in which to optimize
%   0 - All plants, 1 - Control plants, 2 - Representative plant
group = 0;
sigc  = 0.50;
 
% i. Abatement function: no discretion
abateObjND = @(x) abatement2Ds( [0 0]', beta, phi, XT, XTwt, u1e, u2e, ...
                                 muc, sigc, sigma(1), rho, AbsV, group, x );

% ii. Abatement function: full discretion
abateObjFD = @(x) solveInspectionTargetingP( uI, x, beta, phi, rho, ...
                                      XT, XTwt, sigma(1), sigma(2), ...
                                      muc, sigc, AbsV, group );
                                
% iii. Abatement function: partial discretion
[ lambdaStar ] = solveInspectionTargetingP( uI, Ncon, beta, phi, rho, ...
                                            XT, XTwt, sigma(1), sigma(2), ...
                                            muc, sigc, AbsV, group );
abateObjPD = @(x) abatement2Ds( lambdaStar, beta, phi, XT, XTwt, u1e, u2e, ...
                                 muc, sigc, sigma(1), rho, AbsV, group, x );

% Initialize output
mnabate = zeros( length(Nbar), 4 );
lambdas = zeros( length(Nbar), 2 );
for i = 1:length(Nbar) 
    
    % i. Calculate abatement at constant inspection rate
    mnabate(i,1) = abateObjND( Nbar(i) );
    
    % ii. Calculate abatement with full discretion over inspections
    [ lambdas(i,:), ~, mnabate(i,2) ] = abateObjFD( Nbar(i) );
    
    % iii. Calculate abatement with hybrid discretion (up to control level)
    %   and non-discretionary inspections added in treatment, up to budget
    if Ntrt(i) > 0
        mnabate(i,3) = abateObjPD( Ntrt(i) );
    else
        mnabate(i,3) = mnabate(i,2);
    end
    
end

% b. Value of discretion by budget constraint
%    Perfect information
cd(figures)

sigpol2  = sigma(1)^2 + sigma(2)^2;
obsFrac  = 1;
sig1     = sqrt( obsFrac     *sigpol2 );
sig2     = sqrt( (1-obsFrac) *sigpol2 );

% Scale targeting function so that shape is not dependent on sigma1
scale    = sig1 ./ sigma(1);
scbeta   = scale * beta;
scrho    = scale * rho;

abateObjFD = @(x) solveInspectionTargetingP( uI, x, scbeta, phi, scrho, ...
                                             XT, XTwt, sig1, sig2, ...
                                             muc, sigc, AbsV, group );
                                  
for i = 1:length(Nbar) 
    
    % ii. Calculate abatement with full discretion over inspections
    %       And assuming full information
    [ lambdas(i,:), ~, mnabate(i,4) ] = abateObjFD( Nbar(i) );
    
end

% c. Plot value of discretion by information regime
cd(figures)

file      = sprintf('Figure8_Value_of_Discretion.pdf');     
objective = 3; % Average reduction in pollution
ylim      = [ 0 0.6 ];
plotDiscretionValue( file, Nbar, mnabate/(sum(XTwt)), objective, ylim )

display([Nbar' mnabate]);


%% ========================================================================
% Facts related to inspection marginal effects
%==========================================================================

aj = (lambda(1) + XT*beta);

% Expected inspections, given observables
EI = @(x) lambda(2) * normcdf( x/(rho^2+sigma(1)^2)^0.5 );
Is = targetPhiFun( lambda, sigma(1), rho );

% 'Marginal' effect of treatment
%    Plant in Ahmedabad region and not in audit sample
Xeg = [ 0 0 0 0 0 0 ];
fprintf(1,'Valsad, not audit sample, control: %3.2f inspections\n',...
          EI(lambda(1) + Xeg*beta));
Xeg = [ 0 0 0 0 0 1 ];
fprintf(1,'Valsad, not audit sample, treat: %3.2f inspections\n',...
          EI(lambda(1) + Xeg*beta));

% Level of inspection for clean plant
Xeg = [ 0 0 1 0 1 0 ];
fprintf(1,'\nAhmedabad, audit sample, control, clean: %3.2f inspections',...
        EI(lambda(1) + Xeg*beta - 1.65*sigma(1)));
fprintf(1,'\nAhmedabad, audit sample, control, dirty: %3.2f inspections\n',...
    EI(lambda(1) + Xeg*beta + 1.65*sigma(1)));
    

%% ========================================================================
% Figure 1, Panel B: Effect of Treatment on Pollution Distribution
%==========================================================================

% Read pollutant-level data
cd(data);
file    = 'targeting_estimation_pollutant_080515.csv';

x       = dlmread(file,',',1,0);
vnames  = textread(file,'%s',size(x,2),'delimiter',',');

idp   = x(:,1);
Pp    = x(:,4);       % Pollution relative to regulatory limit
TIp   = x(:,10) == 1; % Inspection treatment status
TAp   = x(:,11) == 1; % Audit treatment status
TAxIp = TAp .* TIp;   % Inspection X audit treatment

X1p      = [ TAp TAxIp x(:,12:14) ones(length(x),1) ];
X1namesp = [ vnames(11);'Aud X Ins treat';vnames(12:14);'constant' ]; 
X2p      = x(:,15:17);
X2namesp = vnames(15:17);

% Generate pollutant-level dataset with abatement decisions
cd(data)
load('target_theta_gmm2_ctop_2016_06_24.mat');
% load('target_theta_gmm2_ctop_constrained_2016_08_13');

chgUnits = 0;
lengths  = [ 6 7 1 2 2 ]'; % Beta phi muc sigma lambda
% lengths = [ 9 10 1 2 2 ]';
signs   = [ zeros(1,lengths(1))       ...  % beta
            zeros(1,lengths(2)-1) -1  ...  % phi
            0 1 1 0 0 0 ]';              % muc, sigma, lambda, gamma

[ beta, phi, muc, sigma, lambda, ~ ] = ...
    unpackThetaV3( thetaHatD, chgUnits, signs, lengths );
rho  = 0.25;

% Draw shocks for data generating process
%   u = [ u1, u2, uc ] for common error, pollution error and cost shock
%   t = [ t1, t2 ]     for observable covariates, treatment assignment
rng(20150911);
S = 1;
N = length(Pp);
u = randn(N,S,3);

% Generate datae
[ Im, lnPm, Runm, cm ] = generateRunData( S, X1p, TIp, u, AbsV, rho, sigc, ...
                                          beta, phi, muc, sigma, lambda );

% Estimate treatment effect by bins
cd(figures)
Pm = exp(lnPm);
Pm = (Pm - 1) ./ std(Pm,[],1);

file = sprintf('Figure1B_Treatment_On_Pollution_Bins.pdf');
plotTreatByBin( file, Pm, TIp, X1p );
                        

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%% END %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



