%% ========================================================================
%          Estimation of regulatory targeting model
%%=========================================================================

% This file uses plant pollution, inspections and characteristics data,
% treatment assignments and estimates of the penalty function to estimate
% the parameters of the regulator's targeting problem.
%  
% The output from the file includes:
%    

% Set directories for targeting code and data
%   Start from /replication/code/03_targeting_stage
clear;
cd ../../;
root = pwd;

code    = [root,'/code/03_targeting_stage/'];
data    = [root,'/data/03_targeting_stage/'];
penalty = [root,'/code/02_penalty_stage/'];
tables  = [root,'/output/tables'];
figures = [root,'/output/figures'];

addpath(code);
addpath(penalty);

%% ========================================================================
%      Load data on inspections, pollution and plant characteristics
%%=========================================================================

% Chains estimation data file, most recent
cd(data);
file    = 'targeting_estimation_plant_080515.csv';
x       = dlmread([data,file],',',1,0);
vnames  = textread([data,file],'%s',size(x,2),'delimiter',',');

cd(code);
N    = size(x,1);
id   = x(:,1);
lnP  = log(x(:,4));  % Pollution relative to regulatory limit
I    = x(:,6);       % Chains per year
c    = x(:,9);       % Maintenance cost
TI   = x(:,10) == 1; % Inspection treatment status
TA   = x(:,11) == 1; % Audit treatment status
TAxI = TA .* TI;     % Inspection X audit treatment

X1      = [ TA TAxI x(:,12:14)  ];
X1names = [vnames(11);'Aud X Ins treat';vnames(12:14)]; 
X2      = x(:,15:17);
X2names = vnames(15:17);
X3      = x(:,18:end);
X3names = vnames(18:end);
X4      = [ x(:,21) x(:,27) ];
X4names = [vnames(21); vnames(27)];

X      = [  ones(N,1)  X1      ];
Xnames = [ 'constant'; X1names ];

% X      = [  ones(N,1)  X1       X2      ];
% Xnames = [ 'constant'; X1names; X2names ];

% Decision to run abatement equipment
Run     = c > 0;

% Top-code pollution and maintenance cost outliers
% ctop = prctile(c,99);
% c    = min(c,ctop);

% Create observable 'types' of plants, where J indexes types
[ XT, ~, J ] = unique( [X(:,2:end) TI], 'rows' );
XTwt         = accumarray(J,ones(size(J)));

IJ = [ accumarray(J,I,[],@mean), accumarray(J,I.^2,[],@mean) ];


%% Load penalty function
cd([root,'/data/02_penalty_stage/']);
load('penalty_function.mat');

% Continuous and differentiable spline penalty function
%   Fit additional control points to allow reasonable values outside
%   domain of the original penalty function. Evaluate with ppval(AbsV,p).
pbins   = [ 1.0 1.5 3.5 7.5 ]';
pbinsEx = [0; pbins; 11.5];
VpEx    = [-1; Vp(2:end,3); 2*Vp(end,3)-Vp(end-1,3)];
AbsV    = pchip(pbinsEx,VpEx);


%% ========================================================================
%      Estimation of targeting model
%%=========================================================================

%% Initialize coefficients

% a. Inspection equation and shocks

% Initialize parameters to be estimated   
N       = size(TI,1);
P       = size(X,2);

beta0   = zeros(P,1);
muc0    = 1;               % Log normal distribution initial mean
sigma0  = 0.8 * ones(2,1); % Initial pollution shock std devs
lambda0 = [ 0 8 ]';        % Initial lambdas

% Calibrated parameters
rho     = 0.25;
sigc    = 0.50;

% b. Pollution equation

% Estimate phi0 via 2SLS for starting point
title    = 'Pollution 2SLS: %s';
colHeads = {'','phi'};
format   = ['%15s %10.3f %10.3f'];

% Basic + cost controls
subtitle = 'Starting Values';
titlesub = sprintf(title,subtitle);
[ phi0, se ] = ivregress( lnP, [X Run], [X TI] );
rowHeads = [Xnames;'Run Equipment'];
tabDisplay( 1, titlesub, colHeads, rowHeads, [phi0 se], format )
phi0(end) = -1;

e2hat = lnP - [X Run] * phi0;
mean(e2hat.*I)
corr(e2hat,I)

% c. Pack starting values into theta vector

% Rho calibrated
theta0  = [ beta0; phi0; muc0; sigma0(1); sigma0(2); lambda0 ];
signs   = [ zeros(1,length(beta0))      ...  % beta
            zeros(1,length(phi0)-1) -1  ...  % phi
            0 1 1 0 0 ]';                    % muc, sigma, lambda
lengths = [ length(beta0); length(phi0); length(muc0); length(sigma0); ...
            length(lambda0) ];
 
% % Rho free
% theta0  = [ beta0; phi0; muc0; sigma0(1); sigma0(2); rho0; lambda0 ];
% signs   = [ zeros(1,length(beta0))      ...  % beta
%             zeros(1,length(phi0)-1) -1  ...  % phi
%             0 1 1 0 0 0 ]';                  % muc, sigma, lambda, rho
% lengths = [ length(beta0); length(phi0); length(muc0); length(sigma0); ...
%             length(rho0); length(lambda0) ];

theta0  = changeThetaVars( theta0, signs, 1 );


%% Initialize shocks: Unobservable characteristics of plants
%   Used in simulations and targeting function

% Generate *fixed* matrix of standard normal errors for simulation draws
rng(20160519);
S = 200;
% S  = 5000;          % Simulations to be used for calculating moments
us = randn(N,S,3);

% Set of observed and unobserved pollution shocks at which to evaluate
%   regulator's objective function. Use Halton draws to cover possible
%   standard normal shocks with minimal simulation variation.
% H  = 63;
H  = 31;
h  = haltonset(2,'Skip',1,'Leap',0);
h  = net(h,H);
uI = norminv(h,0,1);


%% ========================================================================
%  Estimate coefficients: unconstrained, one set of simulation draws
foptions = optimset('Display','iter','LargeScale','off',...
                     'TolFun',1e-12,'TolX',1e-12,'TolCon',1e-5,...
                     'MaxIter',2e4,'MaxFunEvals',1e5);
                 
% Two-step GMM: Step one
W = [];
gmmTheta = @(x) gmm7( x, W, rho, sigc, lnP, I, IJ, J, Run, c, X, TI, ...
                      XT, XTwt, AbsV, us, uI, signs, lengths );
                  
tic;
thetaHat = fminunc( gmmTheta, theta0, foptions );
toc;

theta0D   = changeThetaVars( theta0,   signs, 0 );
thetaHatD = changeThetaVars( thetaHat, signs, 0 );
display([ theta0D thetaHatD ]);


%% Two-step GMM: Step two
[ ~, ~, OmegaHat ] = gmmTheta( thetaHat );
W                  = inv(OmegaHat);
gmmTheta = @(x) gmm7( x, W, rho, sigc, lnP, I, IJ, J, Run, c, X, TI, ...
                      XT, XTwt, AbsV, us, uI, signs, lengths );

tic;
[ thetaHat, Qunc ] = fminunc( gmmTheta, thetaHat, foptions );
toc;

theta0D   = changeThetaVars( theta0,   signs, 0 );
thetaHatD = changeThetaVars( thetaHat, signs, 0 );
display([ theta0D thetaHatD ]);


%% Calculate standard errors for unconstrained estimates
delta = 1e-5;

[ sigmaHat ] = covarianceTargetingMoments( gmmTheta, thetaHat, delta, signs );
display([ theta0D thetaHatD sigmaHat ]);

cd(tables);
title = sprintf('Targeting Coefficients: Unconstrained (S = %4.0f)',S);
file  = 'Table6_Estimates_of_Targeting_Stage_Unc.tex';
rowHeads = [Xnames(2:end)',{'Insp. treatment'},Xnames(:)',{'Run'},...
            {'muc'},{'sig1'},{'sig2'},{'lambda1'},{'lambda2'}];
tabTargetCoefs( 1, file, title, rowHeads, theta0D, thetaHatD, sigmaHat, 0 )

file = sprintf('target_theta_gmm_logn_cost_rho25_%s.mat',datestr(now,'yyyy_mm_dd'));
save(file,'thetaHat','thetaHatD','theta0D','sigmaHat','rho','sigc','W');


% Targeting Coefficients: Unconstrained Model (S=200)
%                           truth        estimate 
%   aud_treatment           0.000          -0.005 (0.017)
% Aud X Ins treat           0.000           0.016 (0.021)
%      aud_sample           0.000           0.095 (0.024)
%         reg_abd           0.000          -0.221 (0.044)
%         reg_sur           0.000          -0.178 (0.040)
% Insp. treatment           0.000           0.162 (0.025)
%        constant          -0.197          -0.004 (0.103)
%   aud_treatment          -0.072          -0.102 (0.085)
% Aud X Ins treat           0.033           0.066 (0.108)
%      aud_sample           0.584           0.613 (0.137)
%         reg_abd          -0.219          -0.201 (0.132)
%         reg_sur          -0.254          -0.371 (0.164)
%             Run          -1.000          -0.742 (0.307)
%             muc           1.000           1.859 (0.316)
%            sig1           0.800           0.111 (0.022)
%            sig2           0.800           0.866 (0.042)
%         lambda1           0.000          -0.219 (0.066)
%         lambda2           8.000          10.043 (3.124)

% Targeting Coefficients: Unconstrained Model (S=5000)
%                           truth        estimate 
%   aud_treatment           0.000          -0.005 (0.017)
% Aud X Ins treat           0.000           0.015 (0.021)
%      aud_sample           0.000           0.095 (0.024)
%         reg_abd           0.000          -0.221 (0.044)
%         reg_sur           0.000          -0.178 (0.040)
% Insp. treatment           0.000           0.162 (0.025)
%        constant          -0.197          -0.009 (0.102)
%   aud_treatment          -0.072          -0.101 (0.085)
% Aud X Ins treat           0.033           0.065 (0.108)
%      aud_sample           0.584           0.612 (0.137)
%         reg_abd          -0.219          -0.199 (0.131)
%         reg_sur          -0.254          -0.366 (0.164)
%             Run          -1.000          -0.711 (0.308)
%             muc           1.000           1.833 (0.334)
%            sig1           0.800           0.111 (0.022)
%            sig2           0.800           0.864 (0.042)
%         lambda1           0.000          -0.220 (0.066)
%         lambda2           8.000          10.064 (3.137)


%% ========================================================================
% Estimate coefficients: constrained
                 
% Inspection budget constraint for *control* inspections 
Nbar = 1.4708;  % 1.4708 in control group 

% Solve optimal targeting rule
group = 1;

[ beta, phi, muc, sigma, lambda, ~ ] = ...
    unpackThetaV3( thetaHatD, 0, signs, lengths );

[ lambdaStar ] = solveInspectionTargetingP( uI, Nbar, beta, phi, rho, ...
                                            XT, XTwt, sigma(1), sigma(2), ...
                                            muc, sigc, AbsV, group );
display(lambdaStar);
                                      

%% Initial point by first-order conditions in control group
% gamma0  = 0.1;
theta0  = [ thetaHat(1:end-2); lambdaStar ];

% Ensure feasibility by solving for optimal lambda, gamma at initial point
lambdaStar2 = inspectionTargetingFOCInit( theta0, uI, Nbar, rho, sigc, ...
                                      XT, XTwt, AbsV, signs, lengths );
theta0(end-1:end) = lambdaStar2;
display(lambdaStar2);


%% Estimate coefficients with optimality constraint
lb = -Inf * ones(size(theta0));
ub =  Inf * ones(size(theta0));
lb(end)         = 1;
ub(end-3:end-2) = 2;

% Nonlinear inequality and equality constraints
%       Nlcon to return [ c, ceq ] with c(x) <= 0 and ceq(x) = 0
nlcon = @(x) inspectionTargetingFOC( x, uI, Nbar, rho, sigc, ...
                                     XT, XTwt, AbsV, signs, lengths  );
                    
thetaHat = knitromatlab(gmmTheta,theta0,[],[],[],[],lb,ub,...
                        nlcon,[],foptions);         
                 
%% Two-step GMM: Step two
[ ~, ~, OmegaHat ] = gmmTheta( thetaHat );
W                  = inv(OmegaHat);
gmmTheta = @(x) gmm7( x, W, rho, sigc, lnP, I, IJ, J, Run, c, X, TI, ...
                      XT, XTwt, AbsV, us, uI, signs, lengths );
                  
[ thetaHat, Qcon ] = knitromatlab(gmmTheta,thetaHat,[],[],[],[],lb,ub,...
                                  nlcon,[],foptions); 
                                                           
theta0D   = changeThetaVars( theta0,   signs, 0 );
thetaHatD = changeThetaVars( thetaHat, signs, 0 );
display([ theta0D thetaHatD ]);


%% Calculate standard errors for constrained estimates
[ sigmaHat ] = covarianceTargetingMomentsCon( gmmTheta, thetaHat, delta, ...
                                              signs, nlcon );

% Write all coefficients to screen
cd(tables);
title = sprintf('Estimates of Targeting Stage: Constrained (S = %4.0f)',S);
file  = 'Table6_Estimates_of_Targeting_Stage_Con.tex';
rowHeads = [Xnames(2:end)',{'Insp. treatment'},Xnames(:)',{'Run'},...
            {'muc'},{'sig1'},{'sig2'},{'lambda1'},{'lambda2'},{'gamma'}];
tabTargetCoefs( 1, file, title, rowHeads, theta0D, thetaHatD, sigmaHat, 0 )

file = sprintf('target_theta_gmm2_ctop_constrained_%s.mat',...
               datestr(now,'yyyy_mm_dd'));
save(file,'thetaHat','thetaHatD','theta0D','sigmaHat','rho','sigc','W');

% Targeting Coefficients: Constrained Model (S=200)
%                           truth        estimate 
%   aud_treatment          -0.005           0.001 (0.011)
% Aud X Ins treat           0.016           0.002 (0.012)
%      aud_sample           0.095           0.062 (0.013)
%         reg_abd          -0.221          -0.134 (0.012)
%         reg_sur          -0.178          -0.105 (0.015)
% Insp. treatment           0.162           0.095 (0.009)
%        constant          -0.003           0.210 (0.108)
%   aud_treatment          -0.102          -0.145 (0.099)
% Aud X Ins treat           0.066           0.172 (0.120)
%      aud_sample           0.613           0.590 (0.164)
%         reg_abd          -0.201          -0.233 (0.157)
%         reg_sur          -0.371          -0.462 (0.194)
%             Run          -0.744          -1.880 (0.158)
%             muc           1.859           2.379 (0.060)
%            sig1           0.111           0.069 (0.003)
%            sig2           0.866           1.029 (0.046)
%         lambda1          -0.383          -0.393 (0.003)
%         lambda2          32.849          32.604 (1.853)

% Targeting Coefficients: Constrained Model (S=5000)
%                           truth        estimate 
%   aud_treatment          -0.005           0.001 (0.011)
% Aud X Ins treat           0.015           0.002 (0.012)
%      aud_sample           0.095           0.061 (0.015)
%         reg_abd          -0.221          -0.133 (0.023)
%         reg_sur          -0.178          -0.103 (0.021)
% Insp. treatment           0.162           0.094 (0.010)
%        constant          -0.009           0.214 (0.118)
%   aud_treatment          -0.101          -0.144 (0.100)
% Aud X Ins treat           0.065           0.173 (0.124)
%      aud_sample           0.612           0.590 (0.165)
%         reg_abd          -0.199          -0.232 (0.158)
%         reg_sur          -0.366          -0.463 (0.198)
%             Run          -0.711          -1.910 (0.378)
%             muc           1.833           2.392 (0.146)
%            sig1           0.111           0.068 (0.011)
%            sig2           0.864           1.034 (0.072)
%         lambda1          -0.388          -0.397 (0.076)
%         lambda2          34.083          33.548 (19.030)

%% Test of constrained model with optimal targeting
DM  = N * ( Qcon - Qunc );
DMp = chi2cdf(DM,2,'upper');
fprintf(1,'\nTest of constrained model:');
fprintf(1,'\n  Chi-square (2): %6.4f, p-value %6.4f\n',DM,DMp);


%% ========================================================================
% Appendix exhibits: robustness to calibrated parameters

% Read estimates from multiple runs with different calibrated parameters
cd(data);
files = {'target_theta_gmm_logn_cost_sigc050_2017_07_26',...
         'target_theta_gmm_logn_cost_sigc025_2017_07_26.mat',...
         'target_theta_gmm_logn_cost_sigc100_2017_07_26.mat',...
         'target_theta_gmm_logn_cost_rho15_2017_07_26.mat',...
         'target_theta_gmm_logn_cost_rho35_2017_07_26.mat'};
load(files{1},'thetaHatD','sigmaHat','sigc','rho');
thetas = zeros(length(thetaHatD),5);
sigmas = zeros(length(sigmaHat),5);
sigcs  = zeros(1,5);
rhos   = zeros(1,5);
EI     = zeros(2,5);

for i = 1:5  
    load(files{i},'thetaHatD','sigmaHat','sigc','rho');
     
    thetas(:,i) = thetaHatD;
    sigmas(:,i) = sigmaHat;
    sigcs(:,i) = sigc;
    rhos(:,i)  = rho;
    
    [ beta, phi, muc, sigma, lambda, ~ ] = ...
        unpackThetaV3( thetaHatD, 0, signs, lengths );
      
    [ EI1, EI2 ] = expectedInspectionsP( lambda, beta, sigma(1), ...
                                         rho, XT, XTwt );
    EI(1,i) = XTwt' * EI1 / sum(XTwt);
    EI(2,i) = XTwt' * EI2 / sum(XTwt);
end

% Output sensitivity table
cd(tables);
fname = 'TableD12_Calibration_Sensitivity.tex';
fid = fopen(fname, 'w');
tabCalibrationSensitivity( fid, thetas, sigmas, sigcs, rhos )

% Expected inspections under alternate calibrated parameters
fname = 'TableD13_Expected_Inspection_Sensitivity.tex';
fid = fopen(fname, 'w');
tabCalibrationInspections( fid, EI, sigcs, rhos )


%% ========================================================================
%   Sensitivity analysis (method of Andrews, Gentzgow and Shapiro, 2017)

% Obtain targeting parameter estimates
cd(data);
load 'target_theta_gmm_logn_cost_rho25_2018_04_03.mat';

% Calculate objective function
gmmTheta = @(x) gmm7( x, W, rho, sigc, lnP, I, IJ, J, Run, c, X, TI, ...
                      XT, XTwt, AbsV, us, uI, signs, lengths );
                  
% Calculate sensitivity around estimates
delta = 1e-5;
[ sigmaHat, OmegaHat, LambdaHat ] = ...
    computeSensitivityMatrix(gmmTheta, thetaHat, delta, signs);

cd(tables);                                           
%Sensitivities for Selected Parameters Table
fname = 'TableD14_Sensitivities_for_Selected_Parameters.tex';
tabSelectSensitivities(fname,LambdaHat,OmegaHat)

%Top Moments for Selected Parameters Table
fname = 'TableD15_Most_Important_Moments_for_Selected_Parameters.tex';
tabImportantMoments(fname,LambdaHat,OmegaHat)

cd(figures);

% Figure 5
fname = 'Figure5_Sensitivity_of_Targeting_Parameters.pdf';

LambdaHat = py.numpy.reshape(LambdaHat(:)',int32(size(LambdaHat)), 'F');
OmegaHat  = py.numpy.reshape(OmegaHat(:)',int32(size(OmegaHat)), 'F');
sig1 = thetaHatD(15);
sig2 = thetaHatD(16);

cd(code);
mod = py.importlib.import_module('figure5Code');

cd(figures);
py.figure5Code.figSensitivity(fname,LambdaHat,OmegaHat,sig1,sig2);
                                          
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
